@@ -2,7 +2,7 @@
  * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -24,12 +24,11 @@
 
 #include "dheaderline.h"
 #include "dbaseline.h"
-#include "dseparatorhorizontal.h"
-#include "dseparatorvertical.h"
 #include "dbaseexpand.h"
-#include "darrowlineexpand.h"
 #include "dswitchlineexpand.h"
-#include "dexpandgroup.h"
+#include "ddrawer.h"
+#include "darrowlinedrawer.h"
+#include "ddrawergroup.h"
 
 DWIDGET_USE_NAMESPACE
 
@@ -37,7 +36,7 @@ class LineTab : public QLabel
 {
     Q_OBJECT
 public:
-    explicit LineTab(QWidget *parent = 0);
+    explicit LineTab(QWidget *parent = nullptr);
 };
 
 #endif // LINETAB_H
