@@ -2,7 +2,7 @@
  * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,19 +11,21 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "mainwindow.h"
-#include "dlabel.h"
-#include "dapplication.h"
-#include "dplatformwindowhandle.h"
+
+#include <DTitlebar>
+#include <DApplication>
+#include <DApplicationSettings>
+#include <DWidgetUtil>
+#include <DLog>
+#include <DDialog>
 
 #include <QDebug>
-#include <DLog>
-
-#include "util/dwidgetutil.h"
+#include <QTextBrowser>
 
 DWIDGET_USE_NAMESPACE
 
@@ -32,25 +34,33 @@ int main(int argc, char *argv[])
 #if defined(DTK_STATIC_LIB)
     DWIDGET_INIT_RESOURCE();
 #endif
-
-    DApplication::loadDXcbPlugin();
-
     DApplication a(argc, argv);
+    qDebug() <<  a.arguments();
+    DApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
     Dtk::Core::DLogManager::registerConsoleAppender();
 
     a.loadTranslator();
-    a.setAttribute(Qt::AA_EnableHighDpiScaling, true);
-    a.setTheme("light");
 #ifdef Q_OS_UNIX
     a.setOOMScoreAdj(500);
 #endif
 
-    if (!a.setSingleInstance("deepin-tool-kit-examples")) {
+    if (!DGuiApplicationHelper::setSingleInstance("deepin-tool-kit-examples")) {
         qDebug() << "another instance is running!!";
     }
 
+    a.setApplicationName("dtk-example");
+    a.setOrganizationName("deepin");
+    DApplicationSettings as;
+    Q_UNUSED(as)
+
     MainWindow w;
+//    DIconButton *button = new DIconButton(&w);
+//    button->setIconSize(QSize(30, 30));
+//    button->setFlat(true);
+//    button->setIcon(QIcon::fromTheme("button_edit-clear"));
+//    w.setCentralWidget(button);
     w.show();
+
     Dtk::Widget::moveToCenter(&w);
 
     return a.exec();
