@@ -2,7 +2,7 @@
  * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -50,6 +50,10 @@
 #include "dthememanager.h"
 #include "private/dapplication_p.h"
 #include "daboutdialog.h"
+#include "dmainwindow.h"
+
+#include <DPlatformHandle>
+#include <DGuiApplicationHelper>
 
 #ifdef Q_OS_UNIX
 #include <QDBusError>
@@ -83,22 +87,29 @@ DApplicationPrivate::DApplicationPrivate(DApplication *q) :
     auto cancelNotification = [this, q](const QString id) {
         m_monitoredStartupApps.removeAll(id);
         if (m_monitoredStartupApps.isEmpty()) {
-            q->setOverrideCursor(Qt::ArrowCursor);
+            q->restoreOverrideCursor();
         }
     };
     QObject::connect(monitor, &StartupNotificationMonitor::appStartup,
                      q, [this, q, cancelNotification](const QString id) {
+        // FIX bug start app quikly cursor will not restore...
+        // Every setOverrideCursor() must eventually be followed by a corresponding restoreOverrideCursor(),
+        // otherwise the stack will never be emptied.
+        if (m_monitoredStartupApps.isEmpty()) {
+            q->setOverrideCursor(Qt::WaitCursor);
+        }
         m_monitoredStartupApps.append(id);
-        q->setOverrideCursor(Qt::WaitCursor);
-        // Set a timeout of 15s in case that some apps like pamac-tray started
+        // Set a timeout of 5s in case that some apps like pamac-tray started
         // with StartupNotify but don't show a window after startup finished.
-        QTimer::singleShot(15 * 1000, q, [id, cancelNotification](){
+        QTimer::singleShot(5 * 1000, q, [id, cancelNotification](){
             cancelNotification(id);
         });
     });
     QObject::connect(monitor, &StartupNotificationMonitor::appStartupCompleted,
                      q, cancelNotification);
 #endif
+
+    QApplication::setStyle("chameleon");
 }
 
 DApplicationPrivate::~DApplicationPrivate()
@@ -106,6 +117,11 @@ DApplicationPrivate::~DApplicationPrivate()
     if (m_localServer) {
         m_localServer->close();
     }
+
+    while (q_func()->overrideCursor()) {
+        q_func()->restoreOverrideCursor();
+    }
+
 }
 
 QString DApplicationPrivate::theme() const
@@ -256,6 +272,7 @@ bool DApplicationPrivate::loadTranslator(QList<DPathBuf> translateDirs, const QS
 {
     D_Q(DApplication);
 
+    QStringList missingQmfiles;
     for (auto &locale : localeFallback) {
         QString translateFilename = QString("%1_%2").arg(name).arg(locale.name());
         for (auto &path : translateDirs) {
@@ -269,6 +286,11 @@ bool DApplicationPrivate::loadTranslator(QList<DPathBuf> translateDirs, const QS
             }
         }
 
+        // fix english does not need to translation..
+        if (locale.language() != QLocale::English) {
+            missingQmfiles << translateFilename + ".qm";
+        }
+
         QStringList parseLocalNameList = locale.name().split("_", QString::SkipEmptyParts);
         if (parseLocalNameList.length() > 0) {
             translateFilename = QString("%1_%2").arg(name)
@@ -284,55 +306,35 @@ bool DApplicationPrivate::loadTranslator(QList<DPathBuf> translateDirs, const QS
                 }
             }
         }
+
+        // fix english does not need to translation..
+        if (locale.language() != QLocale::English) {
+            missingQmfiles << translateFilename + ".qm";
+        }
     }
 
-    qWarning() << name << "can not find qm files" ;
+    if (missingQmfiles.size() > 0) {
+        qWarning() << name << "can not find qm files" << missingQmfiles;
+    }
     return false;
 }
 
-void DApplicationPrivate::resetApplicationThemeType()
+// 自动激活DMainWindow类型的窗口
+void DApplicationPrivate::_q_onNewInstanceStarted()
 {
-    D_QC(DApplication);
-    // 在 DThemeManager 初始化期间会调用 QApplicationi::setStyle
-    // 这将导致应用程序的调色板发生变化，因此先初始化DThemeManager对象
-    // 之后再获取调色板中的背景色
-    DThemeManager *tm = DThemeManager::instance();
-
-    // tm为空说明DThemeManager对象正在被初始化
-    if (!tm) {
+    if (!autoActivateWindows)
         return;
+
+    for (QWidget *window : qApp->topLevelWidgets()) {
+        if (qobject_cast<DMainWindow*>(window)) {
+            // 如果窗口最小化，應當先將其show出來
+            if (window->isMinimized())
+                window->showNormal();
+
+            window->activateWindow();
+            break; // 只激活找到的第一个窗口
+        }
     }
-
-    const QColor &window_background = q->palette().background().color();
-
-    // 颜色无效时不处理（窗口背景可能为图片）
-    if (!window_background.isValid()) {
-        return;
-    }
-
-    DThemeManager::ThemeType type = DThemeManager::toThemeType(window_background);
-    tm->setThemeType(type);
-}
-
-void DApplicationPrivate::resetWindowThemeType(QWidget *window)
-{
-    D_QC(DApplication);
-
-    // 如果窗口未自定义调色板，则清除其“主题类型”的设置
-    if (!window->testAttribute(Qt::WA_SetPalette)) {
-        DThemeManager::instance()->setThemeType(window, DThemeManager::UnknownType);
-        return;
-    }
-
-    const QColor &window_background = window->palette().background().color();
-
-    // 颜色无效时不处理（窗口背景可能为图片）
-    if (!window_background.isValid()) {
-        return;
-    }
-
-    DThemeManager::ThemeType type = DThemeManager::toThemeType(window_background);
-    DThemeManager::instance()->setThemeType(window, type);
 }
 
 bool DApplicationPrivate::isUserManualExists()
@@ -465,9 +467,6 @@ DApplication::DApplication(int &argc, char **argv) :
             QTapAndHoldGesture::setTimeout(gsettings.get("longpress-duration").toInt() - 100);
     }
 #endif
-
-    // 初始化窗口主题类型
-    d_func()->resetApplicationThemeType();
 }
 
 
@@ -554,7 +553,7 @@ void DApplication::setOOMScoreAdj(const int score)
  */
 bool DApplication::setSingleInstance(const QString &key)
 {
-    return setSingleInstance(key, SystemScope);
+    return setSingleInstance(key, UserScope);
 }
 
 /*!
@@ -569,24 +568,11 @@ bool DApplication::setSingleInstance(const QString &key, SingleScope singleScope
 {
     D_D(DApplication);
 
-    QString k = key;
+    auto scope = singleScope == SystemScope ? DGuiApplicationHelper::WorldScope : DGuiApplicationHelper::UserScope;
+    connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::newProcessInstance,
+            this, &DApplication::newInstanceStarted, Qt::UniqueConnection);
 
-#ifdef Q_OS_UNIX
-    switch (singleScope) {
-    case DApplication::UserScope:
-        k += QString("_%1").arg(getuid());
-        break;
-    default:
-        break;
-    }
-#endif
-
-#ifdef Q_OS_UNIX
-    if (!qEnvironmentVariableIsSet("DTK_USE_SEMAPHORE_SINGLEINSTANCE")) {
-        return d->setSingleInstanceByDbus(k);
-    }
-#endif
-    return d->setSingleInstanceBySemaphore(k);
+    return DGuiApplicationHelper::setSingleInstance(key, scope);
 }
 
 /*!
@@ -658,12 +644,7 @@ bool DApplication::loadDXcbPlugin()
  */
 bool DApplication::isDXcbPlatform()
 {
-    if (!qApp)
-        return false;
-
-    static bool _is_dxcb = qApp->platformName() == DXCB_PLUGIN_KEY || qApp->property(DXCB_PLUGIN_SYMBOLIC_PROPERTY).toBool();
-
-    return _is_dxcb;
+    return DGUI_NAMESPACE::DPlatformHandle::isDXcbPlatform();
 }
 
 /*!
@@ -1034,6 +1015,28 @@ void DApplication::setVisibleMenuIcon(bool value)
     d->visibleMenuIcon = value;
 }
 
+bool DApplication::autoActivateWindows() const
+{
+    D_DC(DApplication);
+
+    return d->autoActivateWindows;
+}
+
+void DApplication::setAutoActivateWindows(bool autoActivateWindows)
+{
+    D_D(DApplication);
+
+    d->autoActivateWindows = autoActivateWindows;
+
+    if (autoActivateWindows) {
+        connect(DGuiApplicationHelper::instance(), SIGNAL(newProcessInstance(qint64, const QStringList &)),
+                this, SLOT(_q_onNewInstanceStarted()));
+    } else {
+        disconnect(DGuiApplicationHelper::instance(), SIGNAL(newProcessInstance(qint64, const QStringList &)),
+                this, SLOT(_q_onNewInstanceStarted()));
+    }
+}
+
 /**
  * \~english @brief DApplication::handleHelpAction
  *
@@ -1099,8 +1102,14 @@ void DApplication::handleAboutAction()
     }
     aboutDialog->setAcknowledgementVisible(d->acknowledgementPageVisible);
 
-    aboutDialog->exec();
-    aboutDialog->deleteLater();
+    aboutDialog->show();
+    aboutDialog->setAttribute(Qt::WA_DeleteOnClose);
+
+    //目前的关于对话框是非模态的,这里的处理是防止关于对话框可以打开多个的情况
+    d->aboutDialog = aboutDialog;
+    connect(d->aboutDialog, &DAboutDialog::aboutToClose, this, [=] {
+        d->aboutDialog = nullptr;
+    });
 }
 
 /**
@@ -1135,78 +1144,22 @@ static inline bool basePrintPropertiesDialog(const QWidget *w)
 
 bool DApplication::notify(QObject *obj, QEvent *event)
 {
-    switch((int)event->type()) {
-    case QEvent::PolishRequest: {
-        // Fixed the style for the menu widget to dlight
-        // ugly code will no longer needed.
-        static QStyle *light_style = nullptr;
+    if (event->type() == QEvent::FocusIn) {
+        QFocusEvent *fe = static_cast<QFocusEvent*>(event);
+        QWidget *widget = qobject_cast<QWidget*>(obj);
 
-        if (QMenu *menu = qobject_cast<QMenu *>(obj)) {
-            if (!menu->testAttribute(Qt::WA_SetStyle)) {
-                if (!light_style) {
-                    light_style = QStyleFactory::create("dlight");
-                }
+        if (widget && fe->reason() == Qt::ActiveWindowFocusReason && !widget->isTopLevel()
+                && (widget->focusPolicy() & Qt::StrongFocus) != Qt::StrongFocus) {
+            // 针对激活窗口所获得的焦点，为了避免被默认给到窗口内部的控件上，此处将焦点还给主窗口
+            // 并且只设置一次
+#define NON_FIRST_ACTIVE "_d_dtk_non_first_active_focus"
+            QWidget *top_window = widget->topLevelWidget();
 
-                if (light_style) {
-                    menu->setStyle(light_style);
-                }
+            if (top_window->isWindow() && !top_window->property(NON_FIRST_ACTIVE).toBool()) {
+                top_window->setFocus();
+                top_window->setProperty(NON_FIRST_ACTIVE, true);
             }
         }
-#ifdef Q_OS_LINUX
-        else if (QWidget *widget = qobject_cast<QWidget *>(obj)) {
-            if (!widget->testAttribute(Qt::WA_SetStyle)
-                    && (widget->inherits("QPrintDialog")
-                        || widget->inherits("QPrintPropertiesDialog")
-                        || widget->inherits("QPageSetupDialog")
-                        || widget->inherits("QPrintPreviewDialog")
-                        || (widget->inherits("QComboBoxPrivateContainer")
-                            && basePrintPropertiesDialog(widget)))) {
-                if (!light_style) {
-                    light_style = QStyleFactory::create("dlight");
-                }
-
-                if (light_style) {
-                    widget->setStyle(light_style);
-
-                    if (widget->style() != light_style) {
-                        widget->style()->deleteLater();
-                        widget->d_func()->setStyle_helper(light_style, false);
-                    }
-
-                    for (QWidget *w : widget->findChildren<QWidget *>()) {
-                        w->setStyle(light_style);
-                    }
-                }
-            }
-        }
-#endif
-        break;
-    }
-    case QEvent::ParentChange: {
-        if (QWidget *widget = qobject_cast<QWidget *>(obj)) {
-            DThemeManager::instance()->updateThemeOnParentChanged(widget);
-        }
-        break;
-    }
-    // 处理应用程序和主窗口的调色板变化事件，以此更新程序/窗口的主题类型
-    case QEvent::ApplicationPaletteChange: {
-        // 只处理发送给application对象的事件
-        if (obj == this) {
-            D_D(DApplication);
-            d->resetApplicationThemeType();
-        }
-        break;
-    }
-    case QEvent::PaletteChange: {
-        D_D(DApplication);
-
-        if (QWidget *window = qobject_cast<QWidget*>(obj)) {
-            if (window->isTopLevel()) {
-                d->resetWindowThemeType(window);
-            }
-        }
-        break;
-    }
     }
 
     return QApplication::notify(obj, event);
@@ -1215,3 +1168,5 @@ bool DApplication::notify(QObject *obj, QEvent *event)
 int DtkBuildVersion::value = 0;
 
 DWIDGET_END_NAMESPACE
+
+#include "moc_dapplication.cpp"
