@@ -2,7 +2,7 @@
  * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,18 +11,20 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef DAPPLICATION_H
 #define DAPPLICATION_H
 
+#include <dtkwidget_global.h>
+#include <DObject>
+#include <DPalette>
+
 #include <QApplication>
 
-#include "dtkwidget_global.h"
-#include "dobject.h"
-
+DGUI_USE_NAMESPACE
 DWIDGET_BEGIN_NAMESPACE
 
 #define DAPPLICATION_XSTRING(s) DAPPLICATION_STRING(s)
@@ -44,6 +46,7 @@ class LIBDTKWIDGETSHARED_EXPORT DApplication : public QApplication, public DTK_C
     Q_PROPERTY(bool visibleMenuShortcutText READ visibleMenuShortcutText WRITE setVisibleMenuShortcutText)
     Q_PROPERTY(bool visibleMenuCheckboxWidget READ visibleMenuCheckboxWidget WRITE setVisibleMenuCheckboxWidget)
     Q_PROPERTY(bool visibleMenuIcon READ visibleMenuIcon WRITE setVisibleMenuIcon)
+    Q_PROPERTY(bool autoActivateWindows READ autoActivateWindows WRITE setAutoActivateWindows)
 
 public:
     DApplication(int &argc, char **argv);
@@ -53,21 +56,20 @@ public:
         SystemScope
     };
 
-    QString theme() const;
-    void setTheme(const QString &theme);
+    D_DECL_DEPRECATED QString theme() const;
+    D_DECL_DEPRECATED void setTheme(const QString &theme);
 
 #ifdef Q_OS_UNIX
     void setOOMScoreAdj(const int score);
 #endif
 
     bool setSingleInstance(const QString &key);
-
     bool setSingleInstance(const QString &key, SingleScope singleScope);
 
     bool loadTranslator(QList<QLocale> localeFallback = QList<QLocale>() << QLocale::system());
 
     //! warning: Must call before QGuiApplication defined object
-    static bool loadDXcbPlugin();
+    D_DECL_DEPRECATED static bool loadDXcbPlugin();
     static bool isDXcbPlatform();
 
     // return the libdtkwidget version of build application
@@ -78,12 +80,15 @@ public:
     // let startdde know that we've already started.
     static void registerDDESession();
 
+    static void customQtThemeConfigPathByUserHome(const QString &home);
+    static void customQtThemeConfigPath(const QString &path);
+    static QString customizedQtThemeConfigPath();
+
     // meta information that necessary to create a about dialog for the application.
     QString productName() const;
     void setProductName(const QString &productName);
 
     const QIcon &productIcon() const;
-    void D_DECL_DEPRECATED_X("Use void setProductIcon(const QIcon &productIcon).")setProductIcon(const QPixmap &productIconPixmap);
     void setProductIcon(const QIcon &productIcon);
 
     QString applicationLicense() const;
@@ -113,6 +118,9 @@ public:
     bool visibleMenuIcon() const;
     void setVisibleMenuIcon(bool value);
 
+    bool autoActivateWindows() const;
+    void setAutoActivateWindows(bool autoActivateWindows);
+
 #ifdef VERSION
     static inline QString buildVersion(const QString &fallbackVersion)
     {
@@ -134,17 +142,22 @@ Q_SIGNALS:
 
     //###(zccrs): Depend the Qt platform theme plugin(from the package: dde-qt5integration)
     void iconThemeChanged();
+    //###(zccrs): Emit form the Qt platform theme plugin(from the package: dde-qt5integration)
+    void screenDevicePixelRatioChanged(QScreen *screen);
 
 protected:
     virtual void handleHelpAction();
     virtual void handleAboutAction();
     virtual void handleQuitAction();
 
+public:
     bool notify(QObject *obj, QEvent *event) Q_DECL_OVERRIDE;
 
 private:
     friend class DTitlebarPrivate;
     friend class DMainWindowPrivate;
+
+    D_PRIVATE_SLOT(void _q_onNewInstanceStarted())
 };
 
 class DtkBuildVersion {
