@@ -2,7 +2,7 @@
  * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -25,18 +25,22 @@ DWIDGET_BEGIN_NAMESPACE
 ArrowHeaderLine::ArrowHeaderLine(QWidget *parent) :
     DHeaderLine(parent)
 {
-    m_arrowButton = new DArrowButton(this);
-    connect(m_arrowButton, &DArrowButton::mouseRelease, this, &ArrowHeaderLine::mousePress);
+    m_arrowButton = new DIconButton(DStyle::SP_ReduceElement, this);
+    m_arrowButton->setFlat(true);
+    setExpand(false);
+    connect(m_arrowButton, &DIconButton::clicked, this, &ArrowHeaderLine::mousePress);
     setContent(m_arrowButton);
     setFixedHeight(EXPAND_HEADER_HEIGHT);
 }
 
 void ArrowHeaderLine::setExpand(bool value)
 {
-    if (value)
-        m_arrowButton->setArrowDirection(DArrowButton::ArrowUp);
-    else
-        m_arrowButton->setArrowDirection(DArrowButton::ArrowDown);
+    if (value) {
+        m_arrowButton->setIcon(DStyle::SP_ExpandElement);
+    } else {
+        m_arrowButton->setIcon(DStyle::SP_ReduceElement);
+    }
+    m_isExpanded = value;
 }
 
 void ArrowHeaderLine::mousePressEvent(QMouseEvent *)
@@ -44,12 +48,15 @@ void ArrowHeaderLine::mousePressEvent(QMouseEvent *)
     Q_EMIT mousePress();
 }
 
+void ArrowHeaderLine::mouseMoveEvent(QMouseEvent *event)
+{
+    //屏蔽掉鼠标移动事件
+    event->accept();
+}
+
 void ArrowHeaderLine::reverseArrowDirection()
 {
-    if (m_arrowButton->arrowDirection() == DArrowButton::ArrowUp)
-        m_arrowButton->setArrowDirection(DArrowButton::ArrowDown);
-    else
-        m_arrowButton->setArrowDirection(DArrowButton::ArrowUp);
+    setExpand(!m_isExpanded);
 }
 
 /**
