@@ -2,7 +2,7 @@
  * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -19,6 +19,9 @@
 #include "dplatformwindowhandle.h"
 #include "dapplication.h"
 #include "private/darrowrectangle_p.h"
+#include "dstyle.h"
+
+#include <DGuiApplicationHelper>
 
 #ifdef Q_OS_LINUX
 #include <X11/extensions/shape.h>
@@ -308,6 +311,12 @@ bool DArrowRectangle::event(QEvent *e)
 {
     switch (e->type()) {
     case QEvent::WindowDeactivate:  Q_EMIT windowDeactivate();    break;
+    case QEvent::Polish: {
+        D_D(DArrowRectangle);
+        if (d->m_radius < 0)
+            d->m_radius = DStyleHelper(style()).pixelMetric(DStyle::PM_TopLevelWindowRadius);
+        break;
+    }
     default:;
     }
 
@@ -357,6 +366,26 @@ void DArrowRectangle::setShadowYOffset(const qreal &shadowYOffset)
     }
 }
 
+/*!
+ * \~chinese \brief DArrowRectangle::setLeftRightRadius 设置左右箭头时的圆角
+ */
+void DArrowRectangle::setLeftRightRadius(bool enable)
+{
+    D_D(DArrowRectangle);
+    d->leftRightRadius = enable;
+}
+
+/*!
+ * \~chinese \brief DArrowRectangle::setArrowStyleEnable 设置圆角箭头样式
+ */
+void DArrowRectangle::setRadiusArrowStyleEnable(bool enable)
+{
+    D_D(DArrowRectangle);
+    d->radiusArrowStyleEnable = enable;
+    setArrowWidth(40);
+    setArrowHeight(24);
+}
+
 /*!
  * \~english \property DArrowRectangle::shadowXOffset
  * \~english \brief the offset of the widget and its shadow on x axis.
@@ -804,24 +833,64 @@ QPainterPath DArrowRectanglePrivate::getLeftCornerPath()
     QPoint topRight(rect.x() + rect.width(), rect.y());
     QPoint bottomRight(rect.x() + rect.width(), rect.y() + rect.height());
     QPoint bottomLeft(rect.x() + m_arrowHeight, rect.y() + rect.height());
-    int radius =  m_radius > (rect.height() / 2) ? (rect.height() / 2) : m_radius;
+    int radius = m_radius > (rect.height() / 2) ? (rect.height() / 2) : m_radius;
+    int arrowWidth = m_arrowWidth - m_arrowHeight;
+    int widgetRadius = rect.height() > 4 * radius ? 2 * radius : radius;
     if (!radiusEnabled()) {
         radius = 0;
     }
 
     QPainterPath border;
-    border.moveTo(topLeft.x() + radius, topLeft.y());
+    border.moveTo(topLeft.x() + arrowWidth, topLeft.y());
     border.lineTo(topRight.x() - radius, topRight.y());
     border.arcTo(topRight.x() - 2 * radius, topRight.y(), 2 * radius, 2 * radius, 90, -90);
     border.lineTo(bottomRight.x(), bottomRight.y() - radius);
     border.arcTo(bottomRight.x() - 2 * radius, bottomRight.y() - 2 * radius, 2 * radius, 2 * radius, 0, -90);
-    border.lineTo(bottomLeft.x() + radius, bottomLeft.y());
-    border.arcTo(bottomLeft.x(), bottomLeft.y() - 2 * radius, 2 * radius, 2 * radius, -90, -90);
-    border.lineTo(cornerPoint.x() + m_arrowHeight, cornerPoint.y() + m_arrowWidth / 2);
-    border.lineTo(cornerPoint);
-    border.lineTo(cornerPoint.x() + m_arrowHeight, cornerPoint.y() - m_arrowWidth / 2);
-    border.lineTo(topLeft.x(), topLeft.y() + radius);
-    border.arcTo(topLeft.x(), topLeft.y(), 2 * radius, 2 * radius, -180, -90);
+
+    if (radiusArrowStyleEnable) {
+        border.lineTo(bottomLeft.x() + arrowWidth, bottomLeft.y());
+        border.arcTo(bottomLeft.x(), bottomLeft.y() - widgetRadius, widgetRadius, widgetRadius, -90, -90);
+        border.lineTo(bottomLeft.x(), cornerPoint.y() + m_arrowWidth / 2 + radius / 2);
+
+        border.cubicTo(QPointF(bottomLeft.x(), cornerPoint.y() + m_arrowWidth / 2 + radius / 2),
+                       QPointF(bottomLeft.x(), cornerPoint.y() + m_arrowWidth / 2),
+                       QPointF(cornerPoint.x() + m_arrowHeight / 2, cornerPoint.y() + m_arrowWidth / 4.5));
+
+        border.cubicTo(QPointF(cornerPoint.x() + m_arrowHeight / 2, cornerPoint.y() + m_arrowWidth / 4.5),
+                       QPointF(cornerPoint),
+                       QPointF(cornerPoint.x() + m_arrowHeight / 2, cornerPoint.y() - m_arrowWidth / 4.5));
+
+        border.cubicTo(QPointF(cornerPoint.x() + m_arrowHeight / 2, cornerPoint.y() - m_arrowWidth / 4.5),
+                       QPointF(cornerPoint.x() + m_arrowHeight, cornerPoint.y() - m_arrowWidth / 2),
+                       QPointF(topLeft.x(), cornerPoint.y() - m_arrowWidth / 2 - radius / 2));
+
+        border.lineTo(topLeft.x(), cornerPoint.y() - m_arrowWidth / 2 - radius / 2);
+        border.arcTo(topLeft.x(), topLeft.y(), widgetRadius, widgetRadius, -180, -90);
+    } else {
+        if (leftRightRadius) {
+            border.lineTo(bottomLeft.x() + arrowWidth, bottomLeft.y());
+            border.arcTo(bottomLeft.x(), bottomLeft.y() - widgetRadius, widgetRadius, widgetRadius, -90, -90);
+            border.lineTo(bottomLeft.x(), cornerPoint.y() + m_arrowWidth / 2);
+        } else {
+            border.lineTo(bottomLeft.x(), bottomLeft.y());
+
+            if (cornerPoint.y() > m_arrowWidth)
+                border.lineTo(bottomLeft.x(), cornerPoint.y() + m_arrowWidth / 2);
+        }
+
+        border.lineTo(cornerPoint);
+
+        if (leftRightRadius) {
+            border.lineTo(topLeft.x(), cornerPoint.y() - m_arrowWidth / 2);
+            border.lineTo(topLeft.x(), topLeft.y() + radius);
+            border.arcTo(topLeft.x(), topLeft.y(), widgetRadius, widgetRadius, -180, -90);
+        } else {
+            if (cornerPoint.y() > m_arrowWidth)
+                border.lineTo(topLeft.x(), cornerPoint.y() - m_arrowWidth / 2);
+
+            border.lineTo(topLeft.x(), topLeft.y());
+        }
+    }
 
     return border;
 }
@@ -844,19 +913,61 @@ QPainterPath DArrowRectanglePrivate::getRightCornerPath()
     QPoint bottomRight(rect.x() + rect.width() - m_arrowHeight, rect.y() + rect.height());
     QPoint bottomLeft(rect.x(), rect.y() + rect.height());
     int radius = this->m_radius > (rect.height() / 2) ? rect.height() / 2 : this->m_radius;
+    int widgetRadius = rect.height() >= 4 * radius ? 2 * radius : radius;
+
     if (!radiusEnabled()) {
         radius = 0;
     }
 
     QPainterPath border;
-    border.moveTo(topLeft.x() + radius, topLeft.y());
-    border.lineTo(topRight.x() - radius, topRight.y());
-    border.arcTo(topRight.x() - 2 * radius, topRight.y(), 2 * radius, 2 * radius, 90, -90);
-    border.lineTo(cornerPoint.x() - m_arrowHeight, cornerPoint.y() - m_arrowWidth / 2);
-    border.lineTo(cornerPoint);
-    border.lineTo(cornerPoint.x() - m_arrowHeight, cornerPoint.y() + m_arrowWidth / 2);
-    border.lineTo(bottomRight.x(), bottomRight.y() - radius);
-    border.arcTo(bottomRight.x() - 2 * radius, bottomRight.y() - 2 * radius, 2 * radius, 2 * radius, 0, -90);
+    border.moveTo(topLeft.x(), topLeft.y());
+
+    if (radiusArrowStyleEnable) {
+        border.lineTo(topRight.x() - radius, topRight.y());
+        border.arcTo(topRight.x() - widgetRadius, topRight.y(), widgetRadius, widgetRadius, 90, -90);
+        border.lineTo(topRight.x(), cornerPoint.y() - m_arrowWidth / 2 - radius / 2);
+
+        border.cubicTo(QPointF(topRight.x(), cornerPoint.y() - m_arrowWidth / 2 - radius / 2),
+                       QPointF(topRight.x(), cornerPoint.y() - m_arrowWidth / 2),
+                       QPointF(cornerPoint.x() - m_arrowHeight / 2, cornerPoint.y() - m_arrowWidth / 4.5));
+
+        border.cubicTo(QPointF(cornerPoint.x() - m_arrowHeight / 2, cornerPoint.y() - m_arrowWidth / 4.5),
+                       QPointF(cornerPoint),
+                       QPointF(cornerPoint.x() - m_arrowHeight / 2, cornerPoint.y() + m_arrowWidth / 4.5));
+
+        border.cubicTo(QPointF(cornerPoint.x() - m_arrowHeight / 2, cornerPoint.y() + m_arrowWidth / 4.5),
+                       QPointF(bottomRight.x(), cornerPoint.y() + m_arrowWidth / 2),
+                       QPointF(bottomRight.x(), cornerPoint.y() + m_arrowWidth / 2 + radius / 2));
+
+        border.lineTo(bottomRight.x(), cornerPoint.y() + m_arrowWidth / 2 + radius / 2);
+        border.arcTo(bottomRight.x() - widgetRadius, bottomRight.y() - widgetRadius, widgetRadius, widgetRadius, 0, -90);
+    } else {
+        if (leftRightRadius) {
+            border.lineTo(topRight.x() - radius, topRight.y());
+            border.arcTo(topRight.x() - widgetRadius, topRight.y(), widgetRadius, widgetRadius, 90, -90);
+            border.lineTo(topRight.x(), cornerPoint.y() - m_arrowWidth / 2);
+        } else {
+            border.lineTo(topRight.x(), topRight.y());
+
+            if (cornerPoint.y() > m_arrowWidth)
+                border.lineTo(topRight.x(), cornerPoint.y() - m_arrowWidth / 2);
+        }
+
+        border.lineTo(cornerPoint);
+
+        if (leftRightRadius) {
+            border.lineTo(bottomRight.x(), cornerPoint.y() + m_arrowWidth / 2);
+            border.lineTo(bottomRight.x(), bottomRight.y() - radius);
+            border.arcTo(bottomRight.x() - widgetRadius, bottomRight.y() - widgetRadius, widgetRadius, widgetRadius, 0, -90);
+
+        } else if (!leftRightRadius){
+            if (cornerPoint.y() > m_arrowWidth)
+                border.lineTo(bottomRight.x(), cornerPoint.y() + m_arrowWidth / 2);
+
+            border.lineTo(bottomRight.x(), bottomRight.y());
+        }
+    }
+
     border.lineTo(bottomLeft.x() + radius, bottomLeft.y());
     border.arcTo(bottomLeft.x(), bottomLeft.y() - 2 * radius, 2 * radius, 2 * radius, -90, -90);
     border.lineTo(topLeft.x(), topLeft.y() + radius);
@@ -888,9 +999,27 @@ QPainterPath DArrowRectanglePrivate::getTopCornerPath()
 
     QPainterPath border;
     border.moveTo(topLeft.x() + radius, topLeft.y());
-    border.lineTo(cornerPoint.x() - m_arrowWidth / 2, cornerPoint.y() + m_arrowHeight);
-    border.lineTo(cornerPoint);
-    border.lineTo(cornerPoint.x() + m_arrowWidth / 2, cornerPoint.y() + m_arrowHeight);
+
+    if (radiusArrowStyleEnable) {
+        border.lineTo(cornerPoint.x() - m_arrowWidth / 2 - radius / 2, cornerPoint.y() + m_arrowHeight);
+        border.cubicTo(QPointF(cornerPoint.x() - m_arrowWidth / 2 - radius / 2, topLeft.y()),
+                       QPointF(cornerPoint.x() - m_arrowWidth / 2, topLeft.y()),
+                       QPointF(cornerPoint.x() - m_arrowWidth / 4.5, cornerPoint.y() + m_arrowHeight / 2));
+
+        border.cubicTo(QPointF(cornerPoint.x() - m_arrowWidth / 4.5, cornerPoint.y() + m_arrowHeight / 2),
+                       QPointF(cornerPoint),
+                       QPointF(cornerPoint.x() + m_arrowWidth / 4.5, cornerPoint.y() + m_arrowHeight / 2));
+
+        border.cubicTo(QPointF(cornerPoint.x() + m_arrowWidth / 4.5, cornerPoint.y() + m_arrowHeight / 2),
+                       QPointF(cornerPoint.x() + m_arrowWidth / 2, topLeft.y()),
+                       QPointF(cornerPoint.x() + m_arrowWidth / 2 + radius / 2, cornerPoint.y() + m_arrowHeight));
+        border.lineTo(cornerPoint.x() + m_arrowWidth / 2 + radius / 2, cornerPoint.y() + m_arrowHeight);
+    } else {
+        border.lineTo(cornerPoint.x() - m_arrowWidth / 2, cornerPoint.y() + m_arrowHeight);
+        border.lineTo(cornerPoint);
+        border.lineTo(cornerPoint.x() + m_arrowWidth / 2, cornerPoint.y() + m_arrowHeight);
+    }
+
     border.lineTo(topRight.x() - radius, topRight.y());
     border.arcTo(topRight.x() - 2 * radius, topRight.y(), 2 * radius, 2 * radius, 90, -90);
     border.lineTo(bottomRight.x(), bottomRight.y() - radius);
@@ -912,10 +1041,10 @@ QPainterPath DArrowRectanglePrivate::getBottomCornerPath()
     if (!m_handle) {
         qreal delta = q->shadowBlurRadius() + m_shadowDistance;
 
-        rect = rect.marginsRemoved(QMargins(delta, delta, delta, (DArrowRectangle::FloatWidget == floatMode) ?  0 : delta));
+        rect = rect.marginsRemoved(QMargins(delta, delta, delta, (DArrowRectangle::FloatWidget == floatMode) ? 0 : delta));
     }
 
-    QPoint cornerPoint(rect.x() + (m_arrowX > 0 ? m_arrowX : qRound(double(rect.width()) / 2)), rect.y()  + rect.height());
+    QPoint cornerPoint(rect.x() + (m_arrowX > 0 ? m_arrowX : qRound(double(rect.width()) / 2)), rect.y() + rect.height());
     QPoint topLeft(rect.x(), rect.y());
     QPoint topRight(rect.x() + rect.width(), rect.y());
     QPoint bottomRight(rect.x() + rect.width(), rect.y() + rect.height() - m_arrowHeight);
@@ -931,9 +1060,29 @@ QPainterPath DArrowRectanglePrivate::getBottomCornerPath()
     border.arcTo(topRight.x() - 2 * radius, topRight.y(), 2 * radius, 2 * radius, 90, -90);
     border.lineTo(bottomRight.x(), bottomRight.y() - radius);
     border.arcTo(bottomRight.x() - 2 * radius, bottomRight.y() - 2 * radius, 2 * radius, 2 * radius, 0, -90);
-    border.lineTo(cornerPoint.x() + m_arrowWidth / 2, cornerPoint.y() - m_arrowHeight);
-    border.lineTo(cornerPoint);
-    border.lineTo(cornerPoint.x() - m_arrowWidth / 2, cornerPoint.y() - m_arrowHeight);
+
+    if (radiusArrowStyleEnable) {
+        border.lineTo(cornerPoint.x() + m_arrowWidth / 2 + radius / 2, cornerPoint.y() - m_arrowHeight);
+
+        border.cubicTo(QPointF(cornerPoint.x() + m_arrowWidth / 2 + radius / 2, cornerPoint.y() - m_arrowHeight),
+                       QPointF(cornerPoint.x() + m_arrowWidth / 2, bottomRight.y()),
+                       QPointF(cornerPoint.x() + m_arrowWidth / 4.5, cornerPoint.y() - m_arrowHeight / 2));
+
+        border.cubicTo(QPointF(cornerPoint.x() + m_arrowWidth / 4.5 , cornerPoint.y() - m_arrowHeight / 2),
+                       QPointF(cornerPoint),
+                       QPointF(cornerPoint.x() - m_arrowWidth / 4.5 , cornerPoint.y() - m_arrowHeight / 2));
+
+        border.cubicTo(QPointF(cornerPoint.x() - m_arrowWidth / 4.5 , cornerPoint.y() - m_arrowHeight / 2),
+                       QPointF(cornerPoint.x() - m_arrowWidth / 2, bottomLeft.y()),
+                       QPointF(cornerPoint.x() - m_arrowWidth / 2 - radius / 2, cornerPoint.y() - m_arrowHeight));
+
+        border.lineTo(cornerPoint.x() - m_arrowWidth / 2 - radius / 2, cornerPoint.y() - m_arrowHeight);
+    } else {
+        border.lineTo(cornerPoint.x() + m_arrowWidth / 2, cornerPoint.y() - m_arrowHeight);
+        border.lineTo(cornerPoint);
+        border.lineTo(cornerPoint.x() - m_arrowWidth / 2, cornerPoint.y() - m_arrowHeight);
+    }
+
     border.lineTo(bottomLeft.x() + radius, bottomLeft.y());
     border.arcTo(bottomLeft.x(), bottomLeft.y() - 2 * radius, 2 * radius, 2 * radius, -90, -90);
     border.lineTo(topLeft.x(), topLeft.y() + radius);
@@ -1057,11 +1206,13 @@ DArrowRectangle::~DArrowRectangle()
 }
 
 Dtk::Widget::DArrowRectanglePrivate::DArrowRectanglePrivate(DArrowRectangle::ArrowDirection direction, DArrowRectangle *q)
-    : DObjectPrivate(q),
-
-      m_arrowDirection(direction)
+    : DObjectPrivate(q)
+    , m_arrowDirection(direction)
 {
-
+    if (direction == DArrowRectangle::ArrowLeft || direction == DArrowRectangle::ArrowRight) {
+        m_arrowWidth = 16;
+        m_arrowHeight = 16;
+    }
 }
 
 void DArrowRectanglePrivate::init(DArrowRectangle::FloatMode mode)
@@ -1079,11 +1230,10 @@ void DArrowRectanglePrivate::init(DArrowRectangle::FloatMode mode)
     }
 
     if (DApplication::isDXcbPlatform() && (DArrowRectangle::FloatWindow == floatMode)) {
-        m_handle = new DPlatformWindowHandle(q);
+        m_handle = new DPlatformWindowHandle(q, q);
         m_handle->setTranslucentBackground(true);
 
         m_blurBackground = new DBlurEffectWidget(q);
-        m_blurBackground->setMaskColor(DBlurEffectWidget::DarkColor);
         m_blurBackground->setBlendMode(DBlurEffectWidget::BehindWindowBlend);
 
         m_wmHelper = DWindowManagerHelper::instance();
@@ -1170,7 +1320,7 @@ void DArrowRectanglePrivate::resizeWithContent()
 
 #ifdef Q_OS_LINUX
     const qreal ratio = qApp->devicePixelRatio();
-    if (!m_handle && !floatMode) {
+    if (!m_handle && !floatMode && DGUI_NAMESPACE::DGuiApplicationHelper::instance()->isXWindowPlatform()) {
         XRectangle m_contentXRect;
         m_contentXRect.x = m_content->pos().x() * ratio;
         m_contentXRect.y = m_content->pos().y() * ratio;
@@ -1191,10 +1341,18 @@ void DArrowRectanglePrivate::paintEvent(QPaintEvent *e)
         return;
     }
 
+    QColor bk_color;
+
+    if (!m_backgroundColor.isValid()) {
+        bk_color = qApp->palette().background().color();
+    } else {
+        bk_color = m_backgroundColor;
+    }
+
     QPainter painter(q);
 
     if (m_handle) {
-        painter.fillRect(e->rect(), m_backgroundColor);
+        painter.fillRect(e->rect(), bk_color);
     } else {
         painter.setRenderHint(QPainter::Antialiasing);
 
@@ -1218,7 +1376,7 @@ void DArrowRectanglePrivate::paintEvent(QPaintEvent *e)
         }
 
         painter.setClipPath(border);
-        painter.fillPath(border, QBrush(m_backgroundColor));
+        painter.fillPath(border, QBrush(bk_color));
 
         QPen strokePen;
         strokePen.setColor(m_borderColor);
