@@ -2,7 +2,7 @@
  * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -58,9 +58,9 @@ public:
         FloatWidget,
     };
 
-    explicit DArrowRectangle(ArrowDirection direction, QWidget *parent = 0);
-    explicit DArrowRectangle(ArrowDirection direction, FloatMode floatMode, QWidget *parent = 0);
-    ~DArrowRectangle();
+    explicit DArrowRectangle(ArrowDirection direction, QWidget *parent = nullptr);
+    explicit DArrowRectangle(ArrowDirection direction, FloatMode floatMode, QWidget *parent = nullptr);
+    ~DArrowRectangle() override;
 
     Q_PROPERTY(QColor backgroundColor READ backgroundColor WRITE setBackgroundColor)
     Q_PROPERTY(QColor borderColor READ borderColor WRITE setBorderColor)
@@ -71,8 +71,6 @@ public:
     Q_PROPERTY(int arrowX READ arrowX WRITE setArrowX)
     Q_PROPERTY(int arrowY READ arrowY WRITE setArrowY)
     Q_PROPERTY(int margin READ margin WRITE setMargin)
-    Q_PROPERTY(QColor borderColor READ borderColor WRITE setBorderColor)
-    Q_PROPERTY(QColor backgroundColor READ backgroundColor WRITE setBackgroundColor)
     Q_PROPERTY(ArrowDirection arrowDirection READ arrowDirection WRITE setArrowDirection)
     Q_PROPERTY(qreal shadowXOffset READ shadowXOffset WRITE setShadowXOffset)
     Q_PROPERTY(qreal shadowYOffset READ shadowYOffset WRITE setShadowYOffset)
@@ -119,6 +117,9 @@ public:
     void setShadowXOffset(const qreal &shadowXOffset);
     void setShadowYOffset(const qreal &shadowYOffset);
 
+    void setLeftRightRadius(bool enable);
+    void setRadiusArrowStyleEnable(bool enable);
+
 Q_SIGNALS:
     void windowDeactivate() const;
 
