@@ -2,7 +2,7 @@
  * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,14 +11,16 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "dblureffectwidget.h"
 #include "private/dblureffectwidget_p.h"
 #include "dplatformwindowhandle.h"
-#include "util/dwindowmanagerhelper.h"
+
+#include <DWindowManagerHelper>
+#include <DGuiApplicationHelper>
 
 #include <QPainter>
 #include <QBackingStore>
@@ -26,6 +28,20 @@
 #include <QDebug>
 
 #include <qpa/qplatformbackingstore.h>
+#include <private/qwidget_p.h>
+#ifndef slots
+#define slots Q_SLOTS
+#endif
+
+#define private public
+
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+#include <private/qwidgetrepaintmanager_p.h>
+#else
+#include <private/qwidgetbackingstore_p.h>
+#endif
+
+#undef private
 
 #define MASK_COLOR_ALPHA_DEFAULT 204
 
@@ -33,6 +49,8 @@ QT_BEGIN_NAMESPACE
 Q_WIDGETS_EXPORT void qt_blurImage(QPainter *p, QImage &blurImage, qreal radius, bool quality, bool alphaOnly, int transposed = 0);
 QT_END_NAMESPACE
 
+DGUI_USE_NAMESPACE
+
 DWIDGET_BEGIN_NAMESPACE
 
 QMultiHash<QWidget *, const DBlurEffectWidget *> DBlurEffectWidgetPrivate::blurEffectWidgetHash;
@@ -56,7 +74,7 @@ bool DBlurEffectWidgetPrivate::isFull() const
 {
     D_QC(DBlurEffectWidget);
 
-    return full || (q->isTopLevel() && !(blurRectXRadius * blurRectYRadius) && maskPath.isEmpty());
+    return full || (q->isTopLevel() && !(blurRectXRadius && blurRectYRadius) && maskPath.isEmpty());
 }
 
 void DBlurEffectWidgetPrivate::addToBlurEffectWidgetHash()
@@ -108,12 +126,52 @@ void DBlurEffectWidgetPrivate::setMaskAlpha(const quint8 alpha) {
     setMaskColor(maskColor);
 }
 
+quint8 DBlurEffectWidgetPrivate::getMaskColorAlpha() const
+{
+    if (maskAlpha < 0)
+        return isBehindWindowBlendMode() ? 102 : 204;
+
+    return static_cast<quint8>(maskAlpha);
+}
+
+QColor DBlurEffectWidgetPrivate::getMaskColor(const QColor &baseColor) const
+{
+    QColor color = baseColor;
+    DGuiApplicationHelper::ColorType ct = DGuiApplicationHelper::toColorType(color);
+
+    if (DGuiApplicationHelper::DarkType == ct) {
+        color = DGuiApplicationHelper::adjustColor(color, 0, 0, -10, 0, 0, 0, 0);
+    } else {
+        color = DGuiApplicationHelper::adjustColor(color, 0, 0, -5, 0, 0, 0, 0);
+    }
+
+    int maskAlpha = this->getMaskColorAlpha();
+
+    if (!isBehindWindowBlendMode() || DWindowManagerHelper::instance()->hasComposite()) {
+        color.setAlpha(maskAlpha);
+    } else {
+        return ct == DGuiApplicationHelper::DarkType ? "#202020" : "#D2D2D2";
+    }
+
+    return color;
+}
+
+void DBlurEffectWidgetPrivate::resetSourceImage()
+{
+    // 设置了自定义的image时忽略此请求
+    // 属于某个组时也忽略
+    if (customSourceImage || group)
+        return;
+
+    sourceImage = QImage();
+}
+
 void DBlurEffectWidgetPrivate::setMaskColor(const QColor &color)
 {
     maskColor = color;
 
     if (isBehindWindowBlendMode()) {
-        maskColor.setAlpha(DWindowManagerHelper::instance()->hasBlurWindow() ? maskAlpha : MASK_COLOR_ALPHA_DEFAULT);
+        maskColor.setAlpha(DWindowManagerHelper::instance()->hasComposite() ? getMaskColorAlpha() : MASK_COLOR_ALPHA_DEFAULT);
     }
 
     D_Q(DBlurEffectWidget);
@@ -241,7 +299,7 @@ bool DBlurEffectWidgetPrivate::updateWindowBlurArea(QWidget *topLevelWidget)
  * \~chinese \class DBlurEffectWidget
  * \~chinese \brief 用于实现主窗口或控件背景的实时模糊效果。
  *
- * \~chinese 分为主窗口模糊 DBlurEffectWidget::BehindWindowBlend 和控件模糊 DBlurEffectWidget::InWindowBlend
+ * \~chinese 分为主窗口模糊 DBlurEffectWidget::BehindWindowBlend 和控件模糊 DBlurEffectWidget::InWindowBlend DBlurEffectWidget::InWindowBlend
  * \~chinese 这两种不同的模式，主窗口模糊效果依赖于窗口管理器的实现，目前仅支持 deepin-wm 和 kwin，
  * \~chinese 可以使用DWindowManagerHelper::hasBlurWindow 判断当前运行环境中的窗口管理器是否支持
  * \~chinese 模糊特效，使用 DPlatformWindowHandle::setWindowBlurAreaByWM 设置主窗口背景的模糊
@@ -314,7 +372,7 @@ bool DBlurEffectWidgetPrivate::updateWindowBlurArea(QWidget *topLevelWidget)
  * \~chinese 属性的情况下，无论 full 属性的值为多少，都将和值为 true 时的行为保持一致。
  * \~chinese \note 可读可写
  * \~chinese \note 此属性不影响蒙版的绘制区域
- * \~chinese \note 只在模糊的混合模式为 BehindWindowBlend 时生效
+ * \~chinese \note 只在模糊的混合模式为 BehindWindowBlend 或 DBlurEffectWidget::InWindowBlend 时生效
  * \~chinese \see DBlurEffectWidget::blurRectXRadius BlurEffectWidget::blurRectYRadius
  * \~chinese \see DBlurEffectWidget::maskColor
  * \~chinese \see DBlurEffectWidget::blendMode
@@ -361,14 +419,19 @@ bool DBlurEffectWidgetPrivate::updateWindowBlurArea(QWidget *topLevelWidget)
  *
  * \~chinese \var DBlurEffectWidget::BehindWindowBlend DBlurEffectWidget::BehindWindowBlend
  * \~chinese 以外部的其它窗口作为模糊背景
+ *
+ * * \~chinese \var DBlurEffectWidget::InWidgetBlend DBlurEffectWidget::InWidgetBlend
+ * \~chinese 同 DBlurEffectWidget::InWindowBlend，区别是不会自动更新用于模糊的源图片
+ * \~chinese 可手动调用 DBlurEffectWidget::updateBlurSourceImage 更新，以此来实现自行控制模糊
+ * \~chinese 源图片的更新时机
  */
 
 /*!
  * \~chinese \enum DBlurEffectWidget::MaskColorType
  * \~chinese DBlurEffectWidget::MaskColorType 内置的几种颜色模式。分为三种情况：
  * \~chinese \arg \c A：模式为 DBlurEffectWidget::InWindowBlend 或当前窗口管理器支持混成且支持窗口背景模糊
- * \~chinese \arg \c B：模式为 DBlurEffectWidget::BehindWindowBlend 窗口管理器不支持混成
- * \~chinese \arg \c C：模式为 DBlurEffectWidget::BehindWindowBlend 窗口管理器不支持模糊
+ * \~chinese \arg \c B：模式为 DBlurEffectWidget::BehindWindowBlend 或 DBlurEffectWidget::InWindowBlend 窗口管理器不支持混成
+ * \~chinese \arg \c C：模式为 DBlurEffectWidget::BehindWindowBlend 或 DBlurEffectWidget::InWindowBlend 窗口管理器不支持模糊
  * \~chinese \see DBlurEffectWidget::maskAlpha
  *
  * \~chinese \var DBlurEffectWidget::DarkColor DBlurEffectWidget::DarkColor
@@ -384,6 +447,9 @@ bool DBlurEffectWidgetPrivate::updateWindowBlurArea(QWidget *topLevelWidget)
  * \~chinese \arg \c B：\color{#FCFCFC,#FCFCFC}
  * \~chinese \arg \c C：\color{rgba(255\,255\,255\,0.8),#CCFFFFFF}
  *
+ * \~chinese \var DBlurEffectWidget::AutoColor DBlurEffectWidget::AutoColor
+ * \~chinese 自动颜色，以当前应用的主题的背景色作为叠加色（alpha通道值为非定值）
+ *
  * \~chinese \var DBlurEffectWidget::CustomColor DBlurEffectWidget::CustomColor
  * \~chinese 自定义颜色，使用 DBlurEffectWidget::setMaskColor 设置的颜色
  */
@@ -402,6 +468,7 @@ DBlurEffectWidget::DBlurEffectWidget(QWidget *parent)
     , DObject(*new DBlurEffectWidgetPrivate(this))
 {
     setAttribute(Qt::WA_TranslucentBackground);
+    setBackgroundRole(QPalette::Window);
 
     if (!parent) {
         D_D(DBlurEffectWidget);
@@ -434,6 +501,11 @@ DBlurEffectWidget::~DBlurEffectWidget()
     if (d->isBehindWindowBlendMode()) {
         d->removeFromBlurEffectWidgetHash();
     }
+
+    // clean group
+    if (d->group) {
+        d->group->removeWidget(this);
+    }
 }
 
 /*!
@@ -452,7 +524,7 @@ int DBlurEffectWidget::radius() const
 
 /*!
  * \~english \property DBlurEffectWidget::mode
- * \~english \brief This property holds which blur alghorithm to be used.
+ * \~english \brief This property holds which blur algorithm to be used.
  *
  * \~english Currently it only supports DBlurEffectWidget::GaussianBlur.
  */
@@ -520,27 +592,14 @@ QColor DBlurEffectWidget::maskColor() const
     D_DC(DBlurEffectWidget);
 
     switch ((int)d->maskColorType) {
-    case DarkColor: {
-        if (!d->isBehindWindowBlendMode()) {
-            return QColor(0, 0, 0, d->maskAlpha);
-        }
+    case DarkColor:
+        return d->getMaskColor(DGuiApplicationHelper::standardPalette(DGuiApplicationHelper::DarkType).window().color());
+    case LightColor:
+        return d->getMaskColor(DGuiApplicationHelper::standardPalette(DGuiApplicationHelper::LightType).window().color());
+    case AutoColor: {
+        QColor color = palette().color(backgroundRole());
 
-        if (DWindowManagerHelper::instance()->hasComposite()) {
-            return QColor(0, 0, 0, DWindowManagerHelper::instance()->hasBlurWindow() ? d->maskAlpha : MASK_COLOR_ALPHA_DEFAULT);
-        } else {
-            return QColor("#373F47");
-        }
-    }
-    case LightColor: {
-        if (!d->isBehindWindowBlendMode()) {
-            return QColor(255, 255, 255, d->maskAlpha);
-        }
-
-        if (DWindowManagerHelper::instance()->hasComposite()) {
-            return QColor(255, 255, 255, DWindowManagerHelper::instance()->hasBlurWindow() ? d->maskAlpha : MASK_COLOR_ALPHA_DEFAULT);
-        } else {
-            return QColor("#FCFCFC");
-        }
+        return d->getMaskColor(color);
     }
     }
 
@@ -550,7 +609,7 @@ QColor DBlurEffectWidget::maskColor() const
 quint8 DBlurEffectWidget::maskAlpha() const {
     D_DC(DBlurEffectWidget);
 
-    return d->maskAlpha;
+    return d->getMaskColorAlpha();
 }
 
 /*!
@@ -576,6 +635,32 @@ void DBlurEffectWidget::setMaskPath(const QPainterPath &path)
     update();
 }
 
+/*!
+ * \~chinese \brief DBlurEffectWidget::setSourceImage
+ * \~chinese \param image
+ * \~chinese \param autoScale
+ * \~chinese \warning
+ * \~chinese \see
+ */
+void DBlurEffectWidget::setSourceImage(const QImage &image, bool autoScale)
+{
+    D_D(DBlurEffectWidget);
+
+    d->sourceImage = image;
+    d->customSourceImage = !image.isNull();
+    d->autoScaleSourceImage = autoScale && d->customSourceImage;
+
+    if (autoScale && isVisible()) {
+        d->sourceImage.setDevicePixelRatio(devicePixelRatioF());
+        d->sourceImage = d->sourceImage.scaled((size() + QSize(d->radius * 1, d->radius * 2)) * devicePixelRatioF());
+        d->sourceImage.setDevicePixelRatio(devicePixelRatioF());
+    }
+}
+
+/*!
+ * \~chinese \brief DBlurEffectWidget::isFull
+ * \~chinese \return　true 窗口占据了整个模糊区域,反之为false
+ */
 bool DBlurEffectWidget::isFull() const
 {
     D_DC(DBlurEffectWidget);
@@ -583,6 +668,10 @@ bool DBlurEffectWidget::isFull() const
     return d->full;
 }
 
+/*!
+ * \~chinese \brief DBlurEffectWidget::blurEnabled
+ * \~chinese \return true 模糊区域可伸缩调整
+ */
 bool DBlurEffectWidget::blurEnabled() const
 {
     D_DC(DBlurEffectWidget);
@@ -590,6 +679,10 @@ bool DBlurEffectWidget::blurEnabled() const
     return d->blurEnabled;
 }
 
+/*!
+ * \~chinese \brief DBlurEffectWidget::setRadius
+ * \~chinese \param radius　模糊区域的圆角大小　如果设定值和原值不一致会发送信号radiusChanged
+ */
 void DBlurEffectWidget::setRadius(int radius)
 {
     D_D(DBlurEffectWidget);
@@ -599,13 +692,17 @@ void DBlurEffectWidget::setRadius(int radius)
     }
 
     d->radius = radius;
-    d->sourceImage = QImage();
+    d->resetSourceImage();
 
     update();
 
     Q_EMIT radiusChanged(radius);
 }
 
+/*!
+ * \~chinese \brief DBlurEffectWidget::setMode
+ * \~chinese \param mode 设定模糊算法,默认为高斯模糊算法GaussianBlur
+ */
 void DBlurEffectWidget::setMode(DBlurEffectWidget::BlurMode mode)
 {
     D_D(DBlurEffectWidget);
@@ -619,6 +716,10 @@ void DBlurEffectWidget::setMode(DBlurEffectWidget::BlurMode mode)
     Q_EMIT modeChanged(mode);
 }
 
+/*!
+ * \~chinese \brief DBlurEffectWidget::setBlendMode
+ * \~chinese \param blendMode 窗口混合模式，模式设定变化发送blendModeChanged信号
+ */
 void DBlurEffectWidget::setBlendMode(DBlurEffectWidget::BlendMode blendMode)
 {
     D_D(DBlurEffectWidget);
@@ -629,23 +730,35 @@ void DBlurEffectWidget::setBlendMode(DBlurEffectWidget::BlendMode blendMode)
 
     if (blendMode == BehindWindowBlend) {
         d->addToBlurEffectWidgetHash();
+
+        // 移除针对顶层窗口的事件过滤器
+        topLevelWidget()->removeEventFilter(this);
     } else {
-        if (blendMode == InWindowBlend) {
-            d->maskColor.setAlpha(d->maskAlpha);
+        if (blendMode != BehindWindowBlend) {
+            d->maskColor.setAlpha(d->getMaskColorAlpha());
         }
 
         if (d->blendMode == BehindWindowBlend) {
             d->removeFromBlurEffectWidgetHash();
         }
+
+        if (isVisible()) {
+            // 给顶层窗口添加事件过滤器
+            topLevelWidget()->installEventFilter(this);
+        }
     }
 
+    // 前面还有用到 d->blendMode 读取上一次的值
     d->blendMode = blendMode;
-
     update();
 
     Q_EMIT blendModeChanged(blendMode);
 }
 
+/*!
+ * \~chinese \brief DBlurEffectWidget::setBlurRectXRadius
+ * \~chinese \param blurRectXRadius 模糊区域矩形的X圆角大小
+ */
 void DBlurEffectWidget::setBlurRectXRadius(int blurRectXRadius)
 {
     D_D(DBlurEffectWidget);
@@ -661,6 +774,10 @@ void DBlurEffectWidget::setBlurRectXRadius(int blurRectXRadius)
     Q_EMIT blurRectXRadiusChanged(blurRectXRadius);
 }
 
+/*!
+ * \~chinese \brief DBlurEffectWidget::setBlurRectYRadius
+ * \~chinese \param blurRectYRadius 模糊区域矩形的Y圆角大小
+ */
 void DBlurEffectWidget::setBlurRectYRadius(int blurRectYRadius)
 {
     D_D(DBlurEffectWidget);
@@ -676,6 +793,10 @@ void DBlurEffectWidget::setBlurRectYRadius(int blurRectYRadius)
     Q_EMIT blurRectYRadiusChanged(blurRectYRadius);
 }
 
+/*!
+ * \~chinese \brief DBlurEffectWidget::setMaskAlpha
+ * \~chinese \param alpha　设置Alpha通道,值变化发送maskAlphaChanged信号
+ */
 void DBlurEffectWidget::setMaskAlpha(quint8 alpha) {
     D_D(DBlurEffectWidget);
 
@@ -686,6 +807,10 @@ void DBlurEffectWidget::setMaskAlpha(quint8 alpha) {
     Q_EMIT maskAlphaChanged(alpha);
 }
 
+/*!
+ * \~chinese \brief DBlurEffectWidget::setMaskColor
+ * \~chinese \param maskColor 设定mask的颜色
+ */
 void DBlurEffectWidget::setMaskColor(QColor maskColor)
 {
     D_D(DBlurEffectWidget);
@@ -721,6 +846,10 @@ void DBlurEffectWidget::setMaskColor(DBlurEffectWidget::MaskColorType type)
     update();
 }
 
+/*!
+ * \~chinese \brief DBlurEffectWidget::setFull
+ * \~chinese \param full 设置时候模糊区域占满整个窗口大小
+ */
 void DBlurEffectWidget::setFull(bool full)
 {
     D_D(DBlurEffectWidget);
@@ -734,6 +863,10 @@ void DBlurEffectWidget::setFull(bool full)
     Q_EMIT fullChanged(full);
 }
 
+/*!
+ * \~chinese \brief DBlurEffectWidget::setBlurEnabled
+ * \~chinese \param blurEnabled 设定模糊区域是否可以伸缩
+ */
 void DBlurEffectWidget::setBlurEnabled(bool blurEnabled)
 {
     D_D(DBlurEffectWidget);
@@ -748,6 +881,55 @@ void DBlurEffectWidget::setBlurEnabled(bool blurEnabled)
     Q_EMIT blurEnabledChanged(d->blurEnabled);
 }
 
+inline QRect operator *(const QRect &rect, qreal scale)
+{
+    return QRect(rect.left() * scale, rect.top() * scale, rect.width() * scale, rect.height() * scale);
+}
+
+/*!
+ * \~chinese \brief DBlurEffectWidget::updateBlurSourceImage
+ * \~chinese \param ren 设定模糊区域的背景图片
+ */
+void DBlurEffectWidget::updateBlurSourceImage(const QRegion &ren)
+{
+    D_D(DBlurEffectWidget);
+
+    // 自定义模式，或者属于某个组时不需要以下操作
+    if (d->customSourceImage || d->group)
+        return;
+
+    const qreal device_pixel_ratio = devicePixelRatioF();
+    const QPoint point_offset = mapTo(window(), QPoint(0, 0));
+
+    if (d->sourceImage.isNull()) {
+        const QRect &tmp_rect = rect().translated(point_offset).adjusted(-d->radius, -d->radius, d->radius, d->radius);
+
+        d->sourceImage = window()->backingStore()->handle()->toImage().copy(tmp_rect * device_pixel_ratio);
+        d->sourceImage = d->sourceImage.scaledToWidth(d->sourceImage.width() / device_pixel_ratio);
+    } else {
+        QPainter pa_image(&d->sourceImage);
+
+        pa_image.setCompositionMode(QPainter::CompositionMode_Source);
+
+        if (device_pixel_ratio > 1) {
+            const QRect &tmp_rect = this->rect().translated(point_offset);
+            QImage area = window()->backingStore()->handle()->toImage().copy(tmp_rect * device_pixel_ratio);
+            area = area.scaledToWidth(area.width() / device_pixel_ratio);
+
+            for (const QRect &rect : ren.rects()) {
+                pa_image.drawImage(rect.topLeft() + QPoint(d->radius, d->radius), rect == area.rect() ? area : area.copy(rect));
+            }
+        } else {
+            for (const QRect &rect : ren.rects()) {
+                pa_image.drawImage(rect.topLeft() + QPoint(d->radius, d->radius),
+                                   window()->backingStore()->handle()->toImage().copy(rect.translated(point_offset)));
+            }
+        }
+
+        pa_image.end();
+    }
+}
+
 DBlurEffectWidget::DBlurEffectWidget(DBlurEffectWidgetPrivate &dd, QWidget *parent)
     : QWidget(parent)
     , DObject(dd)
@@ -755,11 +937,6 @@ DBlurEffectWidget::DBlurEffectWidget(DBlurEffectWidgetPrivate &dd, QWidget *pare
 
 }
 
-inline QRect operator *(const QRect &rect, qreal scale)
-{
-    return QRect(rect.left() * scale, rect.top() * scale, rect.width() * scale, rect.height() * scale);
-}
-
 void DBlurEffectWidget::paintEvent(QPaintEvent *event)
 {
     D_D(DBlurEffectWidget);
@@ -792,42 +969,33 @@ void DBlurEffectWidget::paintEvent(QPaintEvent *event)
     if (d->isBehindWindowBlendMode()) {
         pa.setCompositionMode(QPainter::CompositionMode_Source);
     } else {
-        int radius = d->radius;
-        QPoint point_offset = mapTo(window(), QPoint(0, 0));
-        const QRect &paintRect = event->rect();
-        qreal device_pixel_ratio = devicePixelRatioF();
-
-        if (d->sourceImage.isNull()) {
-            const QRect &tmp_rect = rect().translated(point_offset).adjusted(-radius, -radius, radius, radius);
-
-            d->sourceImage = window()->backingStore()->handle()->toImage().copy(tmp_rect * device_pixel_ratio);
-            d->sourceImage = d->sourceImage.scaledToWidth(d->sourceImage.width() / device_pixel_ratio);
-        } else {
-            QPainter pa_image(&d->sourceImage);
-
-            pa_image.setCompositionMode(QPainter::CompositionMode_Source);
-
-            for (const QRect &rect : event->region().rects()) {
-                if (device_pixel_ratio > 1) {
-                    const QRect &tmp_rect = this->rect().translated(point_offset);
-                    const QImage &area = window()->backingStore()->handle()->toImage().copy(tmp_rect * device_pixel_ratio);
-
-                    pa_image.drawImage(rect.topLeft() + QPoint(radius, radius), area.scaledToWidth(area.width() / device_pixel_ratio).copy(rect));
-                } else {
-                    pa_image.drawImage(rect.topLeft() + QPoint(radius, radius),
-                                       window()->backingStore()->handle()->toImage().copy(rect.translated(point_offset)));
-                }
-            }
-
-            pa_image.end();
+        // 此模式下是自行控制sourceImage的更新
+        if (d->blendMode != InWidgetBlend) {
+            updateBlurSourceImage(event->region());
         }
 
-        QImage image = d->sourceImage.copy(paintRect.adjusted(0, 0, 2 * radius, 2 * radius));
+        if (d->customSourceImage || !d->sourceImage.isNull()) {
+            int radius = d->radius;
+            qreal device_pixel_ratio = devicePixelRatioF();
+            QImage image;
+            const QRect &paintRect = event->rect();
 
-        QTransform old_transform = pa.transform();
-        pa.translate(paintRect.topLeft() - QPoint(radius, radius));
-        qt_blurImage(&pa, image, radius, false, false);
-        pa.setTransform(old_transform);
+            if (d->customSourceImage) {
+                image = d->sourceImage.copy(paintRect.adjusted(0, 0, 2 * radius, 2 * radius) * device_pixel_ratio);
+                image.setDevicePixelRatio(device_pixel_ratio);
+                pa.setOpacity(0.2);
+            } else {// 非customSourceImage不考虑缩放产生的影响
+                image = d->sourceImage.copy(paintRect.adjusted(0, 0, 2 * radius, 2 * radius));
+            }
+
+            QTransform old_transform = pa.transform();
+            pa.translate(paintRect.topLeft() - QPoint(radius, radius));
+            qt_blurImage(&pa, image, radius, false, false);
+            pa.setTransform(old_transform);
+            pa.setOpacity(1);
+        } else if (d->group) { // 组模式
+            d->group->paint(&pa, this);
+        }
     }
 
     pa.fillRect(rect(), maskColor());
@@ -841,8 +1009,9 @@ void DBlurEffectWidget::moveEvent(QMoveEvent *event)
         return QWidget::moveEvent(event);
     }
 
-    if (d->blendMode == DBlurEffectWidget::InWindowBlend) {
-        d->sourceImage = QImage();
+    if (d->blendMode == DBlurEffectWidget::InWindowBlend
+            || d->blendMode == DBlurEffectWidget::InWindowBlend) {
+        d->resetSourceImage();
 
         return QWidget::moveEvent(event);
     }
@@ -856,9 +1025,14 @@ void DBlurEffectWidget::resizeEvent(QResizeEvent *event)
 {
     D_D(DBlurEffectWidget);
 
-    d->sourceImage = QImage();
+    d->resetSourceImage();
 
     if (!d->isBehindWindowBlendMode()) {
+        if (d->autoScaleSourceImage) {
+            d->sourceImage = d->sourceImage.scaled((size() + QSize(d->radius * 1, d->radius * 2)) * devicePixelRatioF());
+            d->sourceImage.setDevicePixelRatio(devicePixelRatioF());
+        }
+
         return QWidget::resizeEvent(event);
     }
 
@@ -872,6 +1046,14 @@ void DBlurEffectWidget::showEvent(QShowEvent *event)
     D_D(DBlurEffectWidget);
 
     if (!d->isBehindWindowBlendMode()) {
+        if (d->autoScaleSourceImage) {
+            d->sourceImage = d->sourceImage.scaled((size() + QSize(d->radius * 1, d->radius * 2)) * devicePixelRatioF());
+            d->sourceImage.setDevicePixelRatio(devicePixelRatioF());
+        }
+
+        // 给顶层窗口添加事件过滤器
+        topLevelWidget()->installEventFilter(this);
+
         return QWidget::showEvent(event);
     }
 
@@ -885,6 +1067,9 @@ void DBlurEffectWidget::hideEvent(QHideEvent *event)
     D_D(DBlurEffectWidget);
 
     if (!d->isBehindWindowBlendMode()) {
+        // 移除事件过滤器
+        topLevelWidget()->removeEventFilter(this);
+
         return QWidget::hideEvent(event);
     }
 
@@ -910,4 +1095,145 @@ void DBlurEffectWidget::changeEvent(QEvent *event)
     QWidget::changeEvent(event);
 }
 
+bool DBlurEffectWidget::eventFilter(QObject *watched, QEvent *event)
+{
+    if (event->type() != QEvent::UpdateRequest) {
+        return QWidget::eventFilter(watched, event);
+    }
+
+    // 截获顶层窗口的绘制请求事件，判断需要重绘的区域是否在模糊半径内
+    // 是的话则重绘模糊控件，因为避免由于DBlurEffectWidget控件外部（但是在模糊半径内，所以需要将此区域的内容计算到模糊）的重绘
+    if (QWidget *widget = qobject_cast<QWidget*>(watched)) {
+        auto wd = QWidgetPrivate::get(widget);
+
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+        if (!wd->maybeRepaintManager()) {
+#else
+        if (!wd->maybeBackingStore()) {
+#endif
+            return QWidget::eventFilter(watched, event);
+        }
+
+        // 当前待绘制的区域
+        QRegion dirty;
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+        for (const QWidget *w : wd->maybeRepaintManager()->dirtyWidgets) {
+#else
+        for (const QWidget *w : wd->maybeBackingStore()->dirtyWidgets) {
+#endif
+            dirty |= QWidgetPrivate::get(w)->dirty.translated(w->mapToGlobal(QPoint(0, 0)));
+        }
+
+        if (dirty.isEmpty()) {
+            return QWidget::eventFilter(watched, event);
+        }
+
+        D_D(DBlurEffectWidget);
+        const QPoint &offset = mapToGlobal(QPoint(0, 0));
+        const QRect frame_rect = rect() + QMargins(d->radius, d->radius, d->radius, d->radius);
+        QRegion radius_edge = QRegion(frame_rect) - QRegion(rect());
+
+        // 如果更新内容区域包含控件外围的区域（主要时radius半径下的区域），应当更新模糊绘制
+        if (!(dirty & radius_edge.translated(offset)).isEmpty()) {
+            // 此区域已经脏了，应当重置source image
+            d->resetSourceImage();
+
+            if (d->blendMode == InWidgetBlend)
+                Q_EMIT blurSourceImageDirtied();
+            else
+                update();
+        }
+    }
+
+    return QWidget::eventFilter(watched, event);
+}
+
+class DBlurEffectGroupPrivate : public DTK_CORE_NAMESPACE::DObjectPrivate
+{
+public:
+    DBlurEffectGroupPrivate(DBlurEffectGroup *qq)
+        : DObjectPrivate(qq)
+    {
+
+    }
+
+    D_DECLARE_PUBLIC(DBlurEffectGroup)
+    QHash<DBlurEffectWidget*, QPoint> effectWidgetMap;
+    QPixmap blurPixmap;
+};
+
+DBlurEffectGroup::DBlurEffectGroup()
+    : DObject(*new DBlurEffectGroupPrivate(this))
+{
+
+}
+
+DBlurEffectGroup::~DBlurEffectGroup()
+{
+    D_DC(DBlurEffectGroup);
+
+    for (DBlurEffectWidget *widget : d->effectWidgetMap.keys()) {
+        widget->d_func()->group = nullptr;
+        widget->update();
+    }
+}
+
+void DBlurEffectGroup::setSourceImage(QImage image, int blurRadius)
+{
+    D_D(DBlurEffectGroup);
+
+    if (image.isNull()) {
+        d->blurPixmap = QPixmap();
+        return;
+    }
+
+
+    if (blurRadius > 0) {
+        QImage tmp(image.size(), image.format());
+        QPainter pa(&tmp);
+        qt_blurImage(&pa, image, blurRadius, false, false);
+        pa.end();
+        d->blurPixmap = QPixmap::fromImage(tmp);
+    } else {
+        d->blurPixmap = QPixmap::fromImage(image);
+    }
+
+    d->blurPixmap.setDevicePixelRatio(image.devicePixelRatio());
+
+    // 重绘制模糊控件
+    for (auto begin = d->effectWidgetMap.constBegin(); begin != d->effectWidgetMap.constEnd(); ++begin) {
+        begin.key()->update();
+    }
+}
+
+void DBlurEffectGroup::addWidget(DBlurEffectWidget *widget, const QPoint &offset)
+{
+    if (widget->d_func()->group && widget->d_func()->group != this) {
+        widget->d_func()->group->removeWidget(widget);
+    }
+
+    widget->d_func()->group = this;
+    D_D(DBlurEffectGroup);
+    d->effectWidgetMap[widget] = offset;
+
+    widget->update();
+}
+
+void DBlurEffectGroup::removeWidget(DBlurEffectWidget *widget)
+{
+    D_D(DBlurEffectGroup);
+
+    if (d->effectWidgetMap.remove(widget)) {
+        widget->d_func()->group = nullptr;
+        widget->update();
+    }
+}
+
+void DBlurEffectGroup::paint(QPainter *pa, DBlurEffectWidget *widget) const
+{
+    D_DC(DBlurEffectGroup);
+
+    pa->drawPixmap(widget->rect(), d->blurPixmap, widget->geometry().translated(d->effectWidgetMap[widget]));
+}
+
 DWIDGET_END_NAMESPACE
