@@ -2,7 +2,7 @@
  * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,10 +11,12 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <DHorizontalLine>
+
 #include <QPushButton>
 #include <QLabel>
 #include <QButtonGroup>
@@ -25,46 +27,24 @@
 #include <QDesktopWidget>
 #include <QScreen>
 #include <QAction>
-#include <QRegExp>
 #include <QRegularExpression>
-
-#include <QStyle>
-#include <QStyleFactory>
+#include <DFontSizeManager>
 
 #include "private/ddialog_p.h"
 
-#include "dimagebutton.h"
+#include "ddialogclosebutton.h"
 #include "dialog_constants.h"
 #include "ddialog.h"
-#include "dthememanager.h"
 #include "dboxwidget.h"
 #include "DAnchors"
+#include "dtitlebar.h"
+#include "dwarningbutton.h"
+#include "dsuggestbutton.h"
 
 DWIDGET_BEGIN_NAMESPACE
 
-DialogButton::DialogButton(const QString &text, QWidget *parent)
-    :QPushButton(text, parent)
-{
-
-}
-
-int DialogButton::buttonType() const
-{
-    return m_buttonType;
-}
-
-void DialogButton::setButtonType(int buttonType)
-{
-    if (m_buttonType == buttonType)
-        return;
-
-    m_buttonType = buttonType;
-    Q_EMIT buttonTypeChanged(buttonType);
-}
-
 DDialogPrivate::DDialogPrivate(DDialog *qq) :
-    DAbstractDialogPrivate(qq),
-    fixedStyle(Q_NULLPTR)
+    DAbstractDialogPrivate(qq)
 {
 
 }
@@ -74,90 +54,83 @@ QBoxLayout *DDialogPrivate::getContentLayout()
     return contentLayout;
 }
 
+static void palrtteTransparency(QWidget *widget, qint8 alphaFloat)
+{
+    QPalette palette = widget->palette();
+    QColor color = DGuiApplicationHelper::adjustColor(palette.color(QPalette::Active, QPalette::BrightText), 0, 0, 0, 0, 0, 0, alphaFloat);
+    palette.setColor(QPalette::WindowText, color);
+    widget->setPalette(palette);
+}
+
 void DDialogPrivate::init()
 {
     D_Q(DDialog);
 
-    // TopLayout
-    topLayout = new QHBoxLayout;
-    topLayout->setContentsMargins(DIALOG::ICON_LAYOUT_LEFT_MARGIN,
-                                  DIALOG::ICON_LAYOUT_TOP_MARGIN,
-                                  DIALOG::ICON_LAYOUT_RIGHT_MARGIN,
-                                  DIALOG::ICON_LAYOUT_BOTTOM_MARGIN);
-    topLayout->setSpacing(DIALOG::ICON_LAYOUT_SPACING);
-
-
-    // TopLayout--Icon
-    iconLabel = new QLabel;
-    iconLabel->hide();
-    iconLabel->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
-
-    topLayout->addWidget(iconLabel);
-
     // TopLayout--TextLabel
     titleLabel = new QLabel;
     titleLabel->setObjectName("TitleLabel");
-    titleLabel->hide();
     titleLabel->setAttribute(Qt::WA_TransparentForMouseEvents);
+    titleLabel->setWordWrap(true);
+    titleLabel->setAlignment(Qt::AlignCenter);
+    titleLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
+    DFontSizeManager *fontManager =  DFontSizeManager::instance();
+    fontManager->bind(titleLabel, DFontSizeManager::T5, QFont::Medium);
+    palrtteTransparency(titleLabel, -10);
+    titleLabel->hide();
 
     messageLabel = new QLabel;
+    fontManager->bind(messageLabel, DFontSizeManager::T6, QFont::Medium);
     messageLabel->setObjectName("MessageLabel");
-    messageLabel->hide();
     messageLabel->setAttribute(Qt::WA_TransparentForMouseEvents);
+    messageLabel->setWordWrap(true);
+    messageLabel->setAlignment(Qt::AlignCenter);
+    messageLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    palrtteTransparency(messageLabel, -30);
+    messageLabel->hide();
 
     QVBoxLayout *textLayout = new QVBoxLayout;
     textLayout->setContentsMargins(0, 0, 0, 0);
     textLayout->setSpacing(5);
-    textLayout->addStretch();
-    textLayout->addWidget(titleLabel, 0, Qt::AlignLeft);
-    textLayout->addWidget(messageLabel, 0, Qt::AlignLeft);
-    textLayout->addStretch();
+    textLayout->addWidget(titleLabel);
+    textLayout->addWidget(messageLabel, 0, Qt::AlignTop);
 
     // TopLayout--ContentLayout
     contentLayout = new QVBoxLayout;
-    contentLayout->setContentsMargins(0, 0, 0, 0);
+    contentLayout->setContentsMargins(10, 0, 10, 0);
     contentLayout->setSpacing(0);
     contentLayout->addLayout(textLayout);
 
-    topLayout->addLayout(contentLayout);
+    titleBar = new DTitlebar();
+    titleBar->setIcon(icon); //设置标题icon
+    titleBar->setMenuVisible(false);
+    titleBar->setBackgroundTransparent(true);
+    titleBar->setTitle(q->windowTitle());
 
-    // TopLayout--Close button
-    closeButton = new DImageButton(q);
-    closeButton->setObjectName("CloseButton");
-    closeButton->adjustSize();
-//    closeButton->setFixedSize(DIALOG::CLOSE_BUTTON_WIDTH, DIALOG::CLOSE_BUTTON_HEIGHT);
-    closeButton->setAttribute(Qt::WA_NoMousePropagation);
-
-    DAnchorsBase::setAnchor(closeButton, Qt::AnchorRight, q, Qt::AnchorRight);
+    QObject::connect(q, &DDialog::windowTitleChanged, titleBar, &DTitlebar::setTitle);
 
     QVBoxLayout *mainLayout = new QVBoxLayout;
-    mainLayout->setContentsMargins(0, 0, 0, 0);
-    mainLayout->setSpacing(0);
+    spacer = new QSpacerItem(1, 0);
 
     // MainLayout--TopLayout
-    mainLayout->addLayout(topLayout);
+    mainLayout->addWidget(titleBar);
+    mainLayout->addLayout(contentLayout);
+    mainLayout->setContentsMargins(QMargins(0, 0, 0, 0));
 
     // MainLayout--ButtonLayout
     buttonLayout = new QHBoxLayout;
     buttonLayout->setMargin(0);
-    buttonLayout->setSpacing(0);
     buttonLayout->setContentsMargins(DIALOG::BUTTON_LAYOUT_LEFT_MARGIN,
                                      DIALOG::BUTTON_LAYOUT_TOP_MARGIN,
                                      DIALOG::BUTTON_LAYOUT_RIGHT_MARGIN,
                                      DIALOG::BUTTON_LAYOUT_BOTTOM_MARGIN);
+    mainLayout->addSpacerItem(spacer);
     mainLayout->addLayout(buttonLayout);
 
-
-    QAction *button_action = new QAction(q);
-
-    button_action->setShortcuts(QKeySequence::InsertParagraphSeparator);
-    button_action->setAutoRepeat(false);
-
-    QObject::connect(closeButton, SIGNAL(clicked()), q, SLOT(close()));
-    QObject::connect(button_action, SIGNAL(triggered(bool)), q, SLOT(_q_defaultButtonTriggered()));
-
+    QObject::connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, q, [this]() {
+        palrtteTransparency(titleLabel, -10);
+        palrtteTransparency(messageLabel, -30);
+    });
     q->setLayout(mainLayout);
-    q->addAction(button_action);
     q->setFocusPolicy(Qt::ClickFocus);
     q->setFocus();
 }
@@ -168,7 +141,7 @@ const QScreen *DDialogPrivate::getScreen() const
 
     const QScreen *screen = qApp->screens()[qApp->desktop()->screenNumber(q)];
 
-    if(screen)
+    if (screen)
         return screen;
 
     screen = qApp->screens()[qApp->desktop()->screenNumber(QCursor::pos())];
@@ -203,23 +176,23 @@ QString DDialogPrivate::elideString(QString str, const QFontMetrics &fm, int wid
 {
     QString trimmed = trimTag(str);
     if (fm.width(trimmed) > width) {
-         QMap<int, QString> info = scanTags(str);
-         QString elided = fm.elidedText(trimmed, Qt::ElideMiddle, width);
-         int elideStart = elided.indexOf("…");
-         int elideLength = trimmed.length() - elided.length();
-         QList<int> indexes = info.keys();
-         std::sort(indexes.begin(), indexes.end());
-         for (int index : indexes) {
-             if (index <= elideStart) {
-                 elided.insert(index, info[index]);
-             } else if (elideStart < index && index <= elideStart + elideLength) {
-                 elided.insert(elideStart, info[index]);
-                 elideStart += 1;
-             } else {
-                 elided.insert(index - elideLength + 1, info[index]);
-             }
-         }
-         return elided;
+        QMap<int, QString> info = scanTags(str);
+        QString elided = fm.elidedText(trimmed, Qt::ElideMiddle, width);
+        int elideStart = elided.indexOf("…");
+        int elideLength = trimmed.length() - elided.length();
+        QList<int> indexes = info.keys();
+        std::sort(indexes.begin(), indexes.end());
+        for (int index : indexes) {
+            if (index <= elideStart) {
+                elided.insert(index, info[index]);
+            } else if (elideStart < index && index <= elideStart + elideLength) {
+                elided.insert(elideStart, info[index]);
+                elideStart += 1;
+            } else {
+                elided.insert(index - elideLength + 1, info[index]);
+            }
+        }
+        return elided;
     } else {
         return str;
     }
@@ -240,17 +213,22 @@ void DDialogPrivate::updateSize()
     }
 }
 
+void DDialogPrivate::setSpacer(int height)
+{
+    spacer->changeSize(1, height);
+}
+
 void DDialogPrivate::_q_onButtonClicked()
 {
     D_Q(DDialog);
 
-    QAbstractButton *button = qobject_cast<QAbstractButton*>(q->sender());
+    QAbstractButton *button = qobject_cast<QAbstractButton *>(q->sender());
 
-    if(button) {
+    if (button) {
         clickedButtonIndex = buttonList.indexOf(button);
         q->buttonClicked(clickedButtonIndex, button->text());
 
-        if(onButtonClickedClose)
+        if (onButtonClickedClose)
             q->done(clickedButtonIndex);
     }
 }
@@ -259,7 +237,7 @@ void DDialogPrivate::_q_defaultButtonTriggered()
 {
     D_QC(DDialog);
 
-    QAbstractButton *button = qobject_cast<QAbstractButton*>(q->focusWidget());
+    QAbstractButton *button = qobject_cast<QAbstractButton *>(q->focusWidget());
 
     if (button)
         button->click();
@@ -311,8 +289,6 @@ void DDialogPrivate::_q_defaultButtonTriggered()
 DDialog::DDialog(QWidget *parent) :
     DAbstractDialog(*new DDialogPrivate(this), parent)
 {
-    DThemeManager::registerWidget(this);
-
     d_func()->init();
 }
 
@@ -326,8 +302,6 @@ DDialog::DDialog(QWidget *parent) :
 DDialog::DDialog(const QString &title, const QString &message, QWidget *parent) :
     DAbstractDialog(*new DDialogPrivate(this), parent)
 {
-    DThemeManager::registerWidget(this);
-
     d_func()->init();
 
     setTitle(title);
@@ -345,10 +319,10 @@ int DDialog::getButtonIndexByText(const QString &text) const
 {
     int i = -1;
 
-    for(const QAbstractButton *button : getButtons()) {
+    for (const QAbstractButton *button : getButtons()) {
         ++i;
 
-        if(button->text() == text)
+        if (button->text() == text)
             return i;
     }
 
@@ -378,7 +352,7 @@ int DDialog::contentCount() const
 /*!
  * \~chinese \brief 获得对话框的按钮列表
  */
-QList<QAbstractButton*> DDialog::getButtons() const
+QList<QAbstractButton *> DDialog::getButtons() const
 {
     D_DC(DDialog);
 
@@ -408,6 +382,11 @@ QAbstractButton *DDialog::getButton(int index) const
     return d->buttonList.at(index);
 }
 
+/*!
+ * \~chinese \brief DDialog::getContent 获取指定下标对应的内容控件
+ * \~chinese \param index　控件下标
+ * \~chinese \return 返回对应的内容控件
+ */
 QWidget *DDialog::getContent(int index) const
 {
     D_DC(DDialog);
@@ -415,6 +394,10 @@ QWidget *DDialog::getContent(int index) const
     return d->contentList.at(index);
 }
 
+/*!
+ * \~chinese \brief DDialog::title
+ * \~chinese \return 返回对话框的标题内容
+ */
 QString DDialog::title() const
 {
     D_DC(DDialog);
@@ -422,6 +405,10 @@ QString DDialog::title() const
     return d->title;
 }
 
+/*!
+ * \~chinese \brief DDialog::message
+ * \~chinese \return 返回对话框的显示信息
+ */
 QString DDialog::message() const
 {
     D_DC(DDialog);
@@ -429,6 +416,10 @@ QString DDialog::message() const
     return d->message;
 }
 
+/*!
+ * \~chinese \brief DDialog::icon
+ * \~chinese \return  返回对话框的icon
+ */
 QIcon DDialog::icon() const
 {
     D_DC(DDialog);
@@ -436,13 +427,25 @@ QIcon DDialog::icon() const
     return d->icon;
 }
 
+/*!
+ * \~chinese \brief DDialog::iconPixmap
+ * \~chinese \return 返回ICON的pixmap
+ */
 QPixmap DDialog::iconPixmap() const
 {
     D_DC(DDialog);
 
-    return *d->iconLabel->pixmap();
+    if (d->icon.isNull())  {
+        return QPixmap();
+    } else {
+        return d->icon.pixmap(d->icon.availableSizes().at(0));
+    }
 }
 
+/*!
+ * \~chinese \brief DDialog::textFormat
+ * \~chinese \return 返回设定的文本格式
+ */
 Qt::TextFormat DDialog::textFormat() const
 {
     D_DC(DDialog);
@@ -460,18 +463,35 @@ bool DDialog::onButtonClickedClose() const
     return d->onButtonClickedClose;
 }
 
+/*!
+ * \~chinese \brief DDialog::setContentLayoutContentsMargins 设定内容布局的内容margin
+ * \~chinese \param margins 具体的margins
+ */
 void DDialog::setContentLayoutContentsMargins(const QMargins &margins)
 {
     D_D(DDialog);
 
-    d->topLayout->setContentsMargins(margins);
+    d->contentLayout->setContentsMargins(margins);
 }
 
+/*!
+ * \~chinese \brief DDialog::contentLayoutContentsMargins
+ * \~chinese \return 返回内容布局的内容margin
+ */
 QMargins DDialog::contentLayoutContentsMargins() const
 {
     D_DC(DDialog);
 
-    return d->topLayout->contentsMargins();
+    return d->contentLayout->contentsMargins();
+}
+
+/*!
+ * \~chinese \brief DDialog::closeButtonVisible
+ * \~chinese \return 返回关闭按钮是否可见的bool值
+ */
+bool DDialog::closeButtonVisible() const
+{
+    return windowFlags().testFlag(Qt::WindowCloseButtonHint);
 }
 
 /*!
@@ -518,11 +538,23 @@ int DDialog::addButtons(const QStringList &text)
  */
 void DDialog::insertButton(int index, const QString &text, bool isDefault, ButtonType type)
 {
-    DialogButton *button = new DialogButton(text);
+    QAbstractButton *button;
+
+    switch (type) {
+    case ButtonWarning:
+        button = new DWarningButton(this);
+        break;
+    case ButtonRecommend:
+        button = new DSuggestButton(this);
+        break;
+    default:
+        button = new QPushButton(this);
+        break;
+    }
+
+    button->setText(text);
     button->setObjectName("ActionButton");
-    button->setButtonType(type);
     button->setAttribute(Qt::WA_NoMousePropagation);
-    button->setFixedHeight(DIALOG::BUTTON_HEIGHT);
 
     insertButton(index, button, isDefault);
 }
@@ -538,20 +570,19 @@ void DDialog::insertButton(int index, QAbstractButton *button, bool isDefault)
 {
     D_D(DDialog);
 
-    QLabel* label = new QLabel;
-    label->setObjectName("VLine");
-    label->setFixedWidth(1);
-    label->hide();
+    DVerticalLine *line = new DVerticalLine;
+    line->setObjectName("VLine");
+    line->setFixedHeight(30);
 
-    if (index > 0 && index >= buttonCount()) {
-        QLabel *label = qobject_cast<QLabel*>(d->buttonLayout->itemAt(d->buttonLayout->count() - 1)->widget());
-        if(label)
-            label->show();
-    }
-
-    d->buttonLayout->insertWidget(index * 2, button);
+    d->buttonLayout->insertWidget(index * 2 , line);
+    d->buttonLayout->insertWidget(index * 2 + 1, button);
     d->buttonList << button;
-    d->buttonLayout->insertWidget(index * 2 + 1, label);
+    if (d->buttonList.count() == 1) {
+        int spacing = DStyleHelper(style()).pixelMetric(DStyle::PM_ContentsSpacing);
+        d->setSpacer(spacing);
+    }
+    line->show();
+    d->buttonLayout->itemAt(0)->widget()->hide();
 
     connect(button, SIGNAL(clicked(bool)), this, SLOT(_q_onButtonClicked()));
 
@@ -586,7 +617,7 @@ void DDialog::insertButton(int index, QAbstractButton *button, bool isDefault)
  */
 void DDialog::insertButtons(int index, const QStringList &text)
 {
-    for(int i = 0; i < text.count(); ++i) {
+    for (int i = 0; i < text.count(); ++i) {
         insertButton(index + i, text[i]);
     }
 }
@@ -600,27 +631,31 @@ void DDialog::removeButton(int index)
 {
     D_D(DDialog);
 
-    QLabel *label = qobject_cast<QLabel*>(d->buttonLayout->itemAt(index * 2 + 1)->widget());
-    QAbstractButton * button = qobject_cast<QAbstractButton*>(d->buttonLayout->itemAt(index * 2)->widget());
+    DVerticalLine *label = qobject_cast<DVerticalLine *>(d->buttonLayout->itemAt(index * 2 + 1)->widget());
+    QAbstractButton *button = qobject_cast<QAbstractButton *>(d->buttonLayout->itemAt(index * 2)->widget());
 
-    if(label) {
+    if (label) {
         d->buttonLayout->removeWidget(label);
         label->deleteLater();
     }
 
-    if(button) {
+    if (button) {
         d->buttonLayout->removeWidget(button);
         button->deleteLater();
     }
 
-    if(index > 0 && index == buttonCount() - 1) {
-        QLabel *label = qobject_cast<QLabel*>(d->buttonLayout->itemAt(d->buttonLayout->count() - 1)->widget());
+    if (index > 0 && index == buttonCount() - 1) {
+        DVerticalLine *label = qobject_cast<DVerticalLine *>(d->buttonLayout->itemAt(d->buttonLayout->count() - 1)->widget());
 
-        if(label)
+        if (label)
             label->hide();
     }
 
     d->buttonList.removeAt(index);
+
+    if (d->buttonList.isEmpty()) {
+        d->setSpacer(0);
+    }
 }
 
 /*!
@@ -642,7 +677,7 @@ void DDialog::removeButtonByText(const QString &text)
 {
     int index = getButtonIndexByText(text);
 
-    if(index >= 0)
+    if (index >= 0)
         removeButton(index);
 }
 
@@ -654,8 +689,9 @@ void DDialog::clearButtons()
     D_D(DDialog);
 
     d->buttonList.clear();
+    d->setSpacer(0);
 
-    while(d->buttonLayout->count()) {
+    while (d->buttonLayout->count()) {
         QLayoutItem *item = d->buttonLayout->takeAt(0);
 
         item->widget()->deleteLater();
@@ -672,7 +708,7 @@ void DDialog::clearButtons()
  */
 bool DDialog::setDefaultButton(int index)
 {
-    if(index < 0)
+    if (index < 0)
         return false;
 
     setDefaultButton(getButton(index));
@@ -733,7 +769,7 @@ void DDialog::insertContent(int index, QWidget *widget, Qt::Alignment alignment)
     D_D(DDialog);
 
     d->contentLayout->insertWidget(index + DIALOG::CONTENT_INSERT_OFFSET,
-                                         widget, 0, alignment);
+                                   widget, 0, alignment);
     d->contentList << widget;
 }
 
@@ -749,7 +785,7 @@ void DDialog::removeContent(QWidget *widget, bool isDelete)
 
     d->contentLayout->removeWidget(widget);
 
-    if(isDelete)
+    if (isDelete)
         widget->deleteLater();
 
     d->contentList.removeOne(widget);
@@ -764,10 +800,10 @@ void DDialog::clearContents(bool isDelete)
 {
     D_D(DDialog);
 
-    for(QWidget *widget : d->contentList)
+    for (QWidget *widget : d->contentList)
         d->contentLayout->removeWidget(widget);
 
-    if(isDelete) {
+    if (isDelete) {
         qDeleteAll(d->contentList);
     }
 
@@ -825,10 +861,10 @@ void DDialog::clearSpacing()
 {
     D_D(DDialog);
 
-    for(int i = 0; i < d->contentLayout->count(); ++i) {
+    for (int i = 0; i < d->contentLayout->count(); ++i) {
         QLayoutItem *item = d->contentLayout->itemAt(i);
 
-        if(item->spacerItem()) {
+        if (item->spacerItem()) {
             delete d->contentLayout->takeAt(i);
         }
     }
@@ -876,6 +912,16 @@ void DDialog::setTitle(const QString &title)
     Q_EMIT titleChanged(title);
 }
 
+/*!
+ * \~chinese \brief DDialog::setWordWrapTitle 设定标题Label内容是否可截断换行
+ * \~chinese \param wordWrap true可换行　false不可以换行
+ */
+void DDialog::setWordWrapTitle(bool wordWrap)
+{
+    D_D(DDialog);
+    d->titleLabel->setWordWrap(wordWrap);
+}
+
 /*!
  * \~chinese \brief 设置对话框消息内容
  */
@@ -893,11 +939,14 @@ void DDialog::setMessage(const QString &message)
     Q_EMIT messageChanged(message);
 }
 
+void DDialog::setWordWrapMessage(bool wordWrap)
+{
+    D_D(DDialog);
+    d->messageLabel->setWordWrap(wordWrap);
+}
+
 /*!
  * \~chinese \brief 设置对话框图标
- *
- * \~chinese 注意：该接口将会在未来版本中废弃，
- * 请使用 setIcon(const QIcon &icon, const QSize &expectedSize) 这个重载。
  */
 void DDialog::setIcon(const QIcon &icon)
 {
@@ -905,11 +954,8 @@ void DDialog::setIcon(const QIcon &icon)
 
     d->icon = icon;
 
-    if(!icon.isNull()) {
-        auto size = QSize(64, 64);
-        size = icon.availableSizes().value(0, size);
-        auto pixmap = icon.pixmap(size);
-        setIconPixmap(pixmap);
+    if (!icon.isNull()) {
+        d->titleBar->setIcon(d->icon);
     }
 }
 
@@ -938,14 +984,7 @@ void DDialog::setIcon(const QIcon &icon, const QSize &expectedSize)
  */
 void DDialog::setIconPixmap(const QPixmap &iconPixmap)
 {
-    D_D(DDialog);
-
-    d->iconLabel->setPixmap(iconPixmap);
-    if(iconPixmap.isNull()) {
-        d->iconLabel->hide();
-    } else {
-        d->iconLabel->show();
-    }
+    setIcon(QIcon(iconPixmap));
 }
 
 /*!
@@ -995,11 +1034,18 @@ int DDialog::exec()
     return d->clickedButtonIndex >= 0 ? d->clickedButtonIndex : code;
 }
 
+void DDialog::setCloseButtonVisible(bool closeButtonVisible)
+{
+    bool visible = isVisible();
+    // This function calls setParent() when changing the flags for a window, causing the widget to be hidden.
+    setWindowFlag(Qt::WindowCloseButtonHint, closeButtonVisible);
+    // So we need call show() or so to make the widget visible again.
+    this->setVisible(visible);
+}
+
 DDialog::DDialog(DDialogPrivate &dd, QWidget *parent) :
     DAbstractDialog(dd, parent)
 {
-    DThemeManager::registerWidget(this);
-
     d_func()->init();
 }
 
@@ -1043,62 +1089,24 @@ void DDialog::childEvent(QChildEvent *event)
     D_D(DDialog);
 
     if (event->added()) {
-        if (d->closeButton) {
-            d->closeButton->raise();
-        }
-
-        QStyle *style = d->fixedStyle;
-        if (!style) {
-            style = QStyleFactory::create("dlight");
-            if (style) {
-                d->fixedStyle = style;
-                style->setParent(this);
-            }
-        }
-
-
-        QWidget *child = qobject_cast<QWidget*>(event->child());
-        if (child) {
-            if (style) {
-                child->setStyle(style);
-            }
-
-            // TODO(hualet): apply the rule to all dwidgets.
-            // Just tried with no luck, DPsswordWidget's style goes wrong,
-            // no time to deal with this detail, leave it alone for now.
-            if (child->inherits("Dtk::Widget::DLineEdit")) {
-                DThemeManager *dtm = DThemeManager::instance();
-                // NOTE(sbw): want to force reset to light theme.
-                // FIXME(zccrs): fixation the DLineEdit widget theme to light.
-                dtm->setTheme(child, "light");
-            }
+        if (d->titleBar) {
+            d->titleBar->raise();
         }
     }
 }
 
 void DDialog::resizeEvent(QResizeEvent *event)
 {
-    DAbstractDialog::resizeEvent(event);
+    return DAbstractDialog::resizeEvent(event);
+}
 
+void DDialog::keyPressEvent(QKeyEvent *event)
+{
     D_D(DDialog);
-
-
-    d->titleLabel->setWordWrap(false);
-    int labelMaxWidth = maximumWidth() - d->closeButton->width() - d->titleLabel->x();
-
-    if (d->titleLabel->sizeHint().width() > labelMaxWidth) {
-        d->titleLabel->setFixedWidth(labelMaxWidth);
-        d->titleLabel->setWordWrap(true);
-        d->titleLabel->setFixedHeight(d->titleLabel->sizeHint().height());
-    }
-
-    d->messageLabel->setWordWrap(false);
-    labelMaxWidth = maximumWidth() - d->closeButton->width() - d->messageLabel->x();
-
-    if (d->messageLabel->sizeHint().width() > labelMaxWidth) {
-        d->messageLabel->setFixedWidth(labelMaxWidth);
-        d->messageLabel->setWordWrap(true);
-        d->messageLabel->setFixedHeight(d->messageLabel->sizeHint().height());
+    if (event->key() == Qt::Key_Enter || event->key() == Qt::Key_Return) {
+        d->_q_defaultButtonTriggered();
+    } else {
+        DAbstractDialog::keyPressEvent(event);
     }
 }
 
