@@ -2,7 +2,7 @@
  * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -38,9 +38,9 @@ class DDialog : public DAbstractDialog
     Q_PROPERTY(QString title READ title WRITE setTitle NOTIFY titleChanged)
     Q_PROPERTY(QString message READ message WRITE setMessage NOTIFY messageChanged)
     Q_PROPERTY(QIcon icon READ icon WRITE setIcon)
-    Q_PROPERTY(QPixmap iconPixmap READ iconPixmap WRITE setIconPixmap)
     Q_PROPERTY(Qt::TextFormat textFormat READ textFormat WRITE setTextFormat NOTIFY textFormatChanged)
     Q_PROPERTY(bool onButtonClickedClose READ onButtonClickedClose WRITE setOnButtonClickedClose)
+    Q_PROPERTY(bool closeButtonVisible READ closeButtonVisible WRITE setCloseButtonVisible)
 
 public:
     enum ButtonType {
@@ -49,7 +49,7 @@ public:
         ButtonRecommend
     };
 
-    explicit DDialog(QWidget *parent = 0);
+    explicit DDialog(QWidget *parent = nullptr);
     explicit DDialog(const QString &title, const QString& message, QWidget *parent = 0);
 
     int getButtonIndexByText(const QString &text) const;
@@ -62,13 +62,15 @@ public:
     QString title() const;
     QString message() const;
     QIcon icon() const;
-    QPixmap iconPixmap() const;
+    D_DECL_DEPRECATED QPixmap iconPixmap() const;
     Qt::TextFormat textFormat() const;
     bool onButtonClickedClose() const;
 
     void setContentLayoutContentsMargins(const QMargins &margins);
     QMargins contentLayoutContentsMargins() const;
 
+    bool closeButtonVisible() const;
+
 Q_SIGNALS:
     void aboutToClose();
     void closed();
@@ -92,8 +94,8 @@ public Q_SLOTS:
     bool setDefaultButton(int index);
     bool setDefaultButton(const QString &str);
     void setDefaultButton(QAbstractButton *button);
-    void addContent(QWidget *widget, Qt::Alignment alignment = 0);
-    void insertContent(int index, QWidget *widget, Qt::Alignment alignment = 0);
+    void addContent(QWidget *widget, Qt::Alignment alignment = {});
+    void insertContent(int index, QWidget *widget, Qt::Alignment alignment = {});
     void removeContent(QWidget *widget, bool isDelete = true);
     void clearContents(bool isDelete = true);
     void setSpacing(int spacing);
@@ -103,12 +105,15 @@ public Q_SLOTS:
     void setButtonText(int index, const QString &text);
     void setButtonIcon(int index, const QIcon &icon);
     void setTitle(const QString &title);
+    void setWordWrapTitle(bool wordWrap);
     void setMessage(const QString& message);
-    Q_DECL_DEPRECATED void setIcon(const QIcon &icon);
-    void setIcon(const QIcon &icon, const QSize &expectedSize);
-    void setIconPixmap(const QPixmap &iconPixmap);
+    void setWordWrapMessage(bool wordWrap);
+    void setIcon(const QIcon &icon);
+    D_DECL_DEPRECATED void setIcon(const QIcon &icon, const QSize &expectedSize);
+    D_DECL_DEPRECATED void setIconPixmap(const QPixmap &iconPixmap);
     void setTextFormat(Qt::TextFormat textFormat);
     void setOnButtonClickedClose(bool onButtonClickedClose);
+    void setCloseButtonVisible(bool closeButtonVisible);
 
     int exec() Q_DECL_OVERRIDE;
 
@@ -119,13 +124,13 @@ protected:
     void hideEvent(QHideEvent *event) Q_DECL_OVERRIDE;
     void closeEvent(QCloseEvent *event) override;
     void childEvent(QChildEvent *event) Q_DECL_OVERRIDE;
-    void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
+    void resizeEvent(QResizeEvent *event) override;
+    void keyPressEvent(QKeyEvent *event) override;
 
 private:
     D_DECLARE_PRIVATE(DDialog)
 
     Q_PRIVATE_SLOT(d_func(), void _q_onButtonClicked())
-    Q_PRIVATE_SLOT(d_func(), void _q_defaultButtonTriggered())
 };
 
 DWIDGET_END_NAMESPACE
