@@ -2,7 +2,7 @@
  * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,22 +11,21 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "dfilechooseredit.h"
-#include "dthememanager.h"
 #include "private/dfilechooseredit_p.h"
 
-#include <QDebug>
-#include <QFileDialog>
+#include <DStyleHelper>
+#include <DSuggestButton>
+
 #include <QScreen>
 #include <QGuiApplication>
 
 DWIDGET_BEGIN_NAMESPACE
 
-
 /*!
  * \~chinese \class DFileChooserEdit
  * \~chinese \brief 带有选择文件按钮的文本编辑框
@@ -76,7 +75,6 @@ DWIDGET_BEGIN_NAMESPACE
 DFileChooserEdit::DFileChooserEdit(QWidget *parent)
     : DLineEdit(*new DFileChooserEditPrivate(this), parent)
 {
-    DThemeManager::registerWidget(this);
     D_D(DFileChooserEdit);
 
     d->init();
@@ -109,6 +107,33 @@ void DFileChooserEdit::setDialogDisplayPosition(DFileChooserEdit::DialogDisplayP
     d->dialogDisplayPosition = dialogDisplayPosition;
 }
 
+void DFileChooserEdit::setFileDialog(QFileDialog *fileDialog)
+{
+    D_D(DFileChooserEdit);
+
+    d->dialog = fileDialog;
+}
+
+QFileDialog *DFileChooserEdit::fileDialog() const
+{
+    D_DC(DFileChooserEdit);
+
+    return d->dialog;
+}
+
+void DFileChooserEdit::initDialog()
+{
+    D_D(DFileChooserEdit);
+
+    if (d->dialog) {
+        return;
+    }
+
+    d->dialog = new QFileDialog(this);
+    d->dialog->setAcceptMode(QFileDialog::AcceptOpen);
+    d->dialog->setFileMode(QFileDialog::ExistingFile);
+}
+
 /*!
  * \~chinese \brief 设置文件选择模式
  * \~chinese \param mode 要使用的模式
@@ -117,7 +142,11 @@ void DFileChooserEdit::setDialogDisplayPosition(DFileChooserEdit::DialogDisplayP
 void DFileChooserEdit::setFileMode(QFileDialog::FileMode mode)
 {
     D_D(DFileChooserEdit);
-    d->fileMode = mode;
+
+    if (!d->dialog) {
+        initDialog();
+    }
+    d->dialog->setFileMode(mode);
 }
 
 /*!
@@ -131,7 +160,11 @@ void DFileChooserEdit::setFileMode(QFileDialog::FileMode mode)
 QFileDialog::FileMode DFileChooserEdit::fileMode() const
 {
     D_DC(DFileChooserEdit);
-    return d->fileMode;
+
+    if (!d->dialog) {
+        return QFileDialog::FileMode::AnyFile;
+    }
+    return d->dialog->fileMode();
 }
 
 /*!
@@ -142,7 +175,11 @@ QFileDialog::FileMode DFileChooserEdit::fileMode() const
 void  DFileChooserEdit::setNameFilters(const QStringList &filters)
 {
     D_D(DFileChooserEdit);
-    d->nameFilters = filters;
+
+    if (!d->dialog) {
+        initDialog();
+    }
+    d->dialog->setNameFilters(filters);
 }
 
 /*!
@@ -158,7 +195,31 @@ void  DFileChooserEdit::setNameFilters(const QStringList &filters)
 QStringList DFileChooserEdit::nameFilters() const
 {
     D_DC(DFileChooserEdit);
-    return d->nameFilters;
+
+    if (!d->dialog) {
+        return QStringList();
+    }
+    return d->dialog->nameFilters();
+}
+
+void DFileChooserEdit::setDirectoryUrl(const QUrl &directory)
+{
+    D_D(DFileChooserEdit);
+
+    if (!d->dialog) {
+        initDialog();
+    }
+    d->dialog->setDirectoryUrl(directory);
+}
+
+QUrl DFileChooserEdit::directoryUrl()
+{
+    D_D(DFileChooserEdit);
+
+    if (!d->dialog) {
+        initDialog();
+    }
+    return d->dialog->directoryUrl();
 }
 
 
@@ -171,30 +232,37 @@ void DFileChooserEditPrivate::init()
 {
     D_Q(DFileChooserEdit);
 
-    q->setTextMargins(0, 0, 24, 0);
-    q->setReadOnly(true);
-    q->setIconVisible(true);
-    q->connect(q, SIGNAL(iconClicked()), q, SLOT(_q_showFileChooserDialog()));
+    QList<QWidget *> list;
+    DSuggestButton *btn = new DSuggestButton(nullptr);
+    btn->setIcon(DStyleHelper(q->style()).standardIcon(DStyle::SP_SelectElement, nullptr));
+    btn->setIconSize(QSize(24, 24));
+
+    q->setDialogDisplayPosition(DFileChooserEdit::DialogDisplayPosition::CurrentMonitorCenter);
+
+    list.append(btn);
+
+    q->setRightWidgets(list);
+    q->setClearButtonEnabled(true);
+
+    q->connect(btn, SIGNAL(clicked()), q, SLOT(_q_showFileChooserDialog()));
 }
 
 void DFileChooserEditPrivate::_q_showFileChooserDialog()
 {
     D_Q(DFileChooserEdit);
 
-    QFileDialog dialog(q);
-
-    dialog.setAcceptMode(QFileDialog::AcceptOpen);
-    dialog.setFileMode(fileMode);
-    dialog.setNameFilters(nameFilters);
+    if (!dialog) {
+        q->initDialog();
+    }
 
     if (dialogDisplayPosition == DFileChooserEdit::CurrentMonitorCenter) {
         QPoint pos = QCursor::pos();
 
         for (QScreen *screen : qApp->screens()) {
             if (screen->geometry().contains(pos)) {
-                QRect rect = dialog.geometry();
+                QRect rect = dialog->geometry();
                 rect.moveCenter(screen->geometry().center());
-                dialog.move(rect.topLeft());
+                dialog->move(rect.topLeft());
                 break;
             }
         }
@@ -202,11 +270,10 @@ void DFileChooserEditPrivate::_q_showFileChooserDialog()
 
     q->dialogOpened();
 
-    int code = dialog.exec();
+    int code = dialog->exec();
 
-
-    if (code == QDialog::Accepted && !dialog.selectedFiles().isEmpty()) {
-        const QString fileName = dialog.selectedFiles().first();
+    if (code == QDialog::Accepted && !dialog->selectedFiles().isEmpty()) {
+        const QString fileName = dialog->selectedFiles().first();
 
         q->setText(fileName);
         Q_EMIT q->fileChoosed(fileName);
