@@ -2,7 +2,7 @@
  * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -29,27 +29,31 @@ class LIBDTKWIDGETSHARED_EXPORT DFileChooserEdit : public DLineEdit
     Q_OBJECT
 
     Q_ENUMS(DialogDisplayPosition)
-    Q_PROPERTY(DialogDisplayPosition dialogDisplayPosition READ dialogDisplayPosition WRITE setDialogDisplayPosition)
 
 public:
-    enum DialogDisplayPosition{
+    enum DialogDisplayPosition {
         FollowParentWindow,
         CurrentMonitorCenter
     };
 
-
     DFileChooserEdit(QWidget *parent = nullptr);
 
-    DialogDisplayPosition dialogDisplayPosition() const;
-
     void setFileMode(QFileDialog::FileMode mode);
     QFileDialog::FileMode fileMode() const;
 
     void setNameFilters(const QStringList &filters);
     QStringList nameFilters() const;
 
-public Q_SLOTS:
+    void setDirectoryUrl(const QUrl &directory);
+    QUrl directoryUrl();
+
     void setDialogDisplayPosition(DialogDisplayPosition dialogDisplayPosition);
+    DFileChooserEdit::DialogDisplayPosition dialogDisplayPosition() const;
+
+    void setFileDialog(QFileDialog *fileDialog);
+    QFileDialog *fileDialog() const;
+
+    void initDialog();
 
 Q_SIGNALS:
     void fileChoosed(const QString &fileName);
