@@ -2,7 +2,7 @@
  * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,18 +11,20 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <QDebug>
 #include <QScrollBar>
 
-#include "dthememanager.h"
 #include "dboxwidget.h"
 #include "dlistview.h"
 #include "private/dlistview_p.h"
 #include "dflowlayout.h"
+#include "dstyleoption.h"
+#include "dstyleditemdelegate.h"
+#include "dstyle.h"
 
 DWIDGET_BEGIN_NAMESPACE
 
@@ -47,7 +49,7 @@ QVariant DVariantListModel::data(const QModelIndex &index, int role) const
 }
 
 bool DVariantListModel::setData(const QModelIndex &index,
-                                 const QVariant &value, int role)
+                                const QVariant &value, int role)
 {
     if (index.row() >= 0 && index.row() < dataList.size()) {
         dataList.replace(index.row(), value);
@@ -106,6 +108,18 @@ void DListViewPrivate::init()
 
     q->setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);
     q->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);
+
+    DStyledItemDelegate *delegate = new DStyledItemDelegate(q);
+    q->setItemDelegate(delegate);
+
+    q->setFrameShape(QFrame::NoFrame);
+
+    q->viewport()->setAutoFillBackground(false);
+    q->setAutoFillBackground(false);
+    q->setBackgroundRole(q->viewport()->backgroundRole());
+
+    // 默认背景类型为圆角背景
+    q->setBackgroundType(DStyledItemDelegate::RoundedBackground);
 }
 
 void DListViewPrivate::onOrientationChanged()
@@ -114,11 +128,11 @@ void DListViewPrivate::onOrientationChanged()
 
     bool isVerticalLayout = (q->orientation() == Qt::Vertical);
 
-    if(headerLayout) {
+    if (headerLayout) {
         headerLayout->setDirection(isVerticalLayout
                                    ? QBoxLayout::TopToBottom
                                    : QBoxLayout::LeftToRight);
-        if(isVerticalLayout) {
+        if (isVerticalLayout) {
             headerLayout->resize(q->width(), headerLayout->sizeHint().height());
         } else {
             headerLayout->resize(headerLayout->sizeHint().width(), q->height());
@@ -127,12 +141,12 @@ void DListViewPrivate::onOrientationChanged()
         headerLayout->layout()->update();
     }
 
-    if(footerLayout) {
+    if (footerLayout) {
         footerLayout->setDirection(isVerticalLayout
                                    ? QBoxLayout::TopToBottom
                                    : QBoxLayout::LeftToRight);
 
-        if(isVerticalLayout) {
+        if (isVerticalLayout) {
             footerLayout->resize(q->width(), footerLayout->sizeHint().height());
             footerLayout->move(0, q->height() - footerLayout->height());
         } else {
@@ -185,8 +199,6 @@ DListView::DListView(QWidget *parent) :
     QListView(parent),
     DObject(*new DListViewPrivate(this))
 {
-    DThemeManager::registerWidget(this);
-
     d_func()->init();
 }
 
@@ -214,6 +226,40 @@ void DListView::setWrapping(bool enable)
     QListView::setWrapping(enable);
 }
 
+QSize DListView::viewportSizeHint() const
+{
+    return sizeAdjustPolicy() == QAbstractScrollArea::AdjustToContents ? QSize(0, 0) : QListView::viewportSizeHint();
+}
+
+int DListView::horizontalOffset() const
+{
+    if (viewMode() != IconMode || flow() != LeftToRight || !isWrapping()
+            || (!gridSize().isValid() && !itemSize().isValid())) {
+        return QListView::horizontalOffset();
+    }
+
+    int width = contentsSize().width();
+    int offset = gridSize().isValid() ? 0 : spacing() / 2;
+
+    return -(viewport()->width() - width) / 2 + offset;
+}
+
+QSize DListView::minimumSizeHint() const
+{
+    QSize size = QListView::minimumSizeHint();
+    QSize content_size = QListView::contentsSize();
+
+    if (horizontalScrollBarPolicy() == Qt::ScrollBarAlwaysOff) {
+        size.setWidth(content_size.width());
+    }
+
+    if (verticalScrollBarPolicy() == Qt::ScrollBarAlwaysOff) {
+        size.setHeight(content_size.height());
+    }
+
+    return size;
+}
+
 /*!
  * \~chinese \brief 获取一个顶部控件
  *
@@ -338,6 +384,33 @@ void DListView::setModel(QAbstractItemModel *model)
     }
 }
 
+DStyledItemDelegate::BackgroundType DListView::backgroundType() const
+{
+    if (DStyledItemDelegate *d = qobject_cast<DStyledItemDelegate *>(itemDelegate())) {
+        return d->backgroundType();
+    }
+
+    return DStyledItemDelegate::NoBackground;
+}
+
+QMargins DListView::itemMargins() const
+{
+    if (DStyledItemDelegate *d = qobject_cast<DStyledItemDelegate *>(itemDelegate())) {
+        return d->margins();
+    }
+
+    return QMargins();
+}
+
+QSize DListView::itemSize() const
+{
+    if (DStyledItemDelegate *d = qobject_cast<DStyledItemDelegate *>(itemDelegate())) {
+        return d->itemSize();
+    }
+
+    return QSize();
+}
+
 /*!
  * \~chinese \brief 在列表底部新增一个item
  * \~chinese \param data 要新增的数据
@@ -366,7 +439,7 @@ bool DListView::addItems(const QVariantList &datas)
  */
 bool DListView::insertItem(int index, const QVariant &data)
 {
-    if(!model()->insertRow(index))
+    if (!model()->insertRow(index))
         return false;
 
     return model()->setData(model()->index(index, 0, rootIndex()), data);
@@ -380,10 +453,10 @@ bool DListView::insertItem(int index, const QVariant &data)
  */
 bool DListView::insertItems(int index, const QVariantList &datas)
 {
-    if(!model()->insertRows(index, datas.count()))
+    if (!model()->insertRows(index, datas.count()))
         return false;
 
-    for(int i = 0; i < datas.count(); ++i)
+    for (int i = 0; i < datas.count(); ++i)
         model()->setData(model()->index(index + i, 0, rootIndex()), datas.at(i));
 
     return true;
@@ -419,28 +492,28 @@ int DListView::addHeaderWidget(QWidget *widget)
 
     int index = d->headerList.indexOf(widget);
 
-    if(index >= 0)
+    if (index >= 0)
         return index;
 
-    if(!d->headerLayout) {
+    if (!d->headerLayout) {
         bool isVerticalLayout = (orientation() == Qt::Vertical);
 
         d->headerLayout = new DBoxWidget(isVerticalLayout
                                          ? QBoxLayout::TopToBottom
                                          : QBoxLayout::LeftToRight, this);
 
-        if(isVerticalLayout)
+        if (isVerticalLayout)
             d->headerLayout->resize(width(), d->headerLayout->height());
         else
             d->headerLayout->resize(d->headerLayout->width(), height());
 
         connect(d->headerLayout, &DBoxWidget::sizeChanged,
-                this, [this](const QSize &size) {
+        this, [this](const QSize & size) {
             bool isVerticalLayout = (orientation() == Qt::Vertical);
 
             QMargins margins = this->viewportMargins();
 
-            if(isVerticalLayout)
+            if (isVerticalLayout)
                 margins.setTop(size.height());
             else
                 margins.setLeft(size.width());
@@ -464,12 +537,12 @@ void DListView::removeHeaderWidget(int index)
 {
     QWidget *widget = takeHeaderWidget(index);
 
-    if(widget)
+    if (widget)
         widget->deleteLater();
 }
 
 /*!
- * \brief 与 DListView::getHeaderWidget 类似，但返回要移除的顶部控件的对象
+ * \~chinese \brief 与 DListView::getHeaderWidget 类似，但返回要移除的顶部控件的对象
  * \~chinese \sa DListView::getHeaderWidget
  */
 QWidget *DListView::takeHeaderWidget(int index)
@@ -480,7 +553,7 @@ QWidget *DListView::takeHeaderWidget(int index)
 
     d->headerLayout->layout()->removeWidget(widget);
 
-    if(d->headerList.isEmpty()) {
+    if (d->headerList.isEmpty()) {
         d->headerLayout->deleteLater();
         d->headerLayout = nullptr;
     }
@@ -497,30 +570,30 @@ int DListView::addFooterWidget(QWidget *widget)
 
     int index = d->footerList.indexOf(widget);
 
-    if(index >= 0)
+    if (index >= 0)
         return index;
 
-    if(!d->footerLayout) {
+    if (!d->footerLayout) {
         bool isVerticalLayout = (orientation() == Qt::Vertical);
 
         d->footerLayout = new DBoxWidget(isVerticalLayout
                                          ? QBoxLayout::TopToBottom
                                          : QBoxLayout::LeftToRight, this);
 
-        if(isVerticalLayout)
+        if (isVerticalLayout)
             d->footerLayout->resize(width(), d->footerLayout->height());
         else
             d->footerLayout->resize(d->footerLayout->width(), height());
 
         connect(d->footerLayout, &DBoxWidget::sizeChanged,
-                this, [this](const QSize &size) {
+        this, [this](const QSize & size) {
             bool isVerticalLayout = (orientation() == Qt::Vertical);
 
             QMargins margins = this->viewportMargins();
 
             D_D(DListView);
 
-            if(isVerticalLayout) {
+            if (isVerticalLayout) {
                 margins.setBottom(size.height());
                 d->footerLayout->move(0, height() - d->footerLayout->height());
             } else {
@@ -547,7 +620,7 @@ void DListView::removeFooterWidget(int index)
 {
     QWidget *widget = takeFooterWidget(index);
 
-    if(widget)
+    if (widget)
         widget->deleteLater();
 }
 
@@ -562,7 +635,7 @@ QWidget *DListView::takeFooterWidget(int index)
 
     d->footerLayout->layout()->removeWidget(widget);
 
-    if(d->footerList.isEmpty()) {
+    if (d->footerList.isEmpty()) {
         d->footerLayout->deleteLater();
         d->footerLayout = nullptr;
     }
@@ -582,22 +655,22 @@ void DListView::setOrientation(QListView::Flow flow, bool wrapping)
 
     Qt::Orientation orientation = this->orientation();
 
-    if(old_orientation != orientation) {
+    if (old_orientation != orientation) {
         D_D(DListView);
 
         QMargins margins = viewportMargins();
 
-        if(old_orientation == Qt::Vertical) {
-            if(d->headerLayout)
+        if (old_orientation == Qt::Vertical) {
+            if (d->headerLayout)
                 margins.setTop(0);
 
-            if(d->footerLayout)
+            if (d->footerLayout)
                 margins.setBottom(0);
         } else {
-            if(d->headerLayout)
+            if (d->headerLayout)
                 margins.setLeft(0);
 
-            if(d->footerLayout)
+            if (d->footerLayout)
                 margins.setRight(0);
         }
 
@@ -610,14 +683,76 @@ void DListView::setOrientation(QListView::Flow flow, bool wrapping)
 }
 
 /*!
- * \brief 开始编辑一个item
- * \param index 指定要编辑的item的位置
+ * \~chinese \brief 开始编辑一个item
+ * \~chinese \param index 指定要编辑的item的位置
  */
 void DListView::edit(const QModelIndex &index)
 {
     QListView::edit(index);
 }
 
+/*!
+ * \~chinese \brief DListView::setBackgroundType 设定item的背景色类型
+ * \~chinese \param backgroundType 背景色类型
+ */
+void DListView::setBackgroundType(DStyledItemDelegate::BackgroundType backgroundType)
+{
+    if (DStyledItemDelegate *d = qobject_cast<DStyledItemDelegate *>(itemDelegate())) {
+        d->setBackgroundType(backgroundType);
+
+        if (d->backgroundType() == DStyledItemDelegate::RoundedBackground) {
+            d->setItemSpacing(10);
+        } else if (d->backgroundType() == DStyledItemDelegate::ClipCornerBackground) {
+            d->setItemSpacing(1);
+        } else {
+            d->setItemSpacing(0);
+        }
+    }
+}
+
+/*!
+ * \~chinese \brief DListView::setItemMargins 设定item的内容margin
+ * \~chinese \param itemMargins margin值
+ */
+void DListView::setItemMargins(const QMargins &itemMargins)
+{
+    if (DStyledItemDelegate *d = qobject_cast<DStyledItemDelegate *>(itemDelegate())) {
+        d->setMargins(itemMargins);
+    }
+}
+
+/*!
+ * \~chinese \brief DListView::setItemSize设定item的尺寸
+ * \~chinese \param itemSize 尺寸的大小
+ */
+void DListView::setItemSize(QSize itemSize)
+{
+    if (DStyledItemDelegate *d = qobject_cast<DStyledItemDelegate *>(itemDelegate())) {
+        return d->setItemSize(itemSize);
+    }
+}
+
+/*!
+ * \~chinese \brief DListView::setItemSpacing　设定item的间距大小
+ * \~chinese \param spacing　间距大小值
+ */
+void DListView::setItemSpacing(int spacing)
+{
+    if (DStyledItemDelegate *d = qobject_cast<DStyledItemDelegate *>(itemDelegate())) {
+        return d->setItemSpacing(spacing);
+    }
+}
+
+/*!
+ * \~chinese \brief DListView::setItemRadius 设定item的圆角大小
+ * \~chinese \param radius 圆角大小值
+ */
+void DListView::setItemRadius(int radius)
+{
+    DStyle::setFrameRadius(this, radius);
+    update();
+}
+
 #if(QT_VERSION < 0x050500)
 void DListView::setViewportMargins(int left, int top, int right, int bottom)
 {
@@ -652,15 +787,15 @@ void DListView::resizeEvent(QResizeEvent *event)
 
     bool isVerticalLayout = (orientation() == Qt::Vertical);
 
-    if(d->headerLayout) {
-        if(isVerticalLayout)
+    if (d->headerLayout) {
+        if (isVerticalLayout)
             d->headerLayout->resize(width(), d->headerLayout->height());
         else
             d->headerLayout->resize(d->headerLayout->width(), height());
     }
 
-    if(d->footerLayout) {
-        if(isVerticalLayout) {
+    if (d->footerLayout) {
+        if (isVerticalLayout) {
             d->footerLayout->resize(width(), d->footerLayout->height());
             d->footerLayout->move(0, height() - d->footerLayout->height());
         } else {
@@ -689,10 +824,10 @@ bool DListView::edit(const QModelIndex &index, QAbstractItemView::EditTrigger tr
         if (trigger == QAbstractItemView::AllEditTriggers) // force editing
             return true;
         if ((trigger & editTriggers()) == QAbstractItemView::SelectedClicked
-            && !selectionModel()->isSelected(index))
+                && !selectionModel()->isSelected(index))
             return false;
 
-        if(trigger & editTriggers()) {
+        if (trigger & editTriggers()) {
             w->setFocus();
 
             Q_EMIT triggerEdit(index);
@@ -703,12 +838,59 @@ bool DListView::edit(const QModelIndex &index, QAbstractItemView::EditTrigger tr
 
     bool tmp = QListView::edit(index, trigger, event);
 
-    if(tmp)
+    if (tmp)
         Q_EMIT triggerEdit(index);
 
     return tmp;
 }
 
+QStyleOptionViewItem DListView::viewOptions() const
+{
+    QStyleOptionViewItem item = QListView::viewOptions();
+
+    item.showDecorationSelected = true;
+    // 列表项不会变为Inactive状态
+    item.state |= QStyle::State_Active;
+
+    if (viewMode() == QListView::ListMode) {
+        item.decorationAlignment = Qt::AlignVCenter;
+    }
+
+    return item;
+}
+
+QModelIndex DListView::moveCursor(QAbstractItemView::CursorAction cursorAction, Qt::KeyboardModifiers modifiers)
+{
+    switch (cursorAction) {
+    case MoveNext: {
+        auto curIdx = currentIndex();
+        auto curCol = modelColumn();
+
+        auto nextRow = 0;
+        if (curIdx.isValid()) {
+            nextRow = (curIdx.row() + 1) % model()->rowCount();
+        }
+
+        int hiddenCount = 0;
+        while (isRowHidden(nextRow)) {
+            nextRow = (nextRow + 1) % model()->rowCount();
+
+            //防止所有列都是隐藏的死循环
+            ++hiddenCount;
+            if (hiddenCount >= count()) {
+                return currentIndex();
+            }
+        }
+
+        return model()->index(nextRow, curCol);
+    }
+    default:
+        break;
+    }
+
+    return QListView::moveCursor(cursorAction, modifiers);
+}
+
 DWIDGET_END_NAMESPACE
 
 #include "moc_dlistview.cpp"
