@@ -2,7 +2,7 @@
  * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -19,6 +19,7 @@
 #include "dplatformwindowhandle.h"
 #include "dapplication.h"
 #include "dtitlebar.h"
+#include "dmessagemanager.h"
 
 #include "private/dmainwindow_p.h"
 #include "private/dapplication_p.h"
@@ -27,6 +28,7 @@
 #include <QShortcut>
 #include <QWindow>
 #include <QMouseEvent>
+#include <QComboBox>
 
 #ifdef Q_OS_MAC
 #include "osxwindow.h"
@@ -53,12 +55,17 @@ DMainWindowPrivate::DMainWindowPrivate(DMainWindow *qq)
         titlebar->setEmbedMode(true);
 #endif
     }
+
+    qq->setMinimumWidth(titlebar->minimumSizeHint().width());
 }
 
 void DMainWindowPrivate::init()
 {
     D_Q(DMainWindow);
 
+    // 默认开启标题栏阴影
+    q->setTitlebarShadowEnabled(true);
+
     const DApplication *dapp = qobject_cast<DApplication *>(qApp);
     if (dapp) {
         q->setWindowTitle(dapp->productName());
@@ -82,7 +89,7 @@ void DMainWindowPrivate::init()
         q->connect(handle, &DPlatformWindowHandle::enableBlurWindowChanged, q, &DMainWindow::enableBlurWindowChanged);
         q->connect(handle, &DPlatformWindowHandle::autoInputMaskByClipPathChanged, q, &DMainWindow::autoInputMaskByClipPathChanged);
 
-        if (!handle->isEnableNoTitlebar(q->windowHandle())) {
+        if (!handle->isEnabledNoTitlebar(q->windowHandle())) {
             q->connect(qApp, &QGuiApplication::focusWindowChanged, q, [q] {
                 if (q->isActiveWindow())
                 {
@@ -97,7 +104,6 @@ void DMainWindowPrivate::init()
 
     if (!help && DApplicationPrivate::isUserManualExists()) {
         help = new QShortcut(QKeySequence(Qt::Key_F1), q);
-        help->setContext(Qt::ApplicationShortcut);
         QObject::connect(help, &QShortcut::activated,
         q, [ = ]() {
             DApplication *dapp = qobject_cast<DApplication *>(qApp);
@@ -106,8 +112,20 @@ void DMainWindowPrivate::init()
             }
         });
     }
+}
 
+void DMainWindowPrivate::updateTitleShadowGeometry()
+{
+    D_QC(DMainWindow);
 
+    if (!titleShadow)
+        return;
+
+    QRect rect(0, titlebar->rect().bottom() + 1, q->width(), titleShadow->sizeHint().height());
+    titleShadow->setGeometry(rect);
+    // 全凭时会隐藏窗口标题栏，因此不应该显示标题栏的阴影
+    titleShadow->setVisible(!q->isFullScreen());
+    titleShadow->raise();
 }
 
 /*!
@@ -386,6 +404,21 @@ bool DMainWindow::autoInputMaskByClipPath() const
     return d->handle->autoInputMaskByClipPath();
 }
 
+/*!
+ * \~chinese \brief DMainWindow::titlebarShadowIsEnabled
+ * \~chinese \return true　titleBar阴影开启　false 阴影关闭
+ */
+bool DMainWindow::titlebarShadowIsEnabled() const
+{
+    D_DC(DMainWindow);
+
+    return d->titleShadow;
+}
+
+/*!
+ * \~chinese \brief DMainWindow::setWindowRadius　设定窗口的圆角
+ * \~chinese \param windowRadius　窗口的圆角值
+ */
 void DMainWindow::setWindowRadius(int windowRadius)
 {
     D_D(DMainWindow);
@@ -397,6 +430,10 @@ void DMainWindow::setWindowRadius(int windowRadius)
     d->handle->setWindowRadius(windowRadius);
 }
 
+/*!
+ * \~chinese \brief DMainWindow::setBorderWidth 设定边框的宽度
+ * \~chinese \param borderWidth　边框的宽度
+ */
 void DMainWindow::setBorderWidth(int borderWidth)
 {
     D_D(DMainWindow);
@@ -408,6 +445,10 @@ void DMainWindow::setBorderWidth(int borderWidth)
     d->handle->setBorderWidth(borderWidth);
 }
 
+/*!
+ * \~chinese \brief DMainWindow::setBorderColor 设定边框的颜色
+ * \~chinese \param borderColor　边框的颜色
+ */
 void DMainWindow::setBorderColor(const QColor &borderColor)
 {
     D_D(DMainWindow);
@@ -419,6 +460,10 @@ void DMainWindow::setBorderColor(const QColor &borderColor)
     d->handle->setBorderColor(borderColor);
 }
 
+/*!
+ * \~chinese \brief DMainWindow::setShadowRadius 设定阴影区域的圆角
+ * \~chinese \param shadowRadius　阴影区域圆角大小
+ */
 void DMainWindow::setShadowRadius(int shadowRadius)
 {
     D_D(DMainWindow);
@@ -430,6 +475,10 @@ void DMainWindow::setShadowRadius(int shadowRadius)
     d->handle->setShadowRadius(shadowRadius);
 }
 
+/*!
+ * \~chinese \brief DMainWindow::setShadowOffset 设定阴影区域的偏移距离
+ * \~chinese \param shadowOffset　阴影区域的偏移距离
+ */
 void DMainWindow::setShadowOffset(const QPoint &shadowOffset)
 {
     D_D(DMainWindow);
@@ -441,6 +490,10 @@ void DMainWindow::setShadowOffset(const QPoint &shadowOffset)
     d->handle->setShadowOffset(shadowOffset);
 }
 
+/*!
+ * \~chinese \brief DMainWindow::setShadowColor 设定阴影的颜色
+ * \~chinese \param shadowColor　阴影的颜色
+ */
 void DMainWindow::setShadowColor(const QColor &shadowColor)
 {
     D_D(DMainWindow);
@@ -452,6 +505,10 @@ void DMainWindow::setShadowColor(const QColor &shadowColor)
     d->handle->setShadowColor(shadowColor);
 }
 
+/*!
+ * \~chinese \brief DMainWindow::setClipPath 设定裁剪路径
+ * \~chinese \param clipPath　裁剪的路径
+ */
 void DMainWindow::setClipPath(const QPainterPath &clipPath)
 {
     D_D(DMainWindow);
@@ -463,6 +520,10 @@ void DMainWindow::setClipPath(const QPainterPath &clipPath)
     d->handle->setClipPath(clipPath);
 }
 
+/*!
+ * \~chinese \brief DMainWindow::setFrameMask 设定边框的mask区域
+ * \~chinese \param frameMask mask区域
+ */
 void DMainWindow::setFrameMask(const QRegion &frameMask)
 {
     D_D(DMainWindow);
@@ -474,6 +535,10 @@ void DMainWindow::setFrameMask(const QRegion &frameMask)
     d->handle->setFrameMask(frameMask);
 }
 
+/*!
+ * \~chinese \brief DMainWindow::setTranslucentBackground 设定时候擦除背景
+ * \~chinese \param translucentBackground true擦除背景　false不擦除背景
+ */
 void DMainWindow::setTranslucentBackground(bool translucentBackground)
 {
     D_D(DMainWindow);
@@ -485,6 +550,10 @@ void DMainWindow::setTranslucentBackground(bool translucentBackground)
     d->handle->setTranslucentBackground(translucentBackground);
 }
 
+/*!
+ * \~chinese \brief DMainWindow::setEnableSystemResize　设定是否允许系统调整窗口大小
+ * \~chinese \param enableSystemResize　true允许系统调整　false不允许系统调整
+ */
 void DMainWindow::setEnableSystemResize(bool enableSystemResize)
 {
     D_D(DMainWindow);
@@ -496,6 +565,10 @@ void DMainWindow::setEnableSystemResize(bool enableSystemResize)
     d->handle->setEnableSystemResize(enableSystemResize);
 }
 
+/*!
+ * \~chinese \brief DMainWindow::setEnableSystemMove 设定时候允许系统移动窗口
+ * \~chinese \param enableSystemMove　true允许移动　false不允许移动
+ */
 void DMainWindow::setEnableSystemMove(bool enableSystemMove)
 {
     D_D(DMainWindow);
@@ -507,6 +580,10 @@ void DMainWindow::setEnableSystemMove(bool enableSystemMove)
     d->handle->setEnableSystemMove(enableSystemMove);
 }
 
+/*!
+ * \~chinese \brief DMainWindow::setEnableBlurWindow　设定时候能伸缩窗口
+ * \~chinese \param enableBlurWindow true能伸缩　false不能伸缩
+ */
 void DMainWindow::setEnableBlurWindow(bool enableBlurWindow)
 {
     D_D(DMainWindow);
@@ -518,6 +595,10 @@ void DMainWindow::setEnableBlurWindow(bool enableBlurWindow)
     d->handle->setEnableBlurWindow(enableBlurWindow);
 }
 
+/*!
+ * \~chinese \brief DMainWindow::setAutoInputMaskByClipPath 通过裁剪区域自动设定mask
+ * \~chinese \param autoInputMaskByClipPath true自动设定　false不自动设定
+ */
 void DMainWindow::setAutoInputMaskByClipPath(bool autoInputMaskByClipPath)
 {
     D_D(DMainWindow);
@@ -529,6 +610,46 @@ void DMainWindow::setAutoInputMaskByClipPath(bool autoInputMaskByClipPath)
     d->handle->setAutoInputMaskByClipPath(autoInputMaskByClipPath);
 }
 
+/*!
+ * \~chinese \brief DMainWindow::sendMessage 发送消息
+ * \~chinese \param icon 消息展示图标
+ * \~chinese \param message　消息内容
+ */
+void DMainWindow::sendMessage(const QIcon &icon, const QString &message)
+{
+    DMessageManager::instance()->sendMessage(this, icon, message);
+}
+
+/*!
+ * \~chinese \brief DMainWindow::sendMessage 发送消息
+ * \~chinese \param message　DFloatingMessage消息
+ */
+void DMainWindow::sendMessage(DFloatingMessage *message)
+{
+    DMessageManager::instance()->sendMessage(this, message);
+}
+
+/*!
+ * \~chinese \brief DMainWindow::setTitlebarShadowEnabled设定titleBar是否有阴影区域
+ * \~chinese \param titlebarShadowEnabled true titleBar有阴影　false无阴影
+ */
+void DMainWindow::setTitlebarShadowEnabled(bool titlebarShadowEnabled)
+{
+    D_D(DMainWindow);
+
+    if (static_cast<bool>(d->titleShadow) == titlebarShadowEnabled)
+        return;
+
+    if (titlebarShadowEnabled) {
+        d->titleShadow = new DShadowLine(this);
+        d->titleShadow->setAttribute(Qt::WA_AlwaysStackOnTop);
+        d->updateTitleShadowGeometry();
+    } else {
+        d->titleShadow->deleteLater();
+        d->titleShadow = nullptr;
+    }
+}
+
 #ifdef Q_OS_MAC
 void DMainWindow::setWindowFlags(Qt::WindowFlags type)
 {
@@ -544,4 +665,33 @@ DMainWindow::DMainWindow(DMainWindowPrivate &dd, QWidget *parent)
     d_func()->init();
 }
 
+void DMainWindow::mouseMoveEvent(QMouseEvent *event)
+{
+    QWidget *compoment = childAt(event->pos());
+    if (qobject_cast<QComboBox *>(compoment)) {
+        return;
+    }
+    return QMainWindow::mouseMoveEvent(event);
+}
+
+void DMainWindow::resizeEvent(QResizeEvent *event)
+{
+    Q_UNUSED(event)
+    D_D(DMainWindow);
+
+    d->updateTitleShadowGeometry();
+
+    return QMainWindow::resizeEvent(event);
+}
+
+void DMainWindow::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::WindowStateChange) {
+        D_D(DMainWindow);
+        d->updateTitleShadowGeometry();
+    }
+
+    return QMainWindow::changeEvent(event);
+}
+
 DWIDGET_END_NAMESPACE
