@@ -2,7 +2,7 @@
  * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -22,6 +22,7 @@
 #include <QPainter>
 #include <QDebug>
 #include <QVBoxLayout>
+#include <QTimer>
 
 DWIDGET_BEGIN_NAMESPACE
 
@@ -91,6 +92,15 @@ void DMPRISControl::setPictureSize(const QSize &size)
     d->m_picture->setFixedSize(size);
 }
 
+void DMPRISControl::showEvent(QShowEvent *event)
+{
+    D_D(DMPRISControl);
+
+    d->_q_onPlaybackStatusChanged();
+
+    QFrame::showEvent(event);
+}
+
 DMPRISControlPrivate::DMPRISControlPrivate(DMPRISControl *q)
     : DObjectPrivate(q), m_mprisInter(nullptr)
 {
@@ -106,21 +116,29 @@ void DMPRISControlPrivate::init()
     m_picture         = new QLabel;
     m_pictureVisible  = true;
     m_controlWidget   = new QWidget;
-    m_prevBtn         = new DImageButton;
-    m_pauseBtn        = new DImageButton;
-    m_playBtn         = new DImageButton;
-    m_nextBtn         = new DImageButton;
+    m_prevBtn         = new DFloatingButton(m_controlWidget);
+    m_playBtn         = new DFloatingButton(m_controlWidget);
+    m_nextBtn         = new DFloatingButton(m_controlWidget);
     m_tickEffect      = new DTickEffect(m_title, m_title);
 
+    m_prevBtn->setIcon(QIcon::fromTheme(":/assets/images/play_previous.svg"));
+    m_playBtn->setIcon(QIcon::fromTheme(":/assets/images/play_start.svg"));
+    m_nextBtn->setIcon(QIcon::fromTheme(":/assets/images/play_next.svg"));
+    m_prevBtn->setBackgroundRole(DPalette::Button);
+    m_playBtn->setBackgroundRole(DPalette::Button);
+    m_nextBtn->setBackgroundRole(DPalette::Button);
+    m_prevBtn->setAutoExclusive(true);
+    m_playBtn->setAutoExclusive(true);
+    m_nextBtn->setAutoExclusive(true);
+
     m_title->setAlignment(Qt::AlignCenter);
     m_picture->setFixedSize(200, 200);
     m_prevBtn->setObjectName("PrevBtn");
-    m_pauseBtn->setObjectName("PauseBtn");
     m_playBtn->setObjectName("PlayBtn");
     m_nextBtn->setObjectName("NextBtn");
 
     m_tickEffect->setDirection(DTickEffect::RightToLeft);
-    m_tickEffect->setDuration(3000);
+    m_tickEffect->setFixedPixelMove(50);
 
     m_titleScrollArea->setWidget(m_title);
     m_titleScrollArea->setObjectName("scrollarea");
@@ -135,20 +153,19 @@ void DMPRISControlPrivate::init()
 
 #ifdef QT_DEBUG
     m_title->setText("MPRIS Title");
-    m_nextBtn->setNormalPic("://images/arrow_right_normal.png");
-    m_pauseBtn->setNormalPic("://images/arrow_left_white.png");
-    m_playBtn->setNormalPic("://images/arrow_right_white.png");
-    m_prevBtn->setNormalPic("://images/arrow_left_normal.png");
+
+    m_nextBtn->setIcon(QIcon::fromTheme(":/assets/images/arrow_right_normal.png"));
+    m_playBtn->setIcon(QIcon::fromTheme(":/assets/images/arrow_right_white.png"));
+    m_prevBtn->setIcon(QIcon::fromTheme(":/assets/images/arrow_left_normal.png"));
 #endif
 
     QHBoxLayout *controlLayout = new QHBoxLayout;
     controlLayout->addWidget(m_prevBtn);
     controlLayout->addStretch();
-    controlLayout->addWidget(m_pauseBtn);
     controlLayout->addWidget(m_playBtn);
     controlLayout->addStretch();
     controlLayout->addWidget(m_nextBtn);
-    controlLayout->setContentsMargins(0, 10, 0, 0);
+    controlLayout->setContentsMargins(0, 5, 0, 0);
     m_controlWidget->setLayout(controlLayout);
 
 
@@ -165,8 +182,14 @@ void DMPRISControlPrivate::init()
     q->connect(m_mprisMonitor, SIGNAL(mprisAcquired(const QString &)), q, SLOT(_q_loadMPRISPath(const QString &)));
     q->connect(m_mprisMonitor, SIGNAL(mprisLost(const QString &)), q, SLOT(_q_removeMPRISPath(const QString &)));
     q->connect(m_prevBtn, SIGNAL(clicked()), q, SLOT(_q_onPrevClicked()));
-    q->connect(m_pauseBtn, SIGNAL(clicked()), q, SLOT(_q_onPauseClicked()));
-    q->connect(m_playBtn, SIGNAL(clicked()), q, SLOT(_q_onPlayClicked()));
+
+    q->connect(m_playBtn, &DFloatingButton::clicked, q, [q, this] {
+        if (m_clickedStatus)
+            return;
+        m_clickedStatus = true;
+        QTimer::singleShot(100, q, SLOT(_q_onPlayClicked()));
+    });
+
     q->connect(m_nextBtn, SIGNAL(clicked()), q, SLOT(_q_onNextClicked()));
 
     m_mprisMonitor->init();
@@ -178,22 +201,27 @@ void DMPRISControlPrivate::_q_onPrevClicked()
         return;
 
     m_mprisInter->Previous();
+    m_prevBtn->setFocus();
 }
 
 void DMPRISControlPrivate::_q_onPlayClicked()
 {
+    m_clickedStatus = false;
     if (!m_mprisInter)
         return;
 
-    m_mprisInter->Play();
+    if (m_playStatus) {
+        m_mprisInter->Pause();
+    } else {
+        m_mprisInter->Play();
+    }
+
+    m_playBtn->setFocus();
 }
 
 void DMPRISControlPrivate::_q_onPauseClicked()
 {
-    if (!m_mprisInter)
-        return;
-
-    m_mprisInter->Pause();
+    //
 }
 
 void DMPRISControlPrivate::_q_onNextClicked()
@@ -202,6 +230,7 @@ void DMPRISControlPrivate::_q_onNextClicked()
         return;
 
     m_mprisInter->Next();
+    m_nextBtn->setFocus();
 }
 
 void DMPRISControlPrivate::_q_onMetaDataChanged()
@@ -237,16 +266,27 @@ void DMPRISControlPrivate::_q_onMetaDataChanged()
 
 void DMPRISControlPrivate::_q_onPlaybackStatusChanged()
 {
-    const QString stat = m_mprisInter->playbackStatus();
+    if (!m_mprisInter)
+        return;
 
-    if (stat == "Playing")
-    {
-        m_pauseBtn->setVisible(true);
-        m_playBtn->setVisible(false);
+    const QString stat = m_mprisInter->playbackStatus();
+#ifdef QT_DEBUG
+    if (stat == "Playing") {
+        m_playStatus = true;
+        m_playBtn->setIcon(QIcon::fromTheme(":/assets/images/arrow_right_white.png"));
     } else {
-        m_pauseBtn->setVisible(false);
-        m_playBtn->setVisible(true);
+        m_playStatus = false;
+        m_playBtn->setIcon(QIcon::fromTheme(":/assets/images/arrow_left_white.png"));
     }
+#else
+    if (stat == "Playing") {
+        m_playStatus = true;
+        m_playBtn->setIcon(QIcon::fromTheme(":/assets/images/play_pause.svg"));
+    } else {
+        m_playStatus = false;
+        m_playBtn->setIcon(QIcon::fromTheme(":/assets/images/play_start.svg"));
+    }
+#endif
 }
 
 void DMPRISControlPrivate::_q_loadMPRISPath(const QString &path)
