@@ -2,7 +2,7 @@
  * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -21,21 +21,24 @@
 #include <QHBoxLayout>
 
 #include <DSettingsOption>
+#include <DPushButton>
 #include <DSettings>
+#include <DTitlebar>
+#include <DFrame>
 
 #include "dsettingswidgetfactory.h"
 
 #include "private/settings/content.h"
 #include "private/settings/navigation.h"
 
-#include "dthememanager.h"
-#include "dwindowclosebutton.h"
 #include "dspinbox.h"
-#include "dbuttonlist.h"
-#include "doptionlist.h"
+#include "dwindowclosebutton.h"
 
 DWIDGET_BEGIN_NAMESPACE
 
+// see also: dtitlebar.cpp
+const int DefaultTitlebarHeight = 40;
+
 /*!
  * \~english \class DSettingsDialog
  * \brief DSettingsDialog provide an common setting ui for deepin style application.
@@ -57,48 +60,52 @@ public:
     DSettingsDialogPrivate(DSettingsDialog *parent) : q_ptr(parent) {}
 
     Navigation      *leftFrame;
-
-    QFrame          *rightFrame;
-    QVBoxLayout     *rightLayout;
     Content         *content;
+    DTitlebar       *frameBar;
 
     DSettingsDialog *q_ptr;
     Q_DECLARE_PUBLIC(DSettingsDialog)
 };
 
 DSettingsDialog::DSettingsDialog(QWidget *parent) :
-    DAbstractDialog(parent), dd_ptr(new DSettingsDialogPrivate(this))
+    DAbstractDialog(false, parent), dd_ptr(new DSettingsDialogPrivate(this))
 {
     Q_D(DSettingsDialog);
 
-    DThemeManager::registerWidget(this);
-
     setObjectName("DSettingsDialog");
 
-    auto layout = new QHBoxLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
-    layout->setSpacing(0);
+    auto mainlayout = new QVBoxLayout(this);
+    mainlayout->setContentsMargins(0, 0, 0, 0);
+    mainlayout->setSpacing(0);
 
     d->leftFrame = new Navigation;
-    d->leftFrame->layout()->setContentsMargins(0, 30, 0, 0);
-
-    layout->addWidget(d->leftFrame);
-
-    d->rightFrame = new QFrame;
-    d->rightFrame->setObjectName("RightFrame");
-    d->rightLayout = new QVBoxLayout(d->rightFrame);
-    d->rightLayout->setContentsMargins(1, 0, 0, 0);
-    d->rightLayout->setSpacing(0);
-
     d->content = new Content;
 
-    auto closeBt = new DImageButton;
-    closeBt->setObjectName("DSettingsDialogClose");
-    d->rightLayout->addWidget(closeBt, 0, Qt::AlignVCenter | Qt::AlignRight);
-    d->rightLayout->addWidget(d->content);
+    DFrame *rightFrame = new DFrame;
+    rightFrame->setLineWidth(0);
+    rightFrame->setContentsMargins(10, 10, 10, 10);
 
-    layout->addWidget(d->rightFrame);
-    setFixedWidth(680);
+    QVBoxLayout *rightlayout = new QVBoxLayout(rightFrame);
+    d->frameBar = new DTitlebar;
+    d->frameBar->setMenuVisible(false);
+    d->frameBar->setTitle(QString());
+
+    d->leftFrame->setObjectName("LeftFrame");
+    d->content->setObjectName("RightFrame");
+    d->content->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+
+    rightlayout->setMargin(0);
+    rightlayout->addWidget(d->content);
+
+    QHBoxLayout *bottomlayout = new QHBoxLayout;
+    bottomlayout->addWidget(d->leftFrame, 0, Qt::AlignLeft);
+    bottomlayout->addWidget(rightFrame);
+    bottomlayout->setContentsMargins(0, 0, 0, 0);
+
+    mainlayout->addWidget(d->frameBar);
+    mainlayout->addLayout(bottomlayout);
+
+    setMinimumWidth(680);
 
     connect(d->leftFrame, &Navigation::selectedGroup, d->content, &Content::onScrollToGroup);
     connect(d->content, &Content::scrollToGroup, d->leftFrame, [ = ](const QString & key) {
@@ -106,7 +113,9 @@ DSettingsDialog::DSettingsDialog(QWidget *parent) :
         d->leftFrame->onSelectGroup(key);
         d->leftFrame->blockSignals(false);
     });
-    connect(closeBt, &DWindowCloseButton::clicked, this, &DSettingsDialog::close);
+
+    connect(this, &DSettingsDialog::windowIconChanged, d->frameBar, &DTitlebar::setIcon);
+    connect(this, &DSettingsDialog::windowTitleChanged, d->frameBar, &DTitlebar::setTitle);
 }
 
 DSettingsDialog::~DSettingsDialog()
@@ -130,6 +139,51 @@ DSettingsWidgetFactory *DSettingsDialog::widgetFactory() const
     return  d->content->widgetFactory();
 }
 
+bool DSettingsDialog::groupIsVisible(const QString &groupKey) const
+{
+    Q_D(const DSettingsDialog);
+    return d->content->groupIsVisible(groupKey);
+}
+
+/*!
+ * /~chinese \brief DSettingsDialog::setResetVisible 设置恢复默认设置按钮是否显示
+ * /~chinese \param visible true显示 false隐藏
+ * /~chinese \note 请在 updateSettings() 后调用
+ */
+void DSettingsDialog::setResetVisible(bool visible)
+{
+    D_D(DSettingsDialog);
+    DPushButton *btn = d->content->findChild<DPushButton *>("SettingsContentReset");
+    if (btn == nullptr)
+        return;
+    btn->setVisible(visible);
+
+}
+
+/*!
+ * /~chinese \brief DSettingsDialog::scrollToGroup 使对话框跳转到指定的 group 项目
+ * /~chinese \param groupKey DSettings中 groupKeys 以及其子项 childGroups
+ * /~chinese \note 请在对话框 show 以后调用
+ */
+void DSettingsDialog::scrollToGroup(const QString &groupKey)
+{
+    D_D(DSettingsDialog);
+
+    d->leftFrame->onSelectGroup(groupKey);
+    d->content->onScrollToGroup(groupKey);
+}
+
+/*!
+ * \brief DSettingsDialog::setIcon 设置标题栏的图标 QIcon
+ * \param icon 设置的 Icon
+ */
+void DSettingsDialog::setIcon(const QIcon &icon)
+{
+    D_D(DSettingsDialog);
+
+    d->frameBar->setIcon(icon);
+}
+
 /*!
  * \~english \brief Create all widget for settings options.
  * Warnning that you can only call the once.
@@ -165,4 +219,11 @@ void DSettingsDialog::updateSettings(const QByteArray &translateContext, Core::D
     adjustSize();
 }
 
+void DSettingsDialog::setGroupVisible(const QString &groupKey, bool visible)
+{
+    Q_D(DSettingsDialog);
+    d->leftFrame->setGroupVisible(groupKey, visible);
+    d->content->setGroupVisible(groupKey, visible);
+}
+
 DWIDGET_END_NAMESPACE
