@@ -2,7 +2,7 @@
  * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -36,10 +36,15 @@ public:
     ~DSettingsDialog();
 
     DSettingsWidgetFactory* widgetFactory() const;
+    bool groupIsVisible(const QString &groupKey) const;
+    void setResetVisible(bool visible);
+    void scrollToGroup(const QString &groupKey); //需要在对话框 show 以后使用
+    void setIcon(const QIcon &icon);
 
 public Q_SLOTS:
     void updateSettings(DTK_CORE_NAMESPACE::DSettings *settings);
     void updateSettings(const QByteArray &translateContext, DTK_CORE_NAMESPACE::DSettings *settings);
+    void setGroupVisible(const QString &groupKey, bool visible);
 
 private:
     QScopedPointer<DSettingsDialogPrivate> dd_ptr;
