@@ -2,7 +2,7 @@
  * Copyright (C) 2016 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -30,15 +30,87 @@
 #include <QRadioButton>
 #include <QGroupBox>
 #include <QCoreApplication>
+#include <QFormLayout>
 
 #include <DSettingsOption>
+#include <DSwitchButton>
+#include <DFontSizeManager>
+#include <DKeySequenceEdit>
+#include <DSuggestButton>
+#include <DButtonBox>
+#include <DTipLabel>
+#include <DDialog>
 
 #include "private/settings/shortcutedit.h"
 #include "private/settings/buttongroup.h"
 #include "private/settings/combobox.h"
+#include "private/settings/contenttitle.h"
 
 DWIDGET_BEGIN_NAMESPACE
 
+#define SHORTCUT_VALUE "shortcut_null"
+
+class DSettingsWidgetFactoryPrivate;
+
+class KeySequenceEdit : public DKeySequenceEdit
+{
+public:
+    KeySequenceEdit(DTK_CORE_NAMESPACE::DSettingsOption *opt, QWidget *parent = nullptr)
+        : DKeySequenceEdit(parent)
+    {
+        m_poption = opt;
+    }
+    DTK_CORE_NAMESPACE::DSettingsOption *option()
+    {
+        return m_poption;
+    }
+private:
+    DTK_CORE_NAMESPACE::DSettingsOption *m_poption = nullptr;
+};
+
+static QMap<QString, KeySequenceEdit *> shortcutMap;
+
+class ChangeDDialog : public DDialog
+{
+public:
+    ChangeDDialog(QString key, KeySequenceEdit *edit, QString text = QString())
+    {
+        QPushButton *cancel = new QPushButton(qApp->translate("DSettingsDialog", "Cancel"));
+        DSuggestButton *replace = new DSuggestButton(qApp->translate("DSettingsDialog", "Replace"));
+
+        QString str = qApp->translate("DSettingsDialog", "This shortcut conflicts with %1, click on Add to make this shortcut effective immediately")
+                      .arg(QString("<span style=\"color: rgba(255, 90, 90, 1);\">%1 %2</span>").arg(text).arg(QString("[%1]").arg(edit->getKeySequence(key))));
+        setMessage(str);
+        insertButton(1, cancel);
+        insertButton(1, replace);
+        connect(replace, &DSuggestButton::clicked, [ = ] {  //替换
+            auto value = shortcutMap.value(key);
+            value->option()->setValue(SHORTCUT_VALUE);
+            shortcutMap.remove(key);
+
+            edit->option()->setValue(key);
+        });
+        connect(cancel, &QPushButton::clicked, [ = ] {  //取消
+            cancelSettings(edit);
+        });
+        connect(this, &DDialog::closed, [ = ] {
+            cancelSettings(edit);
+        });
+        connect(this, &DDialog::rejected, [ = ] {
+            cancelSettings(edit);
+        });
+    }
+private:
+    void cancelSettings(KeySequenceEdit *edit)
+    {
+        if (shortcutMap.key(edit).isEmpty()) {  //第一次被设置
+            edit->clear();
+        } else {
+            edit->setKeySequence(edit->option()->value().toString());
+        }
+    }
+};
+
 /*!
  * \~chinese \class DSettingsWidgetFactory
  * \~chinese \brief DSettingsWidgetFactory是一个用于构造Deepin风格的设置对话框的控件。\n
@@ -87,132 +159,116 @@ QWidget *DSettingsWidgetFactory::createTwoColumWidget(DTK_CORE_NAMESPACE::DSetti
  */
 QWidget *DSettingsWidgetFactory::createTwoColumWidget(const QByteArray &translateContext, DTK_CORE_NAMESPACE::DSettingsOption *option, QWidget *rightWidget)
 {
-    auto optionFrame = new QFrame;
-    optionFrame->setMinimumHeight(30);
+    auto optionFrame = new QWidget;
     optionFrame->setObjectName("OptionFrame");
-//    optionFrame->setStyleSheet("QFrame{border: 1px solid red;}");
 
-    auto optionLayout = new QGridLayout(optionFrame);
+    auto optionLayout = new QFormLayout(optionFrame);
     optionLayout->setContentsMargins(0, 0, 0, 0);
     optionLayout->setSpacing(0);
 
     rightWidget->setMinimumWidth(240);
 
     if (!option->name().isEmpty()) {
-        optionLayout->setColumnMinimumWidth(0, 110);
-        optionLayout->setHorizontalSpacing(20);
-        optionLayout->setColumnStretch(0, 10);
-        optionLayout->setColumnStretch(1, 100);
-
         auto trName = DWIDGET_NAMESPACE::tr(translateContext, option->name().toStdString().c_str());
-        auto labelWidget = new QLabel(trName);
-        labelWidget->setContentsMargins(5, 0, 0, 0);
-        labelWidget->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
-        labelWidget->setMinimumWidth(150);
-        labelWidget->setFixedWidth(160);
-        labelWidget->setObjectName("OptionLabel");
-        optionLayout->addWidget(labelWidget, 0, 0, Qt::AlignLeft | Qt::AlignVCenter);
-        optionLayout->addWidget(rightWidget, 0, 1, Qt::AlignLeft | Qt::AlignVCenter);
+        optionLayout->addRow(trName, rightWidget);
     } else {
-        optionLayout->setColumnMinimumWidth(0, 5);
-        optionLayout->addWidget(rightWidget, 0, 1, Qt::AlignLeft | Qt::AlignVCenter);
+        optionLayout->addWidget(rightWidget);
     }
 
     return  optionFrame;
 }
 
-QWidget *createShortcutEditOptionHandle(QObject *opt)
+QPair<QWidget *, QWidget *> DSettingsWidgetFactory::createStandardItem(const QByteArray &translateContext, Core::DSettingsOption *option, QWidget *rightWidget)
 {
-    auto option = qobject_cast<DTK_CORE_NAMESPACE::DSettingsOption *>(opt);
+    const QString label(DWIDGET_NAMESPACE::tr(translateContext, option->name().toLocal8Bit().constData()));
 
-    auto rightWidget = new ShortcutEdit();
-    rightWidget->setObjectName("OptionShortcutEdit");
+    if (label.isEmpty())
+        return qMakePair(nullptr, rightWidget);
 
-    auto updateWidgetValue = [rightWidget](const QVariant & optionValue) {
-        switch (optionValue.type()) {
-        case QVariant::List:
-        case QVariant::StringList: {
-            QStringList keyseqs = optionValue.toStringList();
-            if (keyseqs.length() == 2) {
-                auto modifier = static_cast<Qt::KeyboardModifiers>(keyseqs.value(0).toInt());
-                auto key = static_cast<Qt::Key>(keyseqs.value(1).toInt());
-                rightWidget->setShortCut(modifier, key);
-            }
-            break;
-        }
-        case QVariant::String: {
-            rightWidget->setShortCut(optionValue.toString());
-            break;
-        }
-        default:
-            qCritical() << "unknown variant type" << optionValue;
-        }
-    };
-
-    auto optionValue = option->value();
-    updateWidgetValue(optionValue);
-
-    auto translateContext = opt->property(PRIVATE_PROPERTY_translateContext).toByteArray();
-    auto optionWidget = DSettingsWidgetFactory::createTwoColumWidget(translateContext, option, rightWidget);
-
-    // keep raw value type
-    switch (optionValue.type()) {
-    case QVariant::List:
-    case QVariant::StringList: {
-        option->connect(rightWidget, &ShortcutEdit::shortcutChanged,
-        option, [ = ](Qt::KeyboardModifiers modifier, Qt::Key key) {
-            QStringList keyseqs;
-            keyseqs << QString("%1").arg(modifier) << QString("%1").arg(key);
-            option->setValue(keyseqs);
-        });
-        break;
-    }
-    case QVariant::String: {
-        option->connect(rightWidget, &ShortcutEdit::shortcutStringChanged,
-        option, [ = ](const QString & seqString) {
-            option->setValue(seqString);
-        });
-        break;
-    }
-    default:
-        qCritical() << "unknown variant type" << optionValue;
-    }
-
-    option->connect(option, &DTK_CORE_NAMESPACE::DSettingsOption::valueChanged,
-    rightWidget, [ = ](const QVariant & value) {
-        updateWidgetValue(value);
-        rightWidget->update();
-    });
-
-    return  optionWidget;
+    return qMakePair(new QLabel(label), rightWidget);
 }
 
-QWidget *createCheckboxOptionHandle(QObject *opt)
+QPair<QWidget *, QWidget *> createShortcutEditOptionHandle(DSettingsWidgetFactoryPrivate *p, QObject *opt)
+{
+    static DSettingsWidgetFactoryPrivate *pFlg = nullptr;
+    if (pFlg != p) {
+        shortcutMap.clear();
+        pFlg = p;
+    }
+
+    auto option = qobject_cast<DTK_CORE_NAMESPACE::DSettingsOption *>(opt);
+    auto rightWidget = new KeySequenceEdit(option);
+
+    rightWidget->setObjectName("OptionShortcutEdit");
+    rightWidget->ShortcutDirection(Qt::AlignLeft);
+
+    auto optionValue = option->value();
+    auto translateContext = opt->property(PRIVATE_PROPERTY_translateContext).toByteArray();
+
+    option->connect(rightWidget, &KeySequenceEdit::editingFinished, [ = ](const QKeySequence & sequence) {
+
+        QString keyseq = sequence.toString();
+        if (shortcutMap.value(sequence.toString()) == rightWidget) //键位于自己相同
+            return;
+
+        if (shortcutMap.value(keyseq)) {
+            ChangeDDialog frame(keyseq, rightWidget, rightWidget->text());
+            frame.exec();
+        } else {
+            shortcutMap.remove(shortcutMap.key(rightWidget));
+            shortcutMap.insert(keyseq, rightWidget);
+            option->setValue(keyseq);
+        }
+    });
+
+    auto updateWidgetValue = [ = ](const QVariant & optionValue, DTK_CORE_NAMESPACE::DSettingsOption * opt) {
+        QKeySequence sequence(optionValue.toString());
+        QString keyseq = sequence.toString();
+
+        if (shortcutMap.value(keyseq)) {
+            return;
+        }
+
+        if (rightWidget->setKeySequence(sequence)) {
+            shortcutMap.insert(keyseq, rightWidget);
+            opt->setValue(keyseq);
+        }
+    };
+    updateWidgetValue(optionValue, option);
+
+    option->connect(option, &DTK_CORE_NAMESPACE::DSettingsOption::valueChanged, rightWidget, [ = ](const QVariant & value) {
+
+        if (value.toString() == SHORTCUT_VALUE) {
+            rightWidget->clear();
+            return;
+        }
+        QKeySequence sequence(value.toString());
+        QString keyseq = sequence.toString();
+
+        shortcutMap.remove(shortcutMap.key(rightWidget));
+
+        if (rightWidget->setKeySequence(sequence)) {    //设置快捷键
+
+            shortcutMap.insert(keyseq, rightWidget);
+            option->setValue(keyseq);
+        }
+    });
+
+    return DSettingsWidgetFactory::createStandardItem(translateContext, option, rightWidget);
+}
+
+QPair<QWidget *, QWidget *> createCheckboxOptionHandle(QObject *opt)
 {
     auto translateContext = opt->property(PRIVATE_PROPERTY_translateContext).toByteArray();
     auto option = qobject_cast<DTK_CORE_NAMESPACE::DSettingsOption *>(opt);
     auto value = option->data("text").toString();
     auto trName = DWIDGET_NAMESPACE::tr(translateContext, value.toStdString().c_str());
 
-//    auto checkboxFrame = new QWidget;
-//    auto checkboxLayout = new QHBoxLayout(checkboxFrame);
-//    checkboxLayout->setSpacing(0);
-//    checkboxLayout->setContentsMargins(0, 0, 0, 0);
     auto rightWidget = new QCheckBox(trName);
-//    auto checkboxLabel = new QLabel(trName);
-//    checkboxLabel->setWordWrap(true);
-//    checkboxLabel->setMinimumWidth(320);
-//    checkboxLayout->addWidget(rightWidget);
-//    checkboxLayout->addSpacing(5);
-//    checkboxLayout->addWidget(checkboxLabel);
-//    checkboxLayout->addStretch();
 
-    rightWidget->setMinimumHeight(30);
     rightWidget->setObjectName("OptionCheckbox");
     rightWidget->setChecked(option->value().toBool());
 
-//    auto optionWidget = DSettingsWidgetFactory::createTwoColumWidget(translateContext, option, checkboxFrame);
-
     option->connect(rightWidget, &QCheckBox::stateChanged,
     option, [ = ](int status) {
         option->setValue(status == Qt::Checked);
@@ -223,23 +279,19 @@ QWidget *createCheckboxOptionHandle(QObject *opt)
         rightWidget->update();
     });
 
-    return rightWidget;
-//    return  optionWidget;
+    return qMakePair(rightWidget, nullptr);
 }
 
-QWidget *createLineEditOptionHandle(QObject *opt)
+QPair<QWidget *, QWidget *> createLineEditOptionHandle(QObject *opt)
 {
     auto translateContext = opt->property(PRIVATE_PROPERTY_translateContext).toByteArray();
     auto option = qobject_cast<DTK_CORE_NAMESPACE::DSettingsOption *>(opt);
     auto value = option->data("text").toString();
     auto trName = DWIDGET_NAMESPACE::tr(translateContext, value.toStdString().c_str());
     auto rightWidget = new QLineEdit(trName);
-    rightWidget->setFixedHeight(24);
     rightWidget->setObjectName("OptionLineEdit");
     rightWidget->setText(option->value().toString());
 
-    auto optionWidget = DSettingsWidgetFactory::createTwoColumWidget(translateContext, option, rightWidget);
-
     option->connect(rightWidget, &QLineEdit::editingFinished,
     option, [ = ]() {
         option->setValue(rightWidget->text());
@@ -250,18 +302,16 @@ QWidget *createLineEditOptionHandle(QObject *opt)
         rightWidget->update();
     });
 
-    return  optionWidget;
+    return DSettingsWidgetFactory::createStandardItem(translateContext, option, rightWidget);
 }
 
-QWidget *createComboBoxOptionHandle(QObject *opt)
+QPair<QWidget *, QWidget *> createComboBoxOptionHandle(QObject *opt)
 {
     auto translateContext = opt->property(PRIVATE_PROPERTY_translateContext).toByteArray();
     auto option = qobject_cast<DTK_CORE_NAMESPACE::DSettingsOption *>(opt);
     auto rightWidget = new ComboBox();
     rightWidget->setFocusPolicy(Qt::StrongFocus);
-    rightWidget->setFixedHeight(24);
     rightWidget->setObjectName("OptionLineEdit");
-    auto optionWidget = DSettingsWidgetFactory::createTwoColumWidget(translateContext, option, rightWidget);
 
     auto initComboxList = [ = ](const QStringList & data) {
         for (auto item : data) {
@@ -329,37 +379,42 @@ QWidget *createComboBoxOptionHandle(QObject *opt)
         updateData(dataType, value);
     });
 
-    return  optionWidget;
+    return DSettingsWidgetFactory::createStandardItem(translateContext, option, rightWidget);
 }
 
-QWidget *createButtonGroupOptionHandle(QObject *opt)
+QPair<QWidget *, QWidget *> createButtonGroupOptionHandle(QObject *opt)
 {
-    auto option = qobject_cast<DTK_CORE_NAMESPACE::DSettingsOption *>(opt);
-    auto rightWidget = new ButtonGroup();
-    rightWidget->setFixedHeight(24);
-    rightWidget->setObjectName("OptionButtonGroup");
+    QList<DButtonBoxButton *> btnList;
 
+    auto option = qobject_cast<DTK_CORE_NAMESPACE::DSettingsOption *>(opt);
     auto items = option->data("items").toStringList();
-    rightWidget->setButtons(items);
-    rightWidget->setCheckedButton(0);
+    for (const auto item : items) {
+        auto btn = new DButtonBoxButton(item);
+        btnList.append(btn);
+    }
+
+    auto rightWidget = new DButtonBox();
+    rightWidget->setObjectName("OptionButtonBox");
+    rightWidget->setButtonList(btnList, true);
+    rightWidget->setMaximumWidth(60 * btnList.count());
+    btnList.at(option->value().toInt())->setChecked(true);
 
     auto translateContext = opt->property(PRIVATE_PROPERTY_translateContext).toByteArray();
-    auto optionWidget = DSettingsWidgetFactory::createTwoColumWidget(translateContext, option, rightWidget);
-    rightWidget->setParent(optionWidget);
-
-    option->connect(rightWidget, &ButtonGroup::buttonChecked,
-    option, [ = ](int id) {
-        option->setValue(id);
+    option->connect(rightWidget, &DButtonBox::buttonClicked, option, [option, rightWidget ] (QAbstractButton * btn) {
+        int index = rightWidget->buttonList().indexOf(btn);
+        option->setValue(index);
     });
     option->connect(option, &DTK_CORE_NAMESPACE::DSettingsOption::valueChanged,
-    rightWidget, [ = ](const QVariant & value) {
-        rightWidget->setCheckedButton(value.toInt());
+                    rightWidget, [ = ](const QVariant & value) {
+        int index = value.toInt();
+        btnList.at(index)->setChecked(true);
         rightWidget->update();
     });
-    return  optionWidget;
+
+    return DSettingsWidgetFactory::createStandardItem(translateContext, option, rightWidget);
 }
 
-QWidget *createRadioGroupOptionHandle(QObject *opt)
+QPair<QWidget *, QWidget *> createRadioGroupOptionHandle(QObject *opt)
 {
     auto translateContext = opt->property(PRIVATE_PROPERTY_translateContext).toByteArray();
     auto option = qobject_cast<DTK_CORE_NAMESPACE::DSettingsOption *>(opt);
@@ -369,7 +424,8 @@ QWidget *createRadioGroupOptionHandle(QObject *opt)
     rightWidget->setContentsMargins(0, 0, 0, 0);
     rightWidget->setObjectName("OptionRadioGroup");
     rightWidget->setAlignment(Qt::AlignLeft);
-    rightWidget->setFixedHeight(24 * items.length() + 8);
+    rightWidget->setFlat(true);
+    rightWidget->setMinimumHeight(24 * items.length() + 8);
 
     auto rgLayout = new QVBoxLayout;
     rgLayout->setContentsMargins(0, 0, 0, 0);
@@ -377,7 +433,8 @@ QWidget *createRadioGroupOptionHandle(QObject *opt)
     QList<QRadioButton *> buttonList;
     for (auto item : items)  {
         auto rb = new QRadioButton(DWIDGET_NAMESPACE::tr(translateContext, item.toStdString().c_str()));
-        rb->setFixedHeight(24);
+        // fix 加大字体后显示截断，不应该 fixedheight
+        rb->setMinimumHeight(24);
         rb->setProperty("_dtk_widget_settings_radiogroup_index", index);
         rgLayout->addWidget(rb);
         ++index;
@@ -391,9 +448,6 @@ QWidget *createRadioGroupOptionHandle(QObject *opt)
     }
     rightWidget->setLayout(rgLayout);
 
-//    auto optionWidget = DSettingsWidgetFactory::createTwoColumWidget(translateContext, option, rightWidget);
-//    rightWidget->setParent(optionWidget);
-
     option->connect(option, &DTK_CORE_NAMESPACE::DSettingsOption::valueChanged,
     rightWidget, [ buttonList ](const QVariant & value) {
         auto index = value.toInt();
@@ -407,17 +461,14 @@ QWidget *createRadioGroupOptionHandle(QObject *opt)
         buttonList.value(index)->setChecked(true);
     }
 
-    rightWidget->setStyleSheet("QGroupBox{border: 0px solid red;}");
-//    optionWidget->setFixedHeight(24 * items.length() + 8);
-//    return  optionWidget;
-    return rightWidget;
+    return qMakePair(rightWidget, nullptr);
 }
 
-QWidget *createSpinButtonOptionHandle(QObject *opt)
+QPair<QWidget *, QWidget *> createSpinButtonOptionHandle(QObject *opt)
 {
     auto option = qobject_cast<DTK_CORE_NAMESPACE::DSettingsOption *>(opt);
     auto rightWidget = new QSpinBox();
-    rightWidget->setFixedHeight(24);
+    rightWidget->setButtonSymbols(QAbstractSpinBox::PlusMinus);
     rightWidget->setObjectName("OptionDSpinBox");
     rightWidget->setValue(option->value().toInt());
 
@@ -429,7 +480,6 @@ QWidget *createSpinButtonOptionHandle(QObject *opt)
     }
 
     auto translateContext = opt->property(PRIVATE_PROPERTY_translateContext).toByteArray();
-    auto optionWidget = DSettingsWidgetFactory::createTwoColumWidget(translateContext, option, rightWidget);
 
     option->connect(rightWidget, static_cast<void (QSpinBox::*)(int value)>(&QSpinBox::valueChanged),
     option, [ = ](int value) {
@@ -440,14 +490,14 @@ QWidget *createSpinButtonOptionHandle(QObject *opt)
         rightWidget->setValue(value.toInt());
         rightWidget->update();
     });
-    return  optionWidget;
+
+    return DSettingsWidgetFactory::createStandardItem(translateContext, option, rightWidget);
 }
 
-QWidget *createSliderOptionHandle(QObject *opt)
+QPair<QWidget *, QWidget *> createSliderOptionHandle(QObject *opt)
 {
     auto option = qobject_cast<DTK_CORE_NAMESPACE::DSettingsOption *>(opt);
     auto rightWidget = new QSlider();
-    rightWidget->setFixedHeight(24);
     rightWidget->setObjectName("OptionQSlider");
     rightWidget->setOrientation(Qt::Horizontal);
     rightWidget->setMaximum(option->data("max").toInt());
@@ -455,7 +505,6 @@ QWidget *createSliderOptionHandle(QObject *opt)
     rightWidget->setValue(option->value().toInt());
 
     auto translateContext = opt->property(PRIVATE_PROPERTY_translateContext).toByteArray();
-    auto optionWidget = DSettingsWidgetFactory::createTwoColumWidget(translateContext, option, rightWidget);
 
     option->connect(rightWidget, &QSlider::valueChanged,
     option, [ = ](int value) {
@@ -468,7 +517,64 @@ QWidget *createSliderOptionHandle(QObject *opt)
         rightWidget->setValue(value.toInt());
         rightWidget->update();
     });
-    return  optionWidget;
+
+    return DSettingsWidgetFactory::createStandardItem(translateContext, option, rightWidget);
+}
+
+QPair<QWidget *, QWidget *> createSwitchButton(QObject *opt)
+{
+    auto option = qobject_cast<DTK_CORE_NAMESPACE::DSettingsOption *>(opt);
+    auto rightWidget = new DSwitchButton();
+    rightWidget->setObjectName("OptionDSwitchButton");
+    rightWidget->setChecked(option->value().toBool());
+
+    auto translateContext = opt->property(PRIVATE_PROPERTY_translateContext).toByteArray();
+
+    option->connect(rightWidget, &DSwitchButton::checkedChanged,
+    option, [ = ](bool value) {
+        rightWidget->blockSignals(true);
+        option->setValue(value);
+        rightWidget->blockSignals(false);
+    });
+    option->connect(option, &DTK_CORE_NAMESPACE::DSettingsOption::valueChanged,
+    rightWidget, [ = ](const QVariant & value) {
+        rightWidget->setChecked(value.toBool());
+        rightWidget->update();
+    });
+
+    QWidget *widget = new  QWidget();
+    QHBoxLayout *layout = new QHBoxLayout(widget);
+    layout->setContentsMargins(0, 0, 0, 0);
+    layout->addWidget(rightWidget, 0, Qt::AlignRight);
+
+    return DSettingsWidgetFactory::createStandardItem(translateContext, option, widget);
+}
+
+QPair<QWidget *, QWidget *> createTitle1(QObject *opt)
+{
+    auto option = qobject_cast<DTK_CORE_NAMESPACE::DSettingsOption *>(opt);
+    auto translateContext = opt->property(PRIVATE_PROPERTY_translateContext).toByteArray();
+    auto trName = DWIDGET_NAMESPACE::tr(translateContext, option->value().toString().toLocal8Bit().constData());
+
+    auto title = new ContentTitle;
+    title->setTitle(trName);
+    title->label()->setForegroundRole(QPalette::BrightText);
+    DFontSizeManager::instance()->bind(title, DFontSizeManager::T4, QFont::Medium);
+
+    return qMakePair(title, nullptr);
+}
+
+QPair<QWidget *, QWidget *> createTitle2(QObject *opt)
+{
+    auto option = qobject_cast<DTK_CORE_NAMESPACE::DSettingsOption *>(opt);
+    auto translateContext = opt->property(PRIVATE_PROPERTY_translateContext).toByteArray();
+    auto trName = DWIDGET_NAMESPACE::tr(translateContext, option->value().toString().toLocal8Bit().constData());
+
+    auto title = new ContentTitle;
+    title->setTitle(trName);
+    DFontSizeManager::instance()->bind(title, DFontSizeManager::T5, QFont::Medium);
+
+    return qMakePair(title, nullptr);
 }
 
 QWidget *createUnsupportHandle(QObject *opt)
@@ -478,12 +584,9 @@ QWidget *createUnsupportHandle(QObject *opt)
     rightWidget->setFixedHeight(24);
     rightWidget->setObjectName("OptionUnsupport");
     rightWidget->setText("Unsupport option type: " + option->viewType());
+    rightWidget->setWordWrap(true);
 
-    auto translateContext = opt->property(PRIVATE_PROPERTY_translateContext).toByteArray();
-    auto optionWidget = DSettingsWidgetFactory::createTwoColumWidget(translateContext, option, rightWidget);
-
-//    optionWidget->setStyleSheet("QFrame{border: 1px solid red;}");
-    return  optionWidget;
+    return  rightWidget;
 }
 
 class DSettingsWidgetFactoryPrivate
@@ -491,17 +594,21 @@ class DSettingsWidgetFactoryPrivate
 public:
     DSettingsWidgetFactoryPrivate(DSettingsWidgetFactory *parent) : q_ptr(parent)
     {
-        widgetCreateHandles.insert("checkbox", createCheckboxOptionHandle);
-        widgetCreateHandles.insert("lineedit", createLineEditOptionHandle);
-        widgetCreateHandles.insert("combobox", createComboBoxOptionHandle);
-        widgetCreateHandles.insert("shortcut", createShortcutEditOptionHandle);
-        widgetCreateHandles.insert("spinbutton", createSpinButtonOptionHandle);
-        widgetCreateHandles.insert("buttongroup", createButtonGroupOptionHandle);
-        widgetCreateHandles.insert("radiogroup", createRadioGroupOptionHandle);
-        widgetCreateHandles.insert("slider", createSliderOptionHandle);
+        itemCreateHandles.insert("checkbox", createCheckboxOptionHandle);
+        itemCreateHandles.insert("lineedit", createLineEditOptionHandle);
+        itemCreateHandles.insert("combobox", createComboBoxOptionHandle);
+        itemCreateHandles.insert("shortcut", std::bind(createShortcutEditOptionHandle, this, std::placeholders::_1));
+        itemCreateHandles.insert("spinbutton", createSpinButtonOptionHandle);
+        itemCreateHandles.insert("buttongroup", createButtonGroupOptionHandle);
+        itemCreateHandles.insert("radiogroup", createRadioGroupOptionHandle);
+        itemCreateHandles.insert("slider", createSliderOptionHandle);
+        itemCreateHandles.insert("switchbutton", createSwitchButton);
+        itemCreateHandles.insert("title1", createTitle1);
+        itemCreateHandles.insert("title2", createTitle2);
     }
 
     QMap<QString, std::function<DSettingsWidgetFactory::WidgetCreateHandler> > widgetCreateHandles;
+    QMap<QString, std::function<DSettingsWidgetFactory::ItemCreateHandler> > itemCreateHandles;
 
     DSettingsWidgetFactory *q_ptr;
     Q_DECLARE_PUBLIC(DSettingsWidgetFactory)
@@ -529,6 +636,12 @@ void DSettingsWidgetFactory::registerWidget(const QString &viewType, std::functi
     d->widgetCreateHandles.insert(viewType, handler);
 }
 
+void DSettingsWidgetFactory::registerWidget(const QString &viewType, std::function<DSettingsWidgetFactory::ItemCreateHandler> handler)
+{
+    Q_D(DSettingsWidgetFactory);
+    d->itemCreateHandles.insert(viewType, handler);
+}
+
 /*!
  * \~chinese \brief DSettingsWidgetFactory::createWidget 创建一个option对应的配置控件，一般是需要自定义控件时使用，可以通过translateContext设置翻译上下文。
  * \~chinese \param option 需要构建的配置项
@@ -559,4 +672,22 @@ QWidget *DSettingsWidgetFactory::createWidget(const QByteArray &translateContext
     }
 }
 
+QPair<QWidget *, QWidget *> DSettingsWidgetFactory::createItem(QPointer<Core::DSettingsOption> option) const
+{
+    return createItem(QByteArray(), option);
+}
+
+QPair<QWidget *, QWidget *> DSettingsWidgetFactory::createItem(const QByteArray &translateContext, QPointer<Core::DSettingsOption> option) const
+{
+    option->setProperty(PRIVATE_PROPERTY_translateContext, translateContext);
+
+    Q_D(const DSettingsWidgetFactory);
+    auto handle = d->itemCreateHandles.value(option->viewType());
+    if (handle) {
+        return handle(option.data());
+    }
+
+    return qMakePair(nullptr, nullptr);
+}
+
 DWIDGET_END_NAMESPACE
