@@ -2,7 +2,9 @@
 
 #include <QtMath>
 #include <QPainter>
+#include <QPainterPath>
 #include <QTimer>
+#include <QEvent>
 
 #include <DObjectPrivate>
 
@@ -62,10 +64,6 @@ DSpinner::DSpinner(QWidget *parent) :
 {
     Q_D(DSpinner);
 
-    d->indicatorColors << d->createDefaultIndicatorColorList(QColor(200, 46, 255));
-    d->indicatorColors << d->createDefaultIndicatorColorList(QColor(207, 225, 0));
-    d->indicatorColors << d->createDefaultIndicatorColorList(QColor(0, 255, 241));
-
     d->refreshTimer.setInterval(30);
 
     connect(&d->refreshTimer, &QTimer::timeout,
@@ -126,6 +124,11 @@ void DSpinner::paintEvent(QPaintEvent *)
 {
     Q_D(DSpinner);
 
+    if (d->indicatorColors.isEmpty()) {
+        for (int i = 0; i < 3; ++i)
+            d->indicatorColors << d->createDefaultIndicatorColorList(palette().highlight().color());
+    }
+
     QPainter painter(this);
     painter.setRenderHints(QPainter::Antialiasing);
 
@@ -156,6 +159,16 @@ void DSpinner::paintEvent(QPaintEvent *)
     }
 }
 
+void DSpinner::changeEvent(QEvent *e)
+{
+    Q_D(DSpinner);
+
+    if (e->type() == QEvent::PaletteChange)
+        d->indicatorColors.clear();
+
+    QWidget::changeEvent(e);
+}
+
 QList<QColor> DSpinnerPrivate::createDefaultIndicatorColorList(QColor color)
 {
     QList<QColor> colors;
