@@ -6,7 +6,7 @@
  * Maintainer: zccrs <zhangjide@deepin.com>
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -15,13 +15,14 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #ifndef DSTYLEOPTION_H
 #define DSTYLEOPTION_H
 
 #include <dtkwidget_global.h>
+#include <DPalette>
 
 #include <QStyleOption>
 
@@ -29,26 +30,68 @@ QT_BEGIN_NAMESPACE
 class QGuiApplication;
 QT_END_NAMESPACE
 
+DGUI_USE_NAMESPACE
+
+DTK_BEGIN_NAMESPACE
+
+enum ItemDataRole {
+    MarginsRole = Qt::UserRole + 1,
+    LeftActionListRole,
+    TopActionListRole,
+    RightActionListRole,
+    BottomActionListRole,
+    TextActionListRole,
+    ViewItemFontLevelRole,
+    ViewItemBackgroundRole,
+    ViewItemForegroundRole,
+    UserRole = Qt::UserRole << 2
+};
+
+DTK_END_NAMESPACE
+
 DWIDGET_BEGIN_NAMESPACE
 
 class DStyleOption
 {
 public:
-    enum PrimitiveElement {
-        PE_BACKGROUND = QStyle::PE_CustomBase + 1,
+    enum OptionType {
+        SO_HighlightButton = QStyleOption::SO_CustomBase + 1,
+        SO_CustomBase = QStyleOption::SO_CustomBase << 2
     };
 
     virtual void init(QWidget *widget);
+    virtual void init(const QWidget *widget);
+
+    DPalette dpalette;
 };
 
-class DStyleOptionSuggestButton : public QStyleOptionButton, public DStyleOption
+class DStyleOptionButton : public QStyleOptionButton, public DStyleOption
 {
 public:
     enum ButtonFeature {
-        SuggestButton = (CommandLinkButton << 1)
+        SuggestButton = (CommandLinkButton << 1),
+        WarningButton = (SuggestButton << 1),
+        FloatingButton = (WarningButton << 1),
+        TitleBarButton = (FloatingButton << 1),
+        CircleButton = (TitleBarButton << 1)
     };
 
-    void init(QWidget *widget) override;
+    void init(const QWidget *widget) override;
+};
+
+class DStyleOptionButtonBoxButton : public DStyleOptionButton
+{
+public:
+    enum ButtonPosition {
+        Invalid,
+        Beginning,
+        Middle,
+        End,
+        OnlyOne
+    };
+
+    Qt::Orientation orientation;
+    ButtonPosition position;
 };
 
 class DStyleOptionLineEdit : public DStyleOption
@@ -61,7 +104,7 @@ public:
     };
     Q_DECLARE_FLAGS(LineEditFeatures, LineEditFeature)
 
-    void init(QWidget *widget) override;
+    void init(const QWidget *widget) override;
 
     LineEditFeatures features = None;
     QRect iconButtonRect;
@@ -70,11 +113,6 @@ public:
 class DStyleOptionBackgroundGroup : public QStyleOption, public DStyleOption
 {
 public:
-    enum BackgroundDirection {
-        horizontal,
-        vertical,
-    };
-
     enum ItemBackgroundPosition {
         Invalid,
         Beginning,
@@ -85,58 +123,32 @@ public:
 
     using DStyleOption::DStyleOption;
     using QStyleOption::QStyleOption;
-    void init(QWidget *widget) override;
+    void init(const QWidget *widget) override;
 
-    BackgroundDirection direction;
+    Qt::Orientations directions;
     ItemBackgroundPosition position;
-    QRect backgroundRect;
 };
 
-class DPalettePrivate;
-class DPalette : public QPalette
+class DStyleOptionIcon : public QStyleOption, public DStyleOption
 {
 public:
-    enum ColorType {
-        ItemBackground,
-        TextTitle,
-        TextTips,
-        TextWarning,
-        TextLively,
-        NColorTypes
+    QIcon icon;
+};
+
+class DStyleOptionViewItem : public QStyleOptionViewItem, public DStyleOption
+{
+public:
+    enum ViewItemFeature {
+
     };
+};
 
-    DPalette();
-    DPalette(const QPalette &palette);
-    ~DPalette();
-
-    static DPalette get(const QWidget *widget, const QPalette &base);
-    static inline DPalette get(const QWidget *widget)
-    { return get(widget, widget->palette()); }
-
-    static void set(QWidget *widget, const DPalette &pa);
-    static void setGeneric(const DPalette &pa);
-
-    inline const QColor &color(ColorGroup cg, ColorType ct) const
-    { return brush(cg, ct).color(); }
-    const QBrush &brush(ColorGroup cg, ColorType ct) const;
-    inline void setColor(ColorGroup cg, ColorType ct, const QColor &color)
-    { setBrush(cg, ct, color); }
-    inline void setColor(ColorType ct, const QColor &color)
-    { setColor(All, ct, color); }
-    inline void setBrush(ColorType ct, const QBrush &brush)
-    { setBrush(All, ct, brush); }
-    void setBrush(ColorGroup cg, ColorType ct, const QBrush &brush);
-
-    inline const QColor &color(ColorType ct) const { return color(Current, ct); }
-    inline const QBrush &brush(ColorType ct) const { return brush(Current, ct); }
-    inline const QBrush &itemBackground() const { return brush(ItemBackground); }
-    inline const QBrush &textTiele() const { return brush(TextTitle); }
-    inline const QBrush &textTips() const { return brush(TextTips); }
-    inline const QBrush &textWarning() const { return brush(TextWarning); }
-    inline const QBrush &textLively() const { return brush(TextLively); }
-
-private:
-    QSharedPointer<DPalettePrivate> d;
+class DStyleOptionFloatingWidget : public QStyleOption, public DStyleOption
+{
+public:
+    using DStyleOption::init;
+    bool noBackground;
+    int frameRadius = -1;
 };
 
 class DFontSizeManagerPrivate;
@@ -159,12 +171,14 @@ public:
 
     static DFontSizeManager *instance();
     void bind(QWidget *widget, SizeType type);
+    void bind(QWidget *widget, SizeType type, int weight);
     void unbind(QWidget *widget);
 
     quint16 fontPixelSize(SizeType type) const;
     void setFontPixelSize(SizeType type, quint16 size);
     void setFontGenericPixelSize(quint16 size);
     const QFont get(SizeType type, const QFont &base = QFont()) const;
+    const QFont get(SizeType type, int weight, const QFont &base = QFont()) const;
 
     inline const QFont t1(const QFont &base = QFont()) const
     { return get(T1, base); }
@@ -187,6 +201,8 @@ public:
     inline const QFont t10(const QFont &base = QFont()) const
     { return get(T10, base); }
 
+    static int fontPixelSize(const QFont &font);
+
 private:
     DFontSizeManager();
 
