@@ -3,6 +3,7 @@
 
 #include <QStylePainter>
 #include <QStyleOptionButton>
+#include <DGuiApplicationHelper>
 
 DWIDGET_BEGIN_NAMESPACE
 
@@ -37,10 +38,19 @@ DSuggestButton::DSuggestButton(const QString &text, QWidget *parent)
 
 void DSuggestButton::paintEvent(QPaintEvent *event)
 {
+    Q_UNUSED(event)
     QStylePainter p(this);
-    DStyleOptionSuggestButton option;
+    DStyleOptionButton option;
     initStyleOption(&option);
     option.init(this);
+    option.features |= QStyleOptionButton::ButtonFeature(DStyleOptionButton::SuggestButton);
+
+    QColor startColor = palette().color(QPalette::Highlight);
+    QColor endColor = DGuiApplicationHelper::adjustColor(startColor, 0, 0, +10, 0, 0, 0, 0);
+
+    option.palette.setBrush(QPalette::Light, QBrush(endColor));
+    option.palette.setBrush(QPalette::Dark, QBrush(startColor));
+    option.palette.setBrush(QPalette::ButtonText, option.palette.highlightedText());
     p.drawControl(QStyle::CE_PushButton, option);
 }
 
