@@ -6,7 +6,7 @@
  * Maintainer: zccrs <zhangjide@deepin.com>
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -15,13 +15,11 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #include "dtabbar.h"
 #include "dobject_p.h"
-#include "dimagebutton.h"
-#include "dthememanager.h"
 
 #include <QPainter>
 #include <QMouseEvent>
@@ -32,7 +30,7 @@
 #include <QMimeData>
 #include <QDragMoveEvent>
 #include <QTimer>
-#include <QDebug>
+#include <QToolTip>
 
 #include <private/qtabbar_p.h>
 #define private public
@@ -44,6 +42,7 @@
 #undef protected
 
 #include "dapplication.h"
+#include "diconbutton.h"
 
 DWIDGET_BEGIN_NAMESPACE
 
@@ -89,26 +88,6 @@ void DMovableTabWidget::paintEvent(QPaintEvent *e)
     pa.drawPixmap(0, 0, m_pixmap);
 }
 
-class DTabBarAddButton : public QToolButton
-{
-public:
-    explicit DTabBarAddButton(QWidget *parent)
-        : QToolButton(parent) {}
-
-private:
-    void paintEvent(QPaintEvent *event) override;
-};
-
-void DTabBarAddButton::paintEvent(QPaintEvent *event)
-{
-    Q_UNUSED(event)
-
-    QStylePainter p(this);
-    QStyleOptionToolButton opt;
-    initStyleOption(&opt);
-    p.drawControl(static_cast<QStyle::ControlElement>(QStyle::CE_CustomBase + 1), opt);
-}
-
 class DTabBarPrivate : public QTabBar, public DObjectPrivate
 {
     Q_OBJECT
@@ -121,12 +100,10 @@ public:
         startDragDistance = qApp->startDragDistance();
         maskColor = flashColor = QColor(0, 0, 255, 125);
 
-        addButton = new DTabBarAddButton(qq);
+        addButton = new DIconButton(DStyle::SP_IncreaseElement, qq);
         addButton->setObjectName("AddButton");
-        addButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
-        addButton->setFixedWidth(48);
 
-        connect(addButton, &DTabBarAddButton::clicked,
+        connect(addButton, &DIconButton::clicked,
                 qq, &DTabBar::tabAddRequested);
         connect(this, &QTabBar::tabMoved, this, [this] (int from, int to) {
             tabMinimumSize.move(from, to);
@@ -141,49 +118,72 @@ public:
         });
 
         setAcceptDrops(true);
-        setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Expanding);
+        setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Fixed);
+        setDrawBase(false);
 
         QTabBarPrivate *d = reinterpret_cast<QTabBarPrivate *>(qGetPtrHelper(d_ptr));
 
-        leftScrollButton = new QToolButton(qq);
-        rightScrollButton = new QToolButton(qq);
+        leftScrollButton = new DIconButton(DStyle::SP_ArrowLeft, qq);
+        leftScrollButton->setObjectName("leftButton");
+        rightScrollButton = new DIconButton(DStyle::SP_ArrowRight, qq);
+        rightScrollButton->setObjectName("rightButton");
 
         leftScrollButton->setVisible(d->leftB->isVisible());
         leftScrollButton->setAutoRepeat(true);
-        leftScrollButton->setArrowType(Qt::LeftArrow);
-        leftScrollButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
         rightScrollButton->setVisible(d->rightB->isVisible());
         rightScrollButton->setAutoRepeat(true);
-        rightScrollButton->setArrowType(Qt::RightArrow);
-        rightScrollButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
 
         d->leftB->setFixedSize(0, 0);
         d->leftB->installEventFilter(this);
         d->rightB->setFixedSize(0, 0);
         d->rightB->installEventFilter(this);
 
-        connect(leftScrollButton, &QToolButton::clicked, d->leftB, &QToolButton::click);
-        connect(rightScrollButton, &QToolButton::clicked, d->rightB, &QToolButton::click);
+        connect(leftScrollButton, &DIconButton::clicked, d->leftB, &QToolButton::click);
+        connect(rightScrollButton, &DIconButton::clicked, d->rightB, &QToolButton::click);
 
-        QHBoxLayout *layout = new QHBoxLayout(qq);
-
-        layout->setContentsMargins(0, 0, 0, 0);
+        layout = new QHBoxLayout(qq);
+        layout->setMargin(0);
         layout->setSpacing(0);
-        layout->addWidget(leftScrollButton);
-        layout->addWidget(rightScrollButton);
-        layout->addWidget(this);
-        layout->addWidget(addButton);
-        layout->addStretch();
+        stretch = new QSpacerItem(1, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);
+        leftBtnR = new QSpacerItem(0, 0);
+        leftBtnL = new QSpacerItem(0, 0);
+        rightBtnL = new QSpacerItem(0, 0);
+        addBtnL = new QSpacerItem(DStyle::pixelMetric(style(), DStyle::PM_ContentsSpacing), 0);
+        addBtnR = new QSpacerItem(DStyle::pixelMetric(style(), DStyle::PM_ContentsSpacing), 0);
 
+        layout->addSpacerItem(leftBtnL);
+        layout->setContentsMargins(0, 0, 0, 0);
+        layout->addWidget(leftScrollButton);
+
+        layout->addSpacerItem(leftBtnR);
+        layout->addWidget(this);
+        layout->addSpacerItem(rightBtnL);
+
+        layout->addWidget(rightScrollButton);
+        layout->addSpacerItem(addBtnL);
+        layout->addWidget(addButton, Qt::AlignCenter);
+
+        layout->addSpacerItem(addBtnR);
+        layout->addSpacerItem(stretch);
+        d->expanding = false;
+
+        qq->setTabLabelAlignment(Qt::AlignCenter);
         qq->setFocusProxy(this);
 
-        connect(this, &DTabBarPrivate::currentChanged, qq, &DTabBar::currentChanged);
+        connect(this, &DTabBarPrivate::currentChanged, this, &DTabBarPrivate::onCurrentChanged);
         connect(this, &DTabBarPrivate::tabCloseRequested, qq, &DTabBar::tabCloseRequested);
         connect(this, &DTabBarPrivate::tabMoved, qq, &DTabBar::tabMoved);
         connect(this, &DTabBarPrivate::tabBarClicked, qq, &DTabBar::tabBarClicked);
         connect(this, &DTabBarPrivate::tabBarDoubleClicked, qq, &DTabBar::tabBarDoubleClicked);
     }
 
+    ~DTabBarPrivate() override
+    {
+        if (stretchIsRemove && stretch) {
+            delete stretch;
+        }
+    }
+
     void moveTabOffset(int index, int offset)
     {
         QTabBarPrivate *d = reinterpret_cast<QTabBarPrivate *>(qGetPtrHelper(d_ptr));
@@ -220,6 +220,7 @@ public:
     };
 
     bool eventFilter(QObject *watched, QEvent *event) override;
+    bool event(QEvent *e) override;
 
     QSize minimumSizeHint() const override;
 
@@ -243,7 +244,7 @@ public:
 
      QTabBarPrivate *dd() const;
 
-    Q_SLOT void startDrag(int tabIndex);
+    Q_SLOT void startDrag();
 
     void setupMovableTab();
     void updateMoveingTabPosition(const QPoint &mouse);
@@ -262,13 +263,16 @@ public:
     void setDragingFromOther(bool v);
     int tabInsertIndexFromMouse(QPoint pos);
 
-    void startMove(int index);
+    Q_INVOKABLE void startMove(int index);
     void stopMove();
 
+    void onCurrentChanged(int current);
+    void updateCloseButtonVisible();
+
     QList<QSize> tabMinimumSize;
     QList<QSize> tabMaximumSize;
     bool visibleAddButton = true;
-    DTabBarAddButton *addButton;
+    DIconButton *addButton;
     QPointer<QDrag> drag;
     bool dragable = false;
     int startDragDistance;
@@ -279,14 +283,24 @@ public:
     // 为true忽略drag move事件
     bool ignoreDragEvent = false;
 
+    bool mousePress = false;
+    bool stretchIsRemove = false;
+
     QColor maskColor;
     QColor flashColor;
     // 要闪动绘制的Tab
     qreal opacityOnFlash = 1;
     int flashTabIndex = -1;
 
-    QToolButton *leftScrollButton;
-    QToolButton *rightScrollButton;
+    DIconButton *leftScrollButton;
+    DIconButton *rightScrollButton;
+    QHBoxLayout *layout;
+    QSpacerItem *stretch;
+    QSpacerItem *leftBtnL;
+    QSpacerItem *leftBtnR;
+    QSpacerItem *rightBtnL;
+    QSpacerItem *addBtnL;
+    QSpacerItem *addBtnR;
 
     class FullWidget : public QWidget {
     public:
@@ -310,25 +324,24 @@ public:
     int ghostTabIndex = -1;
 };
 
-void DTabBarPrivate::startDrag(int tabIndex)
+void DTabBarPrivate::startDrag()
 {
+    QTabBarPrivate *d = reinterpret_cast<QTabBarPrivate *>(qGetPtrHelper(d_ptr));
     Qt::DropAction action = drag->exec(Qt::MoveAction | Qt::CopyAction, Qt::CopyAction);
 
     Q_EMIT q_func()->dragEnd(action);
 
     if (action == Qt::IgnoreAction) {
-        Q_EMIT q_func()->tabReleaseRequested(tabIndex);
+        Q_EMIT q_func()->tabReleaseRequested(d->pressedIndex);
     } else if (drag->target() != this) {
         if (DTabBarPrivate *tbp = qobject_cast<DTabBarPrivate*>(drag->target()))
-            Q_EMIT q_func()->tabDroped(tabIndex, action, tbp->q_func());
+            Q_EMIT q_func()->tabDroped(d->pressedIndex, action, tbp->q_func());
         else
-            Q_EMIT q_func()->tabDroped(tabIndex, action, drag->target());
+            Q_EMIT q_func()->tabDroped(d->pressedIndex, action, drag->target());
     }
 
     drag->setProperty("_d_DTabBarPrivate_drity", true);
 
-    QTabBarPrivate *d = reinterpret_cast<QTabBarPrivate *>(qGetPtrHelper(d_ptr));
-
     // Be safe!
     if (d->dragInProgress && d->pressedIndex != -1) {
         d->hoverRect = QRect();
@@ -356,6 +369,8 @@ void DTabBarPrivate::setupMovableTab()
     QStyleOptionTab tab;
     initStyleOption(&tab, d->pressedIndex);
     tab.rect.moveTopLeft(QPoint(taboverlap, 0));
+    // 强制让文本居中
+    tab.rightButtonSize = QSize();
     q_func()->paintTab(&p, d->pressedIndex, tab);
 
     reinterpret_cast<DMovableTabWidget*>(d->movingTab)->setPixmap(grabImage);
@@ -439,6 +454,8 @@ void DTabBarPrivate::setupDragableTab()
     QTabBarPrivate *d = reinterpret_cast<QTabBarPrivate *>(qGetPtrHelper(d_ptr));
     QStyleOptionTab opt;
     initStyleOption(&opt, d->pressedIndex);
+    // 强制让文本居中
+    opt.rightButtonSize = QSize();
 
     QMimeData *mime_data = q->createMimeDataFromTab(d->pressedIndex, opt);
 
@@ -459,7 +476,11 @@ void DTabBarPrivate::setupDragableTab()
 
     qRegisterMetaType<Qt::DropAction>();
 
-    QMetaObject::invokeMethod(this, "startDrag", Qt::QueuedConnection, Q_ARG(int, d->pressedIndex));
+
+    //task34370
+    //该函数于事件循环结束后调用，d->pressedIndex在事件中已经更新
+    //然传入参数非更新后的参数，故去除此函数参数
+    QMetaObject::invokeMethod(this, "startDrag", Qt::QueuedConnection);
     QMetaObject::invokeMethod(q, "dragStarted", Qt::QueuedConnection);
     QMetaObject::invokeMethod(q, "dragActionChanged", Qt::QueuedConnection, Q_ARG(Qt::DropAction, Qt::IgnoreAction));
 
@@ -842,11 +863,11 @@ void DTabBarPrivate::startMove(int index)
     mouse_animation->setStartValue(QCursor::pos());
     mouse_animation->setEndValue(mapToGlobal(index_rect.center()));
 
-    connect(mouse_animation, &QVariantAnimation::valueChanged, this, [] (const QVariant &value) {
-        const QPoint pos = value.toPoint();
-
-        QCursor::setPos(pos.x(), pos.y());
-    });
+    // 不要改变鼠标位置。会导致光标不受控的体验，bug-18362
+//    connect(mouse_animation, &QVariantAnimation::valueChanged, this, [=] (const QVariant &value) {
+//        const QPoint pos = value.toPoint();
+//        QCursor::setPos(pos.x(), pos.y());
+//    });
 
     connect(mouse_animation, &QVariantAnimation::finished, this, [this, mouse_animation] {
         mouse_animation->deleteLater();
@@ -867,23 +888,86 @@ void DTabBarPrivate::stopMove()
     setMovable(movable);
 }
 
+void DTabBarPrivate::onCurrentChanged(int current)
+{
+    updateCloseButtonVisible();
+    D_Q(DTabBar);
+    Q_EMIT q->currentChanged(current);
+}
+
+// 只允许当前标签页显示关闭按钮
+void DTabBarPrivate::updateCloseButtonVisible()
+{
+    if (!tabsClosable())
+        return;
+
+    int current = currentIndex();
+
+    for (int i = 0; i < this->count(); ++i) {
+        QWidget *close_button = tabButton(i, QTabBar::RightSide);
+
+        if (!close_button || close_button->metaObject()->className() != QByteArrayLiteral("CloseButton")) {
+            close_button = tabButton(i, QTabBar::LeftSide);
+        }
+
+        if (!close_button || close_button->metaObject()->className() != QByteArrayLiteral("CloseButton"))
+            continue;
+
+        close_button->setVisible(i == current);
+    }
+}
+
+static QIcon getArrowIcon(const QStyle *style, Qt::ArrowType type)
+{
+    switch (type) {
+    case Qt::UpArrow:
+        return style->standardIcon(QStyle::SP_ArrowUp);
+    case Qt::DownArrow:
+        return style->standardIcon(QStyle::SP_ArrowDown);
+    case Qt::LeftArrow:
+        return style->standardIcon(QStyle::SP_ArrowLeft);
+    case Qt::RightArrow:
+        return style->standardIcon(QStyle::SP_ArrowRight);
+    default:
+        break;
+    }
+
+    return QIcon();
+}
+
 bool DTabBarPrivate::eventFilter(QObject *watched, QEvent *event)
 {
+    D_Q(DTabBar);
     QTabBarPrivate *d = reinterpret_cast<QTabBarPrivate *>(qGetPtrHelper(d_ptr));
+    bool enabled = q->property("_d_dtk_tabbartab_type").toBool();
 
     if (watched == d->leftB) {
         switch (event->type()) {
         case QEvent::Show:
+            if (enabled) {
+                leftBtnL->changeSize(10, 0);
+                leftBtnR->changeSize(10, 0);
+                rightBtnL->changeSize(10, 0);
+                if (!q->visibleAddButton())
+                    addBtnL->changeSize(10, 0);
+            }
             leftScrollButton->show();
             break;
         case QEvent::Hide:
+            if (enabled) {
+                leftBtnR->changeSize(0, 0);
+                leftBtnL->changeSize(0, 0);
+                rightBtnL->changeSize(0, 0);
+                if (!q->visibleAddButton())
+                    addBtnL->changeSize(0, 0);
+            }
             leftScrollButton->hide();
             break;
         case QEvent::EnabledChange:
             leftScrollButton->setEnabled(d->leftB->isEnabled());
             break;
         case QEvent::UpdateRequest:
-            leftScrollButton->setArrowType(d->leftB->arrowType());
+            leftScrollButton->setIcon(getArrowIcon(style(), d->leftB->arrowType()));
             break;
         default:
             break;
@@ -892,6 +976,7 @@ bool DTabBarPrivate::eventFilter(QObject *watched, QEvent *event)
         switch (event->type()) {
         case QEvent::Show:
             rightScrollButton->show();
+            rightScrollButton->updateGeometry();
             // ###(zccrs): 当主窗口从最大化还原后，此button的大小会被布局改为 0x40 （原因不明）
             QTimer::singleShot(100, rightScrollButton, [this] {
                 rightScrollButton->resize(rightScrollButton->sizeHint().width(), rightScrollButton->height());
@@ -904,7 +989,7 @@ bool DTabBarPrivate::eventFilter(QObject *watched, QEvent *event)
             rightScrollButton->setEnabled(d->rightB->isEnabled());
             break;
         case QEvent::UpdateRequest:
-            rightScrollButton->setArrowType(d->rightB->arrowType());
+            rightScrollButton->setIcon(getArrowIcon(style(), d->rightB->arrowType()));
             break;
         default:
             break;
@@ -914,6 +999,25 @@ bool DTabBarPrivate::eventFilter(QObject *watched, QEvent *event)
     return QTabBar::eventFilter(watched, event);
 }
 
+bool DTabBarPrivate::event(QEvent *e)
+{
+    QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(e);
+
+    if (e->type() == QEvent::ToolTip) {
+        if (const QTabBarPrivate::Tab *tab = dd()->at(currentIndex())) {
+            if (!tab->toolTip.isEmpty()) {
+                if(mousePress)
+                    return true;
+            }
+        }
+    } if (e->type() == QEvent::MouseButtonPress && mouseEvent->button() == Qt::LeftButton) {
+        mousePress = true;
+    } if (e->type() == QEvent::MouseButtonRelease && mouseEvent->button() == Qt::LeftButton) {
+        mousePress = false;
+    }
+    return QTabBar::event(e);
+}
+
 QSize DTabBarPrivate::minimumSizeHint() const
 {
     const QSize &hint = sizeHint();
@@ -1071,8 +1175,7 @@ void DTabBarPrivate::mouseMoveEvent(QMouseEvent *event)
     }
 
     if (event->buttons() == Qt::LeftButton
-        // 此条件会导致横向拖动时卡顿
-        // && offset_x > startDragDistance
+        && d->dragInProgress // update tab position only in dragging..
         && valid_pressed_index) {
 
         updateMoveingTabPosition(event->pos());
@@ -1183,26 +1286,26 @@ QSize DTabBarPrivate::tabSizeHint(int index) const
 {
     D_QC(DTabBar);
 
-    if (qApp->buildDtkVersion() > DTK_VERSION_CHECK(2, 0, 8, 1))
-        return q->tabSizeHint(index);
-
-    return q->DTabBar::tabSizeHint(index);
+    return q->tabSizeHint(index);
 }
 
 QSize DTabBarPrivate::minimumTabSizeHint(int index) const
 {
     D_QC(DTabBar);
 
-    const QSize &min = qApp->buildDtkVersion() > DTK_VERSION_CHECK(2, 0, 8, 1) ? q->minimumTabSizeHint(index) : q->DTabBar::minimumTabSizeHint(index);
+    const QSize &min = q->minimumTabSizeHint(index);
 
     if (min.isValid())
         return min;
 
     QSize size = QTabBar::tabSizeHint(index);
-    const QSize &max = qApp->buildDtkVersion() > DTK_VERSION_CHECK(2, 0, 8, 1) ? q->maximumTabSizeHint(index) : q->DTabBar::maximumTabSizeHint(index);
+    const QSize &max = q->maximumTabSizeHint(index);
 
-    if (max.isValid()) {
+    if (max.width() > 0) {
         size.setWidth(qMin(size.width(), max.width()));
+    }
+
+    if (max.height() > 0) {
         size.setHeight(qMin(size.height(), max.height()));
     }
 
@@ -1213,30 +1316,23 @@ void DTabBarPrivate::tabInserted(int index)
 {
     D_Q(DTabBar);
 
-    if (qApp->buildDtkVersion() > DTK_VERSION_CHECK(2, 0, 8, 1))
-        q->tabInserted(index);
-    else
-        q->DTabBar::tabInserted(index);
+    q->tabInserted(index);
 }
 
 void DTabBarPrivate::tabRemoved(int index)
 {
     D_Q(DTabBar);
 
-    if (qApp->buildDtkVersion() > DTK_VERSION_CHECK(2, 0, 8, 1))
-        q->tabRemoved(index);
-    else
-        q->DTabBar::tabRemoved(index);
+    q->tabRemoved(index);
 }
 
 void DTabBarPrivate::tabLayoutChange()
 {
     D_Q(DTabBar);
 
-    if (qApp->buildDtkVersion() > DTK_VERSION_CHECK(2, 0, 8, 1))
-        q->tabLayoutChange();
-    else
-        q->DTabBar::tabLayoutChange();
+    q->tabLayoutChange();
+    // 更新关闭按钮的显示
+    updateCloseButtonVisible();
 }
 
 void DTabBarPrivate::initStyleOption(QStyleOptionTab *option, int tabIndex) const
@@ -1365,8 +1461,8 @@ void DTabBar::setShape(QTabBar::Shape shape)
         }
 
         if (new_vertical) {
-            d->leftScrollButton->setArrowType(Qt::UpArrow);
-            d->rightScrollButton->setArrowType(Qt::DownArrow);
+            d->leftScrollButton->setIcon(getArrowIcon(style(), Qt::UpArrow));
+            d->rightScrollButton->setIcon(getArrowIcon(style(), Qt::DownArrow));
             d->leftScrollButton->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
             d->rightScrollButton->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
             d->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum);
@@ -1375,8 +1471,8 @@ void DTabBar::setShape(QTabBar::Shape shape)
             d->addButton->setMinimumWidth(0);
             d->addButton->setMaximumWidth(9999);
         } else {
-            d->leftScrollButton->setArrowType(Qt::LeftArrow);
-            d->rightScrollButton->setArrowType(Qt::RightArrow);
+            d->leftScrollButton->setIcon(getArrowIcon(style(), Qt::LeftArrow));
+            d->rightScrollButton->setIcon(getArrowIcon(style(), Qt::RightArrow));
             d->leftScrollButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
             d->rightScrollButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
             d->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Expanding);
@@ -1657,12 +1753,29 @@ void DTabBar::setSelectionBehaviorOnRemove(QTabBar::SelectionBehavior behavior)
 
 bool DTabBar::expanding() const
 {
-    return d_func()->expanding();
+    QTabBarPrivate *dd = reinterpret_cast<QTabBarPrivate *>(qGetPtrHelper(d_func()->d_ptr));
+    return dd->expanding;
 }
 
 void DTabBar::setExpanding(bool enabled)
 {
-    d_func()->setExpanding(enabled);
+    D_D(DTabBar);
+
+    if (enabled == expanding())
+        return;
+    QTabBarPrivate *dd = reinterpret_cast<QTabBarPrivate *>(qGetPtrHelper(d->d_ptr));
+    dd->expanding = enabled;
+    QHBoxLayout *auto_layout = d->layout;
+
+    if (enabled) {
+        auto_layout->removeItem(d->stretch);
+        d->stretchIsRemove = true;
+        d->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
+    } else {
+        auto_layout->addSpacerItem(d->stretch);
+        d->stretchIsRemove = false;
+        d->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Fixed);
+    }
 }
 
 bool DTabBar::isMovable() const
@@ -1740,6 +1853,45 @@ QWindow *DTabBar::dragIconWindow() const
     return nullptr;
 }
 
+/*!
+ * \~chinese \brief DTabBar::setEnabledEmbedStyle 启用直角样式的Tabbar
+ * \~chinese \row 此风格适用于切换窗口的操作,多用于支持多开的应用
+ * \param replace true 启用，false 恢复
+ */
+void DTabBar::setEnabledEmbedStyle(bool enable)
+{
+    D_D(DTabBar);
+
+    int radius;
+    setProperty("_d_dtk_tabbartab_type", enable);
+
+    if (enable) {
+        radius = DStyle::pixelMetric(style(), DStyle::PM_FloatingWidgetRadius);
+        d->addButton->setMaximumSize(QSize(24, 24));
+        d->rightScrollButton->setMaximumSize(QSize(24, 24));
+        d->leftScrollButton->setMaximumSize(QSize(24, 24));
+    } else {
+        radius = DStyle::pixelMetric(style(), DStyle::PM_FrameRadius);
+        QSize size = d->addButton->sizeHint();
+        d->addButton->setMaximumSize(size);
+        d->rightScrollButton->setMaximumSize(size);
+        d->leftScrollButton->setMaximumSize(size);
+    }
+
+    DStyle::setFrameRadius(d->rightScrollButton, radius);
+    DStyle::setFrameRadius(d->leftScrollButton, radius);
+    DStyle::setFrameRadius(d->addButton, radius);
+}
+
+/*!
+ * \~chinese \brief DTabBar::setTabLabelAlignment 设置tab标签文字对齐方式
+ * \~chinese \param alignment 对齐
+ */
+void DTabBar::setTabLabelAlignment(Qt::Alignment alignment)
+{
+    setProperty("_d_dtk_tabbar_alignment", int(alignment));
+}
+
 /*!
  * \~chinese \brief 设置当前标签索引位置
  */
@@ -1757,6 +1909,14 @@ void DTabBar::setVisibleAddButton(bool visibleAddButton)
 
     d->visibleAddButton = visibleAddButton;
     d->addButton->setVisible(visibleAddButton);
+
+    if (visibleAddButton) {
+        d->addBtnL->changeSize(10, 0);
+        d->addBtnR->changeSize(10, 0);
+    } else {
+        d->addBtnL->changeSize(0, 0);
+        d->addBtnR->changeSize(0, 0);
+    }
 }
 
 /*!
@@ -1817,9 +1977,7 @@ void DTabBar::dragEnterEvent(QDragEnterEvent *e)
             d->ghostTabIndex = index;
             insertFromMimeDataOnDragEnter(index, e->mimeData());
             // 延时启动startMove， 此时tabbar的大小还没有更新
-            QTimer::singleShot(10, [d, index] {
-                d->startMove(index);
-            });
+            QMetaObject::invokeMethod(d, "startMove", Qt::QueuedConnection, Q_ARG(int, index));
         }
     }
 }
@@ -2032,19 +2190,20 @@ QSize DTabBar::tabSizeHint(int index) const
     if (is_vertical) {
         size.setWidth(qMax(size.width(), d->width()));
     } else {
-        size.setHeight(qMax(size.height(), d->height()));
+        size.setHeight(qMax(size.height(), dd->leftB->height()));
     }
 
-    const QSize &min = qApp->buildDtkVersion() > DTK_VERSION_CHECK(2, 0, 8, 1) ? minimumTabSizeHint(index) : DTabBar::minimumTabSizeHint(index);
-    const QSize &max = qApp->buildDtkVersion() > DTK_VERSION_CHECK(2, 0, 8, 1) ? maximumTabSizeHint(index) : DTabBar::maximumTabSizeHint(index);
+    const QSize &min = minimumTabSizeHint(index);
+    const QSize &max = maximumTabSizeHint(index);
 
     size.setWidth(qMax(size.width(), min.width()));
     size.setHeight(qMax(size.height(), min.height()));
 
-    if (max.isValid()) {
+    if (max.width() > 0)
         size.setWidth(qMin(size.width(), max.width()));
+
+    if (max.height() > 0)
         size.setHeight(qMin(size.height(), max.height()));
-    }
 
     return size;
 }
