@@ -2,7 +2,7 @@
  * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -224,8 +224,7 @@ class DThemeManagerPrivate : public DCORE_NAMESPACE::DObjectPrivate
     D_DECLARE_PUBLIC(DThemeManager)
 
     QString themeName;
-    QMap<QWidget *, QMap<QString, QString> > watchedDynamicPropertys;
-    DThemeManager::ThemeType themeType = DThemeManager::UnknownType;
+    QMap<QWidget *, QMap<QString, QString> > watchedDynamicProperties;
 
 public:
     DThemeManagerPrivate(DThemeManager *qq)
@@ -311,7 +310,7 @@ public:
         return "";
     }
 
-    void registerWidget(QWidget *widget, const QString &filename, const QStringList &propertys)
+    void registerWidget(QWidget *widget, const QString &filename, const QStringList &properties)
     {
         if (filename.isEmpty()) {
             qWarning() << "can not load qss with out filename" << widget;
@@ -349,29 +348,29 @@ public:
         });
 
         auto meta = widget->metaObject();
-        QMap<QString, QString> dynamicPropertys;
-        for (auto &prop : propertys) {
+        QMap<QString, QString> dynamicProperties;
+        for (auto &prop : properties) {
             auto propIndex = meta->indexOfProperty(prop.toLatin1().data());
             if (propIndex < 0) {
-                dynamicPropertys.insert(prop, prop);
+                dynamicProperties.insert(prop, prop);
                 continue;
             }
             dtm->connect(widget, meta->property(propIndex).notifySignal(),
                          dtm, dtm->metaObject()->method(dtm->metaObject()->indexOfMethod("updateQss()")));
         }
 
-        if (!dynamicPropertys.isEmpty()) {
+        if (!dynamicProperties.isEmpty()) {
             widget->installEventFilter(dtm);
-            if (dtm->d_func()->watchedDynamicPropertys.contains(widget)) {
-                QMap<QString, QString> oldProps = dtm->d_func()->watchedDynamicPropertys.value(widget);
+            if (dtm->d_func()->watchedDynamicProperties.contains(widget)) {
+                QMap<QString, QString> oldProps = dtm->d_func()->watchedDynamicProperties.value(widget);
                 for (auto &key : oldProps.keys()) {
-                    dynamicPropertys.insert(key, oldProps.value(key));
+                    dynamicProperties.insert(key, oldProps.value(key));
                 }
             }
-            dtm->d_func()->watchedDynamicPropertys.insert(widget, dynamicPropertys);
+            dtm->d_func()->watchedDynamicProperties.insert(widget, dynamicProperties);
 
             dtm->connect(widget, &QObject::destroyed, dtm, [ = ]() {
-                dtm->d_func()->watchedDynamicPropertys.remove(widget);
+                dtm->d_func()->watchedDynamicProperties.remove(widget);
             });
         }
     }
@@ -520,65 +519,6 @@ void DThemeManager::setTheme(QWidget *widget, const QString theme)
     d->setTheme(widget, theme);
 }
 
-/*!
- * \~chinese \brief DThemeManager::themeType 返回应用程序的主题类型。DApplication 对象构造时会
- * \~chinese 调用 setThemeType 初始化应用程序的主题类型，未初始化时返回 UnknownType。
- * \~chinese \return 主题类型的枚举值
- *
- * \~chinese \sa \class DApplication
- * \~chinese \sa DThemeManager::setThemeType
- */
-DThemeManager::ThemeType DThemeManager::themeType() const
-{
-    D_DC(DThemeManager);
-
-    return d->themeType;
-}
-
-/*!
- * \~chinese \brief DThemeManager::themeType 返回窗口的主题类型。当窗口未设置主题类型时，将返回
- * \~chinese 应用程序的主题类型。
- * \~chinese \param window 要获取主题类型的顶级窗口对象
- * \~chinese \return 主题类型的枚举值
- *
- * \~chinese \sa DThemeManager::setThemeType
- * \~chinese \sa DThemeManager::setThemeType(QWidget*, DThemeManager::ThemeType)
- */
-DThemeManager::ThemeType DThemeManager::themeType(const QWidget *window) const
-{
-    ThemeType type = static_cast<ThemeType>(window->property("_d_dtk_theme_type").toInt());
-
-    if (type == UnknownType) {
-        type = themeType();
-    }
-
-    return type;
-}
-
-/*!
- * \~chinese \brief DThemeManager::setThemeType 设置窗口的主题类型。
- * \~chinese \param window 要设置主题类型的顶级窗口对象
- * \~chinese \param 要设置的主题类型枚举值，值为 UnknownType 时将清空 window 对象的主题类型设置
- *
- * \~chinese \sa DThemeManager::setThemeType()
- * \~chinese \note 针对窗口设置的主题类型将存储在窗口对象的 "_d_dtk_theme_type" 属性中
- */
-void DThemeManager::setThemeType(QWidget *window, DThemeManager::ThemeType type)
-{
-    ThemeType old_type = themeType(window);
-
-    if (type == UnknownType) {
-        window->setProperty("_d_dtk_theme_type", QVariant());
-        type = themeType();
-    } else {
-        window->setProperty("_d_dtk_theme_type", type);
-    }
-
-    if (old_type != type) {
-        Q_EMIT windowThemeTypeChanged(window, type);
-    }
-}
-
 /*!
  * \~english \brief DThemeManager::getQssForWidget searches for the theme file of one class in a specific theme.
  * \~english \param className is the name of the class.
@@ -603,13 +543,6 @@ QString DThemeManager::getQssForWidget(const QString className, const QString &t
     return d->getQssContent(themeURL);
 }
 
-QString DThemeManager::getQssForWidget(const QString className, const QWidget *widget) const
-{
-    Q_ASSERT(widget);
-
-    return getQssForWidget(className, theme(widget));
-}
-
 /*!
  * \~english \brief DThemeManager::getQssForWidget This function is overloaded.
  * \~english \param widget is the target widget.
@@ -622,57 +555,37 @@ QString DThemeManager::getQssForWidget(const QString className, const QWidget *w
  */
 QString DThemeManager::getQssForWidget(const QWidget *widget) const
 {
-    return getQssForWidget(getObjectClassName(widget), widget);
+    return getQssForWidget(getObjectClassName(widget), theme(widget));
 }
 
 /*!
  * \~chinese \brief DThemeManager::registerWidget 用于将控件注册到 DThemeManager 的管理范围内。
  * \~chinese 只有通过 registerWidget() 注册的控件才会受到 DThemeManager 的自动管理，
- * \~chinese 通常注册的动作都会在实例的构造过程中完成。\ref propertys 参数用来注册属性，
+ * \~chinese 通常注册的动作都会在实例的构造过程中完成。\ref properties 参数用来注册属性，
  * \~chinese 注册的属性发生变化时 DThemeManager 会自动刷新控件的样式。
  * \~chinese \param widget 需要注册的控件。
- * \~chinese \param propertys 需要注册的控件属性。
+ * \~chinese \param properties 需要注册的控件属性。
  */
-void DThemeManager::registerWidget(QWidget *widget, QStringList propertys)
+void DThemeManager::registerWidget(QWidget *widget, QStringList properties)
 {
     auto dtm = DThemeManager::instance();
     auto fileName = dtm->d_func()->fallbackWidgetThemeFilename(widget);
-    registerWidget(widget, fileName, propertys);
+    registerWidget(widget, fileName, properties);
 }
 
 /*!
  * \~chinese \brief DThemeManager::registerWidget 用于将控件注册到 DThemeManager 的管理范围内。
  * \~chinese \param widget 需要注册的控件。
  * \~chinese \param filename 需要注册的控件所对应的主题文件名。
- * \~chinese \param propertys 需要注册的控件属性。
+ * \~chinese \param properties 需要注册的控件属性。
  *
  *
- * \sa registerWidget(QWidget *widget, QStringList propertys)
+ * \sa registerWidget(QWidget *widget, QStringList properties)
  */
-void DThemeManager::registerWidget(QWidget *widget, const QString &filename, const QStringList &propertys)
+void DThemeManager::registerWidget(QWidget *widget, const QString &filename, const QStringList &properties)
 {
     auto dtm = DThemeManager::instance();
-    dtm->d_func()->registerWidget(widget, filename, propertys);
-}
-
-/*!
- * \~chinese \brief DThemeManager::toThemeType 获取颜色的明亮度，将其转换为主题类型的枚举值。
- * \~chinese 转换的策略为：先将颜色转换为rgb格式，再根据 Y = 0.299R + 0.587G + 0.114B 的公式
- * \~chinese 计算出颜色的亮度，亮度大于 191 时认为其为浅色，否则认为其为深色。
- * \~chinese \param color 需要转换为主题的类型的颜色
- * \~chinese \return 主题类型的枚举值
- */
-DThemeManager::ThemeType DThemeManager::toThemeType(const QColor &color)
-{
-    QColor rgb_color = color.toRgb();
-    // 获取rgb颜色的亮度
-    float luminance = 0.299 * rgb_color.redF() + 0.587 * rgb_color.greenF() + 0.114 * rgb_color.blueF();
-
-    if (qRound(luminance * 255) > 191) {
-        return LightType;
-    }
-
-    return DarkType;
+    dtm->d_func()->registerWidget(widget, filename, properties);
 }
 
 /*!
@@ -698,7 +611,7 @@ DThemeManager::DThemeManager()
     : QObject()
     , DObject(*new DThemeManagerPrivate(this))
 {
-    setTheme("light");
+    qApp->setStyle("chameleon");
 }
 
 bool DThemeManager::eventFilter(QObject *watched, QEvent *event)
@@ -709,7 +622,7 @@ bool DThemeManager::eventFilter(QObject *watched, QEvent *event)
     }
 
     auto widget = qobject_cast<QWidget *>(watched);
-    if (!d->watchedDynamicPropertys.contains(widget)) {
+    if (!d->watchedDynamicProperties.contains(widget)) {
         return QObject::eventFilter(watched, event);
     }
 
@@ -718,7 +631,7 @@ bool DThemeManager::eventFilter(QObject *watched, QEvent *event)
         return QObject::eventFilter(watched, event);
     }
 
-    auto props = d->watchedDynamicPropertys.value(widget);
+    auto props = d->watchedDynamicProperties.value(widget);
     auto propName = QString::fromLatin1(propEvent->propertyName().data());
     if (props.contains(propName) && widget) {
         widget->setStyleSheet(widget->styleSheet());
@@ -751,26 +664,4 @@ void DThemeManager::updateThemeOnParentChanged(QWidget *widget)
     updateWidgetTheme(this, widget, base_widget, theme);
 }
 
-/*!
- * \~chinese \brief DThemeManager::setThemeType 设置应用程序的主题类型。
- * \~chinese \param themeType 新的主题类型
- */
-void DThemeManager::setThemeType(DThemeManager::ThemeType themeType)
-{
-    D_D(DThemeManager);
-
-    if (d->themeType == themeType)
-        return;
-
-    d->themeType = themeType;
-    Q_EMIT themeTypeChanged(themeType);
-
-    // 未自定义主题类型的窗口应该跟随应用程序的主题类型改变，此处需要为这些窗口发送通知
-    for (QWidget *window : qApp->topLevelWidgets()) {
-        if (!window->property("_d_dtk_theme_type").isValid()) {
-            Q_EMIT windowThemeTypeChanged(window, themeType);
-        }
-    }
-}
-
 DWIDGET_END_NAMESPACE
