@@ -2,7 +2,7 @@
  * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -190,16 +190,6 @@ void DTickEffect::setDirection(DTickEffect::Direction direction)
     play();
 }
 
-/*!
- * \~chinese \brief 设置滚动的时长
- *
- * @param duration
- */
-void DTickEffect::setDuration(const int duration)
-{
-    Q_UNUSED(duration);
-}
-
 void DTickEffect::setFixedPixelMove(const int pixel)
 {
     D_D(DTickEffect);
