@@ -2,7 +2,7 @@
  * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -24,29 +24,30 @@
 #include <QMouseEvent>
 #include <QProcess>
 
+#include <DWindowManagerHelper>
 #include <DObjectPrivate>
 
 #include "dwindowclosebutton.h"
 #include "dwindowmaxbutton.h"
 #include "dwindowminbutton.h"
 #include "dwindowoptionbutton.h"
-#include "dlabel.h"
+#include "dwindowquitfullbutton.h"
 #include "dplatformwindowhandle.h"
-#ifdef Q_OS_LINUX
-#include "../platforms/x11/xutil.h"
-#endif
 #include "daboutdialog.h"
 #include "dapplication.h"
 #include "private/dapplication_p.h"
-#include "dthememanager.h"
-#include "util/dwindowmanagerhelper.h"
 #include "dmainwindow.h"
+#include "DHorizontalLine"
+#include "dimagebutton.h"
+#include "dblureffectwidget.h"
+#include "dwidgetstype.h"
+#include "dlabel.h"
 
 DWIDGET_BEGIN_NAMESPACE
 
-const int DefaultTitlebarHeight = 40;
-const int DefaultIconHeight = 24;
-const int DefaultIconWidth = 24;
+const int DefaultTitlebarHeight = 50;
+const int DefaultIconHeight = 32;
+const int DefaultIconWidth = 32;
 
 class DTitlebarPrivate : public DTK_CORE_NAMESPACE::DObjectPrivate
 {
@@ -65,6 +66,8 @@ private:
     void updateFullscreen();
     void updateButtonsState(Qt::WindowFlags type);
     void updateButtonsFunc();
+    void updateCenterArea();
+
     void handleParentWindowStateChange();
     void handleParentWindowIdChange();
     void _q_toggleWindowState();
@@ -76,30 +79,45 @@ private:
     void _q_helpActionTriggered();
     void _q_aboutActionTriggered();
     void _q_quitActionTriggered();
+    void _q_switchThemeActionTriggered(QAction*action);
 #endif
 
+    void setIconVisible(bool visible);
+    void updateTabOrder();
+
     QHBoxLayout         *mainLayout;
-    DLabel              *iconLabel;
-    DLabel              *titleLabel;
+    QWidget             *leftArea;
+    QHBoxLayout         *leftLayout;
+    QWidget             *rightArea;
+    QHBoxLayout         *rightLayout;
+    DLabel              *centerArea;
+    QHBoxLayout         *centerLayout;
+    DIconButton         *iconLabel;
+    QWidget             *buttonArea;
     DWindowMinButton    *minButton;
     DWindowMaxButton    *maxButton;
     DWindowCloseButton  *closeButton;
     DWindowOptionButton *optionButton;
-    DImageButton        *quitFullButton;
+    DWindowQuitFullButton *quitFullButton;
+    DLabel              *titleLabel;
+    QWidget             *customWidget = nullptr;
 
-    QWidget             *customWidget = Q_NULLPTR;
-    QWidget             *coustomAtea;
-    QWidget             *buttonArea;
-    QWidget             *titleArea;
-    QWidget             *titlePadding;
-    QLabel              *separatorTop;
-    QLabel              *separator;
+    DHorizontalLine     *separatorTop;
+    DHorizontalLine     *separator;
+
+    DBlurEffectWidget   *blurWidget = nullptr;
 
 #ifndef QT_NO_MENU
-    QMenu               *menu           = Q_NULLPTR;
-    QAction             *helpAction     = Q_NULLPTR;
-    QAction             *aboutAction    = Q_NULLPTR;
-    QAction             *quitAction     = Q_NULLPTR;
+    QMenu               *menu             = Q_NULLPTR;
+    QAction             *helpAction       = Q_NULLPTR;
+    QAction             *aboutAction      = Q_NULLPTR;
+    QAction             *quitAction       = Q_NULLPTR;
+    bool                canSwitchTheme    = true;
+    QAction             *themeSeparator   = nullptr;
+    QMenu               *switchThemeMenu  = nullptr;
+    QAction             *autoThemeAction  = nullptr;
+    QAction             *lightThemeAction = nullptr;
+    QAction             *darkThemeAction  = nullptr;
 #endif
 
     QWindow            *targetWindowHandle = Q_NULLPTR;
@@ -108,6 +126,7 @@ private:
     bool                mousePressed    = false;
     bool                embedMode       = false;
     bool                autoHideOnFullscreen = false;
+    bool                fullScreenButtonVisible = true;
 
     Q_DECLARE_PUBLIC(DTitlebar)
 };
@@ -121,93 +140,99 @@ void DTitlebarPrivate::init()
     D_Q(DTitlebar);
 
     mainLayout      = new QHBoxLayout;
-    iconLabel       = new DLabel;
-    titleLabel      = new DLabel;
+    leftArea        = new QWidget;
+    leftLayout      = new QHBoxLayout(leftArea);
+    rightArea       = new QWidget;
+    rightLayout     = new QHBoxLayout;
+    centerArea      = new DLabel(q);
+    centerLayout    = new QHBoxLayout(centerArea);
+    iconLabel       = new DIconButton(q);
+    buttonArea      = new QWidget;
     minButton       = new DWindowMinButton;
     maxButton       = new DWindowMaxButton;
     closeButton     = new DWindowCloseButton;
     optionButton    = new DWindowOptionButton;
-    quitFullButton  = new DImageButton;
-    coustomAtea     = new QWidget;
-    buttonArea      = new QWidget;
-    titleArea       = new QWidget;
-    titlePadding    = new QWidget;
-    separatorTop    = new QLabel(q);
-    separator       = new QLabel(q);
+    quitFullButton  = new DWindowQuitFullButton;
+    separatorTop    = new DHorizontalLine(q);
+    separator       = new DHorizontalLine(q);
+    titleLabel      = centerArea;
+    titleLabel->setElideMode(Qt::ElideMiddle);
+
+    minButton->installEventFilter(q);
+    maxButton->installEventFilter(q);
+    closeButton->installEventFilter(q);
+    optionButton->installEventFilter(q);
+    quitFullButton->installEventFilter(q);
 
     optionButton->setObjectName("DTitlebarDWindowOptionButton");
+    optionButton->setIconSize(QSize(DefaultTitlebarHeight, DefaultTitlebarHeight));
     minButton->setObjectName("DTitlebarDWindowMinButton");
+    minButton->setIconSize(QSize(DefaultTitlebarHeight, DefaultTitlebarHeight));
     maxButton->setObjectName("DTitlebarDWindowMaxButton");
+    maxButton->setIconSize(QSize(DefaultTitlebarHeight, DefaultTitlebarHeight));
     closeButton->setObjectName("DTitlebarDWindowCloseButton");
+    closeButton->setIconSize(QSize(DefaultTitlebarHeight, DefaultTitlebarHeight));
     quitFullButton->setObjectName("DTitlebarDWindowQuitFullscreenButton");
+    quitFullButton->setIconSize(QSize(DefaultTitlebarHeight, DefaultTitlebarHeight));
     quitFullButton->hide();
 
-    mainLayout->setContentsMargins(6, 0, 0, 0);
-    mainLayout->setSpacing(0);
-
-    iconLabel->setFixedSize(DefaultIconWidth, DefaultIconHeight);
+    iconLabel->setIconSize(QSize(DefaultIconWidth, DefaultIconHeight));
     iconLabel->setWindowFlags(Qt::WindowTransparentForInput);
-    titleLabel->setText(qApp->applicationName());
-    // TODO: use QSS
-    titleLabel->setStyleSheet("font-size: 12px;");
-    titleLabel->setContentsMargins(0, 0, DefaultIconWidth + 10, 0);
-    titleLabel->setWindowFlags(Qt::WindowTransparentForInput);
-//    q->setStyleSheet("background-color: green;");
+    iconLabel->setFocusPolicy(Qt::NoFocus);
+    iconLabel->setFlat(true);
+    // 默认无图标，所以隐藏
+    iconLabel->hide();
+
+    leftArea->setWindowFlag(Qt::WindowTransparentForInput);
+    leftArea->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
+    leftLayout->setContentsMargins(0, 0, 0, 0);
+
+    centerLayout->setContentsMargins(0, 0, 0, 0);
+    centerArea->setText(qApp->applicationName());
+    centerArea->setWindowFlags(Qt::WindowTransparentForInput);
+    centerArea->setFrameShape(QFrame::NoFrame);
+    centerArea->setAutoFillBackground(false);
+    centerArea->setBackgroundRole(QPalette::NoRole);
+    centerArea->setAlignment(Qt::AlignCenter);
+
+    buttonArea->setWindowFlag(Qt::WindowTransparentForInput);
+    buttonArea->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
+    QHBoxLayout *buttonLayout = new QHBoxLayout(buttonArea);
+    buttonLayout->setContentsMargins(0, 0, 0, 0);
+    buttonLayout->setSpacing(0);
+    buttonLayout->addWidget(optionButton);
+    buttonLayout->addWidget(minButton);
+    buttonLayout->addWidget(maxButton);
+    buttonLayout->addWidget(quitFullButton);
+    buttonLayout->addWidget(closeButton);
+
+    rightArea->setWindowFlag(Qt::WindowTransparentForInput);
+    rightArea->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
+    rightLayout->setContentsMargins(0, 0, 0, 0);
+    auto rightAreaLayout = new QHBoxLayout(rightArea);
+    rightAreaLayout->setContentsMargins(0, 0, 0, 0);
+    rightAreaLayout->setMargin(0);
+    rightAreaLayout->setSpacing(0);
+    rightAreaLayout->addLayout(rightLayout);
+    rightAreaLayout->addWidget(buttonArea);
 
     separatorTop->setFixedHeight(1);
-    separatorTop->setStyleSheet("background: rgba(0, 0, 0, 20);");
     separatorTop->hide();
     separatorTop->setWindowFlags(Qt::WindowTransparentForInput);
 
     separator->setFixedHeight(1);
-    separator->setStyleSheet("background: rgba(0, 0, 0, 20);");
     separator->hide();
     separator->setWindowFlags(Qt::WindowTransparentForInput);
 
-    QHBoxLayout *buttonAreaLayout = new QHBoxLayout;
-    buttonAreaLayout->setContentsMargins(0, 0, 0, 0);
-    buttonAreaLayout->setMargin(0);
-    buttonAreaLayout->setSpacing(0);
-    buttonAreaLayout->addWidget(optionButton);
-    buttonAreaLayout->addWidget(minButton);
-    buttonAreaLayout->addWidget(maxButton);
-    buttonAreaLayout->addWidget(closeButton);
-    buttonAreaLayout->addWidget(quitFullButton);
-    buttonArea->setLayout(buttonAreaLayout);
-
-    QHBoxLayout *titleAreaLayout = new QHBoxLayout;
-    titleAreaLayout->setContentsMargins(4, 0, 10 + iconLabel->width(), 0);
-    titleAreaLayout->setSpacing(0);
-    titleAreaLayout->addWidget(iconLabel);
-    titleAreaLayout->setAlignment(iconLabel, Qt::AlignLeft);
-    titlePadding->setFixedSize(buttonArea->size());
-    titlePadding->setWindowFlags(Qt::WindowTransparentForInput);
-    titleAreaLayout->addWidget(titlePadding);
-    titleAreaLayout->addStretch();
-    titleAreaLayout->addWidget(titleLabel);
-    titleAreaLayout->setAlignment(titleLabel, Qt::AlignCenter);
-
-    titleAreaLayout->addStretch();
-    titleArea->setLayout(titleAreaLayout);
-    titleArea->setWindowFlags(Qt::WindowTransparentForInput);
-
-    QHBoxLayout *coustomAteaLayout = new QHBoxLayout;
-    coustomAteaLayout->setMargin(0);
-    coustomAteaLayout->setSpacing(0);
-    coustomAteaLayout->addWidget(titleArea);
-    coustomAtea->setLayout(coustomAteaLayout);
-
-    mainLayout->addWidget(coustomAtea);
-    mainLayout->addWidget(buttonArea);
-    mainLayout->setAlignment(buttonArea, Qt::AlignRight |  Qt::AlignVCenter);
+    mainLayout->setContentsMargins(0, 0, 0, 0);
+    mainLayout->addWidget(leftArea, 0, Qt::AlignLeft);
+    mainLayout->addWidget(rightArea, 0, Qt::AlignRight);
 
     q->setLayout(mainLayout);
     q->setFixedHeight(DefaultTitlebarHeight);
     q->setMinimumHeight(DefaultTitlebarHeight);
-    coustomAtea->setFixedHeight(q->height());
-    buttonArea->setFixedHeight(q->height());
 
-    q->connect(quitFullButton, &DImageButton::clicked, q, [ = ]() {
+    q->connect(quitFullButton, &DWindowQuitFullButton::clicked, q, [ = ]() {
         bool isFullscreen = targetWindow()->windowState().testFlag(Qt::WindowFullScreen);
         if (isFullscreen) {
             targetWindow()->showNormal();
@@ -218,6 +243,17 @@ void DTitlebarPrivate::init()
     q->connect(optionButton, &DWindowOptionButton::clicked, q, &DTitlebar::optionClicked);
     q->connect(DWindowManagerHelper::instance(), SIGNAL(windowMotifWMHintsChanged(quint32)),
                q, SLOT(_q_onTopWindowMotifHintsChanged(quint32)));
+
+    q->setFrameShape(QFrame::NoFrame);
+    q->setBackgroundRole(QPalette::Base);
+    q->setAutoFillBackground(true);
+    q->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+    // 确保点击标题栏后输入框能失去焦点
+    // 另外，让标题栏接收焦点，还是为了避免一个focus控件隐藏时，会把焦点转移给标题栏上的按钮控件
+    q->setFocusPolicy(Qt::StrongFocus);
+
+    // fix wayland 下显示了两个应用图标，系统标题栏 和 dtk标题栏 均显示应用图标
+    q->setEmbedMode(!DApplication::isDXcbPlatform());
 }
 
 QWidget *DTitlebarPrivate::targetWindow()
@@ -284,21 +320,24 @@ void DTitlebarPrivate::updateButtonsState(Qt::WindowFlags type)
     bool useDXcb = DPlatformWindowHandle::isEnabledDXcb(targetWindow());
     bool isFullscreen = targetWindow()->windowState().testFlag(Qt::WindowFullScreen);
 
-    bool forceShow = !useDXcb;
+//    bool forceShow = !useDXcb;
+    bool forceShow = false;
 #ifndef Q_OS_LINUX
     forceShow = false;
 #endif
 
     bool showTitle = (type.testFlag(Qt::WindowTitleHint) || forceShow) && !embedMode;
     if (titleLabel) {
-        titleLabel->setVisible(showTitle);
-    }
-    if (iconLabel) {
-        iconLabel->setVisible(showTitle);
+        if (showTitle) {
+            titleLabel->setText(q->property("_dtk_title").toString());
+        } else {
+            q->setProperty("_dtk_title", titleLabel->text());
+            titleLabel->clear();
+        }
     }
 
     // Never show in embed/fullscreen
-    bool forceHide = embedMode || isFullscreen;
+    bool forceHide = (!useDXcb) || embedMode || isFullscreen;
 
     bool showMin = (type.testFlag(Qt::WindowMinimizeButtonHint) || forceShow) && !forceHide;
     minButton->setVisible(showMin);
@@ -312,27 +351,22 @@ void DTitlebarPrivate::updateButtonsState(Qt::WindowFlags type)
     }
 
     bool showMax = (type.testFlag(Qt::WindowMaximizeButtonHint) || forceShow) && !forceHide && allowResize;
+    bool showClose = type.testFlag(Qt::WindowCloseButtonHint) && useDXcb;
+    bool showQuit = isFullscreen && useDXcb && fullScreenButtonVisible;
 //    qDebug() << "max:"
 //             << "allowResize" << allowResize
 //             << "useDXcb" << useDXcb
 //             << "forceHide" << forceHide
 //             << "type.testFlag(Qt::WindowMaximizeButtonHint)" << type.testFlag(Qt::WindowMaximizeButtonHint);
     maxButton->setVisible(showMax);
-
-    bool showClose = (type.testFlag(Qt::WindowCloseButtonHint) || forceShow) && !forceHide;
     closeButton->setVisible(showClose);
-
-    buttonArea->adjustSize();
-    buttonArea->resize(buttonArea->size());
-
-    if (titlePadding) {
-        titlePadding->setFixedSize(buttonArea->size());
-    }
+    quitFullButton->setVisible(showQuit);
 }
 
 void DTitlebarPrivate::updateButtonsFunc()
 {
-    if (!targetWindowHandle) {
+    // TASK-18145 (bug-17474) do not setMotifFunctions on wayland
+    if (!targetWindowHandle || !qgetenv("WAYLAND_DISPLAY").isEmpty()) {
         return;
     }
 
@@ -355,6 +389,20 @@ void DTitlebarPrivate::updateButtonsFunc()
         !disableFlags.testFlag(Qt::WindowCloseButtonHint));
 }
 
+void DTitlebarPrivate::updateCenterArea()
+{
+    D_QC(DTitlebar);
+
+    if (centerArea->isHidden()) {
+        return;
+    }
+
+    int padding = qMax(leftArea->width(), rightArea->width());
+    QRect rect(0, 0, q->width() - 2 * padding, q->height());
+    rect.moveCenter(q->rect().center());
+    centerArea->setGeometry(rect);
+}
+
 void DTitlebarPrivate::handleParentWindowStateChange()
 {
     maxButton->setMaximized(targetWindow()->windowState() == Qt::WindowMaximized);
@@ -390,14 +438,12 @@ void DTitlebarPrivate::_q_toggleWindowState()
         parentWindow->showNormal();
     } else if (!parentWindow->isFullScreen()
                && (maxButton->isVisible())) {
-        maxButton->setState(DImageButton::Normal);
         parentWindow->showMaximized();
     }
 }
 
 void DTitlebarPrivate::_q_showMinimized()
 {
-    minButton->setState(DImageButton::Normal);
     targetWindow()->showMinimized();
 }
 
@@ -429,10 +475,6 @@ void DTitlebarPrivate::_q_onTopWindowMotifHintsChanged(quint32 winId)
         titleLabel->setVisible(decorations_hints.testFlag(DWindowManagerHelper::DECOR_TITLE));
     }
 
-    if (iconLabel) {
-        iconLabel->setVisible(decorations_hints.testFlag(DWindowManagerHelper::DECOR_TITLE));
-    }
-
     updateButtonsState(targetWindow()->windowFlags());
 
     minButton->setEnabled(functions_hints.testFlag(DWindowManagerHelper::FUNC_MINIMIZE));
@@ -449,10 +491,6 @@ void DTitlebarPrivate::_q_onTopWindowMotifHintsChanged(quint32 winId)
     setWindowFlag(disableFlags, Qt::WindowMaximizeButtonHint, !maxButton->isEnabled());
     setWindowFlag(disableFlags, Qt::WindowCloseButtonHint, !closeButton->isEnabled());
 #endif
-
-    if (titlePadding) {
-        titlePadding->setFixedSize(buttonArea->size());
-    }
 }
 
 #ifndef QT_NO_MENU
@@ -465,6 +503,35 @@ void DTitlebarPrivate::_q_addDefaultMenuItems()
         q->setMenu(new QMenu(q));
     }
 
+    // add switch theme sub menu
+    if (!switchThemeMenu) {
+        bool disableDtkSwitchThemeMenu = qEnvironmentVariableIsSet("KLU_DISABLE_MENU_THEME");
+        if (!disableDtkSwitchThemeMenu) {
+            switchThemeMenu = new QMenu(qApp->translate("TitleBarMenu", "Theme"), menu);
+            lightThemeAction = switchThemeMenu->addAction(qApp->translate("TitleBarMenu", "Light Theme"));
+            darkThemeAction = switchThemeMenu->addAction(qApp->translate("TitleBarMenu", "Dark Theme"));
+            autoThemeAction = switchThemeMenu->addAction(qApp->translate("TitleBarMenu", "System Theme"));
+
+            autoThemeAction->setCheckable(true);
+            lightThemeAction->setCheckable(true);
+            darkThemeAction->setCheckable(true);
+
+            QActionGroup *group = new QActionGroup(switchThemeMenu);
+            group->addAction(autoThemeAction);
+            group->addAction(lightThemeAction);
+            group->addAction(darkThemeAction);
+
+            QObject::connect(group, SIGNAL(triggered(QAction*)),
+                             q, SLOT(_q_switchThemeActionTriggered(QAction*)));
+
+            menu->addMenu(switchThemeMenu);
+            themeSeparator = menu->addSeparator();
+
+            switchThemeMenu->menuAction()->setVisible(canSwitchTheme);
+            themeSeparator->setVisible(canSwitchTheme);
+        }
+    }
+
     // add help menu item.
     if (!helpAction && DApplicationPrivate::isUserManualExists()) {
         helpAction = new QAction(qApp->translate("TitleBarMenu", "Help"), menu);
@@ -511,6 +578,69 @@ void DTitlebarPrivate::_q_quitActionTriggered()
     }
 }
 
+void DTitlebarPrivate::_q_switchThemeActionTriggered(QAction *action)
+{
+    DGuiApplicationHelper::ColorType type = DGuiApplicationHelper::UnknownType;
+
+    if (action == lightThemeAction) {
+        type = DGuiApplicationHelper::LightType;
+    } else if (action == darkThemeAction) {
+        type = DGuiApplicationHelper::DarkType;
+    }
+
+    DGuiApplicationHelper::instance()->setPaletteType(type);
+}
+
+void DTitlebarPrivate::setIconVisible(bool visible)
+{
+    if (iconLabel->isVisible() == visible)
+        return;
+
+    if (visible) {
+        leftLayout->insertSpacing(0, 10);
+        leftLayout->insertWidget(1, iconLabel, 0, Qt::AlignLeading | Qt::AlignVCenter);
+        iconLabel->show();
+    } else {
+        iconLabel->hide();
+        // 从布局中移除图标相关的东西
+        delete leftLayout->takeAt(0);
+        delete leftLayout->takeAt(1);
+    }
+}
+
+void DTitlebarPrivate::updateTabOrder()
+{
+    D_Q(DTitlebar);
+
+    QList<QWidget *> orderWidget;
+    QList<QHBoxLayout *> orderLayout;
+    orderLayout << leftLayout << centerLayout << rightLayout;
+
+    //查找 leftLayout、centerLayout、rightLayout 三个区域中有 TabFocus 属性的 widget
+    for (QHBoxLayout * lyt : orderLayout) {
+        if (!lyt) {
+            continue;
+        }
+
+        for (int i = 0; i < lyt->count(); ++i) {
+            QWidget *wdg = lyt->itemAt(i)->widget();
+            if (wdg && (wdg->focusPolicy() & Qt::FocusPolicy::TabFocus)) {
+                orderWidget.append(wdg);
+            }
+        }
+    }
+
+    if (orderWidget.isEmpty()) {
+        return;
+    }
+
+    //对筛选出来的 widget 重新设置 taborder
+    QWidget::setTabOrder(q, orderWidget.first());
+    for (int i = 0; i < orderWidget.count() - 1; ++i) {
+        QWidget::setTabOrder(orderWidget.at(i), orderWidget.at(i + 1));
+    }
+}
+
 #endif
 
 /*!
@@ -546,8 +676,6 @@ DTitlebar::DTitlebar(QWidget *parent) :
         setBackgroundTransparent(true);
     }
 
-    DThemeManager::registerWidget(this, QStringList({"transparent"}));
-
     D_D(DTitlebar);
     d->init();
 
@@ -555,10 +683,6 @@ DTitlebar::DTitlebar(QWidget *parent) :
     if (parent && parent->window()->windowType() != Qt::Window) {
         d->optionButton->hide();
     }
-
-    d->buttonArea->adjustSize();
-    d->buttonArea->resize(d->buttonArea->size());
-    d->titlePadding->setFixedSize(d->buttonArea->size());
 }
 
 #ifndef QT_NO_MENU
@@ -634,14 +758,31 @@ void DTitlebar::showMenu()
     D_D(DTitlebar);
 
     if (d->menu) {
-        d->optionButton->setState(DImageButton::Normal);
+        // 更新主题选中的项
+        if (d->switchThemeMenu) {
+            QAction *action;
+
+            switch (DGuiApplicationHelper::instance()->paletteType()) {
+            case DGuiApplicationHelper::LightType:
+                action = d->lightThemeAction;
+                break;
+            case DGuiApplicationHelper::DarkType:
+                action = d->darkThemeAction;
+                break;
+            default:
+                action = d->autoThemeAction;
+                break;
+            }
+
+            action->setChecked(true);
+        }
+
         d->menu->exec(d->optionButton->mapToGlobal(d->optionButton->rect().bottomLeft()));
+        d->optionButton->update(); // FIX: bug-25253 sometimes optionButton not udpate after menu exec(but why?)
     }
 }
 #endif
 
-
-
 void DTitlebar::showEvent(QShowEvent *event)
 {
     //fix the width issue and process menu
@@ -661,12 +802,14 @@ void DTitlebar::showEvent(QShowEvent *event)
         d->_q_onTopWindowMotifHintsChanged(
             static_cast<quint32>(window()->internalWinId()));
     }
+
+    d->updateCenterArea();
 }
 
 void DTitlebar::mousePressEvent(QMouseEvent *event)
 {
     D_D(DTitlebar);
-    d->mousePressed = (event->buttons() == Qt::LeftButton);
+    d->mousePressed = (event->button() == Qt::LeftButton);
 
     if (event->button() == Qt::RightButton) {
         DWindowManagerHelper::popupSystemWindowMenu(window()->windowHandle());
@@ -682,7 +825,7 @@ void DTitlebar::mousePressEvent(QMouseEvent *event)
 void DTitlebar::mouseReleaseEvent(QMouseEvent *event)
 {
     D_D(DTitlebar);
-    if (event->buttons() == Qt::LeftButton) {
+    if (event->button() == Qt::LeftButton) {
         d->mousePressed = false;
     }
 }
@@ -691,6 +834,16 @@ bool DTitlebar::eventFilter(QObject *obj, QEvent *event)
 {
     D_D(DTitlebar);
 
+    if (event->type() == QEvent::MouseButtonPress &&
+            static_cast<QMouseEvent *>(event)->button() == Qt::RightButton &&
+            (obj ==d->minButton || obj == d->maxButton ||
+            obj == d->closeButton || obj == d->optionButton ||
+            obj == d->quitFullButton))
+    {
+        event->accept(); // button on titlebar should not show kwin menu
+        return true;
+    }
+
     if (obj == d->targetWindow()) {
         switch (event->type()) {
         case QEvent::ShowToParent:
@@ -726,17 +879,30 @@ bool DTitlebar::eventFilter(QObject *obj, QEvent *event)
     return QWidget::eventFilter(obj, event);
 }
 
+bool DTitlebar::event(QEvent *e)
+{
+    if (e->type() == QEvent::LayoutRequest) {
+        D_D(DTitlebar);
+
+        d->updateCenterArea();
+    }
+
+    return QFrame::event(e);
+}
+
 void DTitlebar::resizeEvent(QResizeEvent *event)
 {
     //override QWidget::resizeEvent to fix button and separator pos.
     D_D(DTitlebar);
 
-    d->optionButton->setFixedHeight(event->size().height());
-    d->minButton->setFixedHeight(event->size().height());
-    d->maxButton->setFixedHeight(event->size().height());
-    d->closeButton->setFixedHeight(event->size().height());
     d->separatorTop->setFixedWidth(event->size().width());
     d->separator->setFixedWidth(event->size().width());
+    d->updateCenterArea();
+
+    if (d->blurWidget) {
+        d->blurWidget->resize(event->size());
+    }
+
     return QWidget::resizeEvent(event);
 }
 
@@ -753,55 +919,79 @@ void DTitlebar::resizeEvent(QResizeEvent *event)
  * @param fixCenterPos 是否需要自动修正控件位置，用于保持控件居中显示。
  */
 void DTitlebar::setCustomWidget(QWidget *w, bool fixCenterPos)
-{
-    setCustomWidget(w, Qt::AlignCenter, fixCenterPos);
-}
-
-/*!
- * \~english @brief DTitlebar::setCustomWidget sets a customized widget to be used as the
- * central content of the title bar.
- * @param w is the widget to be used as the customize widget shown in the title
- * bar.
- * @param wflag is used to vertically align the widget.
- * @param fixCenterPos indicates whether it should automatically move the
- * customize widget to the horizontal center of the title bar or not.
- */
-/*!
- * \~chinese @brief 设置标题栏上的自定义控件
- * @param w 需要显示的控件。
- * @param wflag 控件对齐方式。
- * @param fixCenterPos 是否需要自动修正控件位置，用于保持控件居中显示。
- */
-void DTitlebar::setCustomWidget(QWidget *w, Qt::AlignmentFlag wflag, bool fixCenterPos)
 {
     D_D(DTitlebar);
-    if (!w || w == d->titleArea) {
+
+    if (w == d->customWidget) {
         return;
     }
 
-    QSize old = d->buttonArea->size();
-
-    QHBoxLayout *l = new QHBoxLayout;
-    l->setSpacing(0);
-    l->setMargin(0);
-
-    if (fixCenterPos) {
-        d->titlePadding = new QWidget;
-        d->titlePadding->setFixedSize(old);
-        l->addWidget(d->titlePadding);
+    if (d->customWidget) {
+        d->mainLayout->removeWidget(d->customWidget);
+        d->customWidget->hide();
+        d->customWidget->deleteLater();
     }
 
-    l->addWidget(w, 0, wflag);
-    qDeleteAll(d->coustomAtea->children());
-    d->titleLabel = Q_NULLPTR;
-    d->titleArea = Q_NULLPTR;
-    d->iconLabel = Q_NULLPTR;
-    d->titlePadding = Q_NULLPTR;
-    d->coustomAtea->setLayout(l);
-    d->buttonArea->resize(old);
     d->customWidget = w;
 
-    w->resize(d->coustomAtea->size());
+    if (w) {
+        w->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    } else {
+        d->centerArea->show();
+        d->titleLabel = d->centerArea;
+
+        return;
+    }
+
+    if (fixCenterPos) {
+        for (int i = 0; i < d->centerLayout->count(); ++i) {
+            delete d->centerLayout->itemAt(i);
+        }
+
+        addWidget(w, Qt::Alignment());
+        d->centerArea->show();
+        d->titleLabel = d->centerArea;
+    } else {
+        d->mainLayout->insertWidget(1, w);
+        d->titleLabel = nullptr;
+        d->centerArea->hide();
+    }
+}
+
+void DTitlebar::addWidget(QWidget *w, Qt::Alignment alignment)
+{
+    D_D(DTitlebar);
+
+    if (alignment & Qt::AlignLeft) {
+        d->leftLayout->addWidget(w, 0, alignment & ~Qt::AlignLeft);
+    } else if (alignment & Qt::AlignRight) {
+        d->rightLayout->addWidget(w, 0, alignment & ~Qt::AlignRight);
+    } else {
+        d->centerLayout->addWidget(w, 0, alignment);
+        d->centerArea->clear();
+        d->titleLabel = nullptr;
+    }
+
+    updateGeometry();
+    d->updateTabOrder();
+}
+
+void DTitlebar::removeWidget(QWidget *w)
+{
+    D_D(DTitlebar);
+
+    d->leftLayout->removeWidget(w);
+    d->centerLayout->removeWidget(w);
+    d->rightLayout->removeWidget(w);
+
+    if (d->centerLayout->isEmpty()) {
+        d->titleLabel = d->centerArea;
+        d->titleLabel->setText(d->targetWindowHandle->title());
+        setProperty("_dtk_title", d->titleLabel->text());
+    }
+
+    updateGeometry();
+    d->updateTabOrder();
 }
 
 /*!
@@ -810,15 +1000,12 @@ void DTitlebar::setCustomWidget(QWidget *w, Qt::AlignmentFlag wflag, bool fixCen
  * @param h is the target height.
  */
 /*!
- * \~chinese @brief 设置标题栏的高度，默认高度为40。
+ * \~chinese @brief 设置标题栏的高度，默认高度为 50。
  * @param h 需要设置的高度
  */
 void DTitlebar::setFixedHeight(int h)
 {
-    D_D(DTitlebar);
     QWidget::setFixedHeight(h);
-    d->coustomAtea->setFixedHeight(h);
-    d->buttonArea->setFixedHeight(h);
 }
 
 /*!
@@ -831,7 +1018,12 @@ void DTitlebar::setFixedHeight(int h)
  */
 void DTitlebar::setBackgroundTransparent(bool transparent)
 {
-    setProperty("transparent", transparent);
+    setAutoFillBackground(!transparent);
+
+    if (transparent)
+        setBackgroundRole(QPalette::NoRole);
+    else
+        setBackgroundRole(QPalette::Base);
 }
 
 /*!
@@ -870,6 +1062,7 @@ void DTitlebar::setTitle(const QString &title)
     } else if (parentWidget()) {
         parentWidget()->setWindowTitle(title);
     }
+    setProperty("_dtk_title", title);
 }
 
 /*!
@@ -883,10 +1076,11 @@ void DTitlebar::setTitle(const QString &title)
 void DTitlebar::setIcon(const QIcon &icon)
 {
     D_D(DTitlebar);
-    if (d->titleLabel && !d->embedMode) {
-        d->titleLabel->setContentsMargins(0, 0, 0, 0);
-        d->iconLabel->setPixmap(icon.pixmap(QSize(DefaultIconWidth, DefaultIconHeight)));
+    if (!d->embedMode) {
+        d->iconLabel->setIcon(icon);
+        d->setIconVisible(!icon.isNull());
     } else if (parentWidget()) {
+        d->setIconVisible(false);
         parentWidget()->setWindowIcon(icon);
     }
 }
@@ -898,6 +1092,29 @@ void DTitlebar::toggleWindowState()
     d->_q_toggleWindowState();
 }
 
+void DTitlebar::setBlurBackground(bool blurBackground)
+{
+    D_D(DTitlebar);
+
+    if (static_cast<bool>(d->blurWidget) == blurBackground)
+        return;
+
+    if (d->blurWidget) {
+        d->blurWidget->hide();
+        d->blurWidget->deleteLater();
+        d->blurWidget = nullptr;
+    } else {
+        d->blurWidget = new DBlurEffectWidget(this);
+        d->blurWidget->lower();
+        d->blurWidget->resize(size());
+        d->blurWidget->setMaskColor(DBlurEffectWidget::AutoColor);
+        d->blurWidget->setRadius(30);
+        d->blurWidget->show();
+    }
+
+    setAutoFillBackground(!blurBackground);
+}
+
 /*!
  * \~english @brief DTitlebar::buttonAreaWidth returns the width of the area that all the
  * window buttons occupies.
@@ -1002,43 +1219,117 @@ void DTitlebar::setEmbedMode(bool visible)
     d->updateButtonsState(windowFlags());
 }
 
-void DTitlebar::resize(int w, int h)
-{
-    D_DC(DTitlebar);
-    if (d->customWidget) {
-        d->customWidget->resize(w - d->buttonArea->width(), h);
-    }
-}
-
-void DTitlebar::resize(const QSize &sz)
-{
-    DTitlebar::resize(sz.width(), sz.height());
-}
-
+/*!
+ * \~chinese \brief DTitlebar::menuIsVisible
+ * \~chinese \return true 菜单可见 false菜单不可见
+ */
 bool DTitlebar::menuIsVisible() const
 {
     D_DC(DTitlebar);
     return !d->optionButton->isVisible();
 }
 
+/*!
+ * \~chinese \brief DTitlebar::setMenuVisible 设置菜单是否可见
+ * \~chinese \param visible true 菜单可见 false菜单不可见
+ */
 void DTitlebar::setMenuVisible(bool visible)
 {
     D_D(DTitlebar);
     d->optionButton->setVisible(visible);
 }
 
+/*!
+ * \~chinese \brief DTitlebar::menuIsDisabled
+ * \~chinese \return true 菜单被禁用 false 菜单没有被禁用
+ */
 bool DTitlebar::menuIsDisabled() const
 {
     D_DC(DTitlebar);
     return !d->optionButton->isEnabled();
 }
 
+/*!
+ * \~chinese \brief DTitlebar::setMenuDisabled 设置菜单是否被禁用
+ * \~chinese \param disabled true 菜单被禁用 false菜单没有被禁用
+ */
 void DTitlebar::setMenuDisabled(bool disabled)
 {
     D_D(DTitlebar);
     d->optionButton->setDisabled(disabled);
 }
 
+/*!
+ * \~chinese \brief DTitlebar::quitMenuIsDisabled
+ * \~chinese \return true 退出菜单被禁用 false退出菜单没有被禁用
+ */
+bool DTitlebar::quitMenuIsDisabled() const
+{
+    D_DC(DTitlebar);
+
+    return d->quitAction && !d->quitAction->isEnabled();
+}
+
+/*!
+ * \~chinese \brief DTitlebar::setQuitMenuDisabled 设置退出菜单是否被禁用
+ * \~chinese \param disabled true 退出菜单被禁用 false退出菜单没有被禁用
+ */
+void DTitlebar::setQuitMenuDisabled(bool disabled)
+{
+    D_D(DTitlebar);
+
+    if (!d->quitAction) {
+        d->_q_addDefaultMenuItems();
+    }
+
+    d->quitAction->setEnabled(!disabled);
+}
+
+/*!
+ * \~chinese \brief DTitlebar::setQuitMenuVisible 设置退出菜单是否被可见
+ * \~chinese \param visible true 退出菜单可见 false退出菜单不可见
+ */
+void DTitlebar::setQuitMenuVisible(bool visible)
+{
+    D_D(DTitlebar);
+
+    if (!d->quitAction) {
+        d->_q_addDefaultMenuItems();
+    }
+
+    d->quitAction->setVisible(visible);
+}
+
+/*!
+ * \~chinese \brief DTitlebar::switchThemeMenuIsVisible
+ * \~chinese \return true 切换主题菜单可见 false切换主题菜单不可见
+ */
+bool DTitlebar::switchThemeMenuIsVisible() const
+{
+    D_DC(DTitlebar);
+
+    return d->switchThemeMenu;
+}
+
+/*!
+ * \~chinese \brief DTitlebar::setSwitchThemeMenuVisible 设置切换主题菜单是否可见
+ * \~chinese \param visible true 切换主题菜单可见 false切换主题菜单不可见
+ */
+void DTitlebar::setSwitchThemeMenuVisible(bool visible)
+{
+    D_D(DTitlebar);
+
+    if (visible == d->canSwitchTheme) {
+        return;
+    }
+
+    d->canSwitchTheme = visible;
+
+    if (d->switchThemeMenu) {
+        d->switchThemeMenu->menuAction()->setVisible(visible);
+        d->themeSeparator->setVisible(visible);
+    }
+}
 
 /*!
  * \~english \brief DTitlebar::setDisableFlags will disable button match flags.
@@ -1067,10 +1358,46 @@ Qt::WindowFlags DTitlebar::disableFlags() const
     return d->disableFlags;
 }
 
+QSize DTitlebar::sizeHint() const
+{
+    D_DC(DTitlebar);
+
+    if (d->centerArea->isHidden()) {
+        return QFrame::sizeHint();
+    }
+
+    int padding = qMax(d->leftArea->sizeHint().width(), d->rightArea->sizeHint().width());
+    int width = d->centerArea->sizeHint().width() + 2 * d->mainLayout->spacing() + 2 * padding;
+
+    return QSize(width, DefaultTitlebarHeight);
+}
+
+QSize DTitlebar::minimumSizeHint() const
+{
+    return sizeHint();
+}
+
+bool DTitlebar::blurBackground() const
+{
+    D_DC(DTitlebar);
+    return d->blurWidget;
+}
+
+void DTitlebar::setFullScreenButtonVisible(bool visible)
+{
+    D_D(DTitlebar);
+    d->fullScreenButtonVisible = visible;
+}
+
 void DTitlebar::mouseMoveEvent(QMouseEvent *event)
 {
+    D_D(DTitlebar);
+
     Qt::MouseButton button = event->buttons() & Qt::LeftButton ? Qt::LeftButton : Qt::NoButton;
     if (event->buttons() == Qt::LeftButton /*&& d->mousePressed*/) {
+        if (!d->mousePressed) {
+            return;
+        }
         Q_EMIT mouseMoving(button);
     }
 
