@@ -2,7 +2,7 @@
  * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,22 +11,21 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <DObjectPrivate>
-
-#include "dthememanager.h"
 #include "dwindowmaxbutton.h"
-#include "private/dimagebutton_p.h"
-#include <QStyle>
+#include "private/diconbutton_p.h"
+#include "dstyleoption.h"
 
 DWIDGET_BEGIN_NAMESPACE
 
-class DWindowMaxButtonPrivate : public DImageButtonPrivate{
+class DWindowMaxButtonPrivate : public DIconButtonPrivate {
 public:
-    DWindowMaxButtonPrivate(DWindowMaxButton* qq):DImageButtonPrivate(qq) {
+    DWindowMaxButtonPrivate(DWindowMaxButton* qq)
+        : DIconButtonPrivate(qq)
+    {
         m_isMaximized = false;
     }
 
@@ -55,11 +54,11 @@ private:
  * \~chinese \param parent 为创建对象的父控件。
  */
 DWindowMaxButton::DWindowMaxButton(QWidget * parent) :
-    DImageButton(*new DWindowMaxButtonPrivate(this), parent)
+    DIconButton(*new DWindowMaxButtonPrivate(this), parent)
 {
-    DThemeManager::registerWidget(this, QStringList({"isMaximized"}));
-
-    setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
+    setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Expanding);
+    setIcon(QStyle::SP_TitleBarMaxButton);
+    setFlat(true);
 }
 
 /*!
@@ -84,6 +83,11 @@ bool DWindowMaxButton::isMaximized() const
     return d->m_isMaximized;
 }
 
+QSize DWindowMaxButton::sizeHint() const
+{
+    return iconSize();
+}
+
 void DWindowMaxButton::setMaximized(bool isMaximized)
 {
     D_D(DWindowMaxButton);
@@ -92,9 +96,23 @@ void DWindowMaxButton::setMaximized(bool isMaximized)
         return;
 
     d->m_isMaximized = isMaximized;
+
+    if (isMaximized) {
+        setIcon(QStyle::SP_TitleBarNormalButton);
+    } else {
+        setIcon(QStyle::SP_TitleBarMaxButton);
+    }
+
     Q_EMIT maximizedChanged(isMaximized);
 }
 
+void DWindowMaxButton::initStyleOption(DStyleOptionButton *option) const
+{
+    DIconButton::initStyleOption(option);
+
+    option->features |= QStyleOptionButton::ButtonFeature(DStyleOptionButton::TitleBarButton);
+}
+
 DWIDGET_END_NAMESPACE
 
 
