@@ -2,7 +2,7 @@
  * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,22 +11,28 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef DWINDOWMINBUTTON_H
 #define DWINDOWMINBUTTON_H
 
-#include "dimagebutton.h"
+#include <DIconButton>
 
 DWIDGET_BEGIN_NAMESPACE
 
-class LIBDTKWIDGETSHARED_EXPORT DWindowMinButton : public DImageButton
+class LIBDTKWIDGETSHARED_EXPORT DWindowMinButton : public DIconButton
 {
     Q_OBJECT
+
 public:
     DWindowMinButton(QWidget * parent = 0);
+
+    QSize sizeHint() const override;
+
+protected:
+    void initStyleOption(DStyleOptionButton *option) const override;
 };
 
 DWIDGET_END_NAMESPACE
