@@ -2,7 +2,7 @@
  * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -20,11 +20,15 @@
 
 #include "dlineedit_p.h"
 #include "dipv4lineedit.h"
+#include "dimagebutton.h"
 
 DWIDGET_BEGIN_NAMESPACE
 
-class DIpv4LineEditPrivate : public DLineEditPrivate
+class DIpv4LineEditPrivate : public DTK_CORE_NAMESPACE::DObjectPrivate
 {
+    Q_DECLARE_PUBLIC(DIpv4LineEdit)
+
+public:
     DIpv4LineEditPrivate(DIpv4LineEdit *parent);
 
     void init();
@@ -41,8 +45,6 @@ class DIpv4LineEditPrivate : public DLineEditPrivate
     QWidget *editMainWidget;
 
     bool focus = false;
-
-    D_DECLARE_PUBLIC(DIpv4LineEdit)
 };
 
 DWIDGET_END_NAMESPACE
