@@ -2,7 +2,7 @@
  * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -19,34 +19,36 @@
 #define DLINEEDIT_P_H
 
 #include "dlineedit.h"
-#include "dimagebutton.h"
+#include "dalertcontrol.h"
 
 #include <DObjectPrivate>
-
-#include <QHBoxLayout>
-
-QT_BEGIN_NAMESPACE
-class QWidgetAction;
-QT_END_NAMESPACE
+#include <QPointer>
+#include <DFloatingWidget>
 
 DWIDGET_BEGIN_NAMESPACE
 
-class DArrowRectangle;
+class DToolTip;
 class DLineEditPrivate : public DTK_CORE_NAMESPACE::DObjectPrivate
 {
     Q_DECLARE_PUBLIC(DLineEdit)
 
 public:
     DLineEditPrivate(DLineEdit *q);
+    void updateTooltipPos();
 
     void init();
 
-public:
-    bool m_isAlert = false;
+    DAlertControl *control{nullptr};
 
-    DImageButton *m_rightIcon;
-    QWidgetAction *m_iconAction;
-    DArrowRectangle *tooltip = Q_NULLPTR;
+    QWidget *leftWidget;
+    QWidget *rightWidget;
+
+    QLineEdit *lineEdit;
+    QHBoxLayout *hLayout;
+
+    bool bSpeechToText = true;
+    bool bTextToSpeech = true;
+    bool bTextToTranslate = true;
 };
 
 DWIDGET_END_NAMESPACE
