@@ -2,7 +2,7 @@
  * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,16 +11,18 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef DMAINWINDOW_P_H
 #define DMAINWINDOW_P_H
 
-#include <DObjectPrivate>
 #include "dtkwidget_global.h"
 #include "dmainwindow.h"
+#include "dshadowline.h"
+
+#include <DObjectPrivate>
 
 class QShortcut;
 
@@ -34,9 +36,11 @@ public:
     DMainWindowPrivate(DMainWindow *qq);
 
     void init();
+    void updateTitleShadowGeometry();
 
     DPlatformWindowHandle   *handle     = Q_NULLPTR;
     DTitlebar               *titlebar   = Q_NULLPTR;
+    DShadowLine             *titleShadow = nullptr;
     QShortcut               *help       = Q_NULLPTR;
 
 private:
