@@ -2,7 +2,7 @@
  * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -23,6 +23,7 @@
 
 DWIDGET_BEGIN_NAMESPACE
 
+class DSuggestButton;
 class DPasswordEditPrivate : DLineEditPrivate
 {
 public:
@@ -34,6 +35,9 @@ public:
 
 protected:
     Q_DECLARE_PUBLIC(DPasswordEdit)
+
+private:
+    DSuggestButton * togglePasswordVisibleButton;
 };
 
 DWIDGET_END_NAMESPACE
