@@ -2,7 +2,7 @@
  * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -27,19 +27,14 @@ class QLabel;
 
 DWIDGET_BEGIN_NAMESPACE
 
-class DImageButton;
+class DLineEdit;
 class DSpinBoxPrivate : public DTK_CORE_NAMESPACE::DObjectPrivate
 {
     DSpinBoxPrivate(DSpinBox *parent);
 
     void init();
 
-    void _q_resizeInsideFrame(const QSize &size);
-
-    QFrame *insideFrame;
-    bool alert = false;
-    int defaultValue = 0;
-
+    DLineEdit *lineEdit;
     D_DECLARE_PUBLIC(DSpinBox)
 };
 
@@ -49,12 +44,7 @@ class DDoubleSpinBoxPrivate : public DTK_CORE_NAMESPACE::DObjectPrivate
 
     void init();
 
-    void _q_resizeInsideFrame(const QSize &size);
-
-    QFrame *insideFrame;
-    bool alert = false;
-    double defaultValue = 0;
-
+    DLineEdit *lineEdit;
     D_DECLARE_PUBLIC(DDoubleSpinBox)
 };
 
