@@ -2,7 +2,7 @@
  * Copyright (C) 2016 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -25,6 +25,8 @@
 
 #include <DSettings>
 #include <DSettingsGroup>
+#include <DListView>
+#include <DApplicationHelper>
 
 #include "navigationdelegate.h"
 
@@ -34,8 +36,19 @@ class NavigationPrivate
 {
 public:
     NavigationPrivate(Navigation *parent) : q_ptr(parent) {}
+    QModelIndex indexOfGroup(const QString &key) const
+    {
+        for (int i = 0; i < navbarModel->rowCount(); ++i) {
+            auto index = navbarModel->index(i, 0);
+            if (index.data(NavigationDelegate::NavKeyRole).toString() == key) {
+                return index;
+            }
+        }
 
-    QListView           *navbar         = nullptr;
+        return QModelIndex();
+    }
+
+    DListView           *navbar         = nullptr;
     QStandardItemModel  *navbarModel    = nullptr;
 
     Navigation *q_ptr;
@@ -48,29 +61,29 @@ Navigation::Navigation(QWidget *parent) :
     Q_D(Navigation);
 
     setObjectName("Navigation");
-//    setStyleSheet("#Navigation{border: none; border-right: 1px solid rgba(0,0,0,0.1);}");
 
     setContentsMargins(0, 0, 0, 0);
     auto layout = new QHBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
 
-    d->navbar = new QListView(this);
+    d->navbar = new DListView(this);
     d->navbar->setObjectName("NavigationBar");
-//    d->navbar->setStyleSheet("#NavigationBar{border: none;}");
-//    d->navbar->setMinimumWidth(160);
-//    d->navbar->setMaximumWidth(199);
     d->navbar->setContentsMargins(0, 0, 0, 0);
+    d->navbar->setAutoFillBackground(true);
+    d->navbar->setViewportMargins(10, 0, 10, 0);
+    DPalette pa = DApplicationHelper::instance()->palette(d->navbar);
+    pa.setBrush(DPalette::ItemBackground, Qt::transparent);
+    DApplicationHelper::instance()->setPalette(d->navbar, pa);
 
     d->navbar->setSelectionMode(QListView::SingleSelection);
-    d->navbar->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     d->navbar->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
-    d->navbarModel = new QStandardItemModel;
+    d->navbarModel = new QStandardItemModel(this);
 
     d->navbar->setModel(d->navbarModel);
 
     d->navbar->setEditTriggers(QAbstractItemView::NoEditTriggers);
-    d->navbar->setItemDelegate(new NavigationDelegate);
+    d->navbar->setItemDelegate(new NavigationDelegate(d->navbar));
 
     layout->addWidget(d->navbar);
 
@@ -80,25 +93,41 @@ Navigation::Navigation(QWidget *parent) :
             Q_EMIT selectedGroup(key);
         }
     });
-
-//    setMaximumWidth(200);
     d->navbar->setFixedWidth(190);
-    setFixedWidth(190 + 1);
 }
 
 Navigation::~Navigation()
 {
 }
 
+bool Navigation::groupIsVisible(const QString &key) const
+{
+    Q_D(const Navigation);
+
+    const QModelIndex &index = d->indexOfGroup(key);
+
+    return index.isValid() && d->navbar->isRowHidden(index.row());
+}
+
+void Navigation::setGroupVisible(const QString &key, bool visible)
+{
+    Q_D(Navigation);
+
+    const QModelIndex &index = d->indexOfGroup(key);
+
+    if (index.isValid()) {
+        d->navbar->setRowHidden(index.row(), !visible);
+    }
+}
+
 void Navigation::onSelectGroup(const QString &key)
 {
     Q_D(Navigation);
-    for (int i = 0; i < d->navbarModel->rowCount(); ++i) {
-        auto index = d->navbarModel->index(i, 0);
-        if (index.data(NavigationDelegate::NavKeyRole).toString() == key) {
-            d->navbar->setCurrentIndex(index);
-            return;
-        }
+
+    const QModelIndex &index = d->indexOfGroup(key);
+
+    if (index.isValid()) {
+        d->navbar->setCurrentIndex(index);
     }
 }
 
@@ -106,16 +135,7 @@ void Navigation::updateSettings(const QByteArray &translateContext, QPointer<DTK
 {
     Q_D(Navigation);
 
-    bool first = true;
     for (auto groupKey : settings->groupKeys()) {
-        if (!first) {
-            auto item = new QStandardItem;
-            item->setData("", Qt::DisplayRole);
-            item->setData(NavigationDelegate::Split, NavigationDelegate::NavLevelRole);
-            d->navbarModel->appendRow(item);
-        }
-        first = false;
-
         auto group = settings->group(groupKey);
         if (group->isHidden()) {
             continue;
@@ -159,9 +179,6 @@ void Navigation::updateSettings(const QByteArray &translateContext, QPointer<DTK
     }
 
     d->navbar->setCurrentIndex(d->navbarModel->index(0, 0));
-//    this->adjustSize();
-//    d->navbar->setMaximumWidth(200);
-//    this->setFixedWidth(d->navbar->width() + 1);
 }
 
 DWIDGET_END_NAMESPACE
